import { EventEmitter, OnChanges, Type } from '@angular/core';
import { ControlValueAccessor, FormGroup, AbstractControl } from '@angular/forms';
import { FieldConfigProperty, Field, Item } from '@ec.components/core';
import { DynamicSlotComponent } from '../dynamic-slot/dynamic-slot.component';
/** This directive can be used to display a field. It is used inside ec-form as well as ec-list. */
export declare class InputComponent extends DynamicSlotComponent implements ControlValueAccessor, OnChanges {
    /** The belonging form group */
    group: FormGroup;
    /** If true, the input is readonly. Is set by ControlValueAccessor#setDisabled */
    disabled: FormGroup;
    /** The belonging form control. This is not required if you pass in a field and group. */
    control: AbstractControl;
    /** The changed ouput emits whenever the form control of the input changes. */
    changed: EventEmitter<any>;
    /** Emits when the component has been loaded */
    ready: EventEmitter<any>;
    /** Debounce time in ms before the changed event emits. */
    debounce: number;
    /** The instance of field that should be used in the template, can also be a property name. */
    field: Field;
    /** The property name that is edited. Expects a form as item input */
    property: string;
    /** The belonging item */
    item: Item<any>;
    /** Config that should be used, only needed when not using field input */
    config: FieldConfigProperty;
    /** Overrides the default component */
    component: Type<any>;
    /** If true, the input will never reinit/reload. */
    lazy: boolean;
    /** Holds a reference to the component instance. This is helpful when you want to modify the component after form intialization.
     * You can access a form's InputComponents via FormComponent#inputs */
    componentInstance: InputComponent;
    /** The current value of the input. Needs to be saved for the case the component is not yet loaded */
    value: any;
    /** Emitter to focus the input field */
    focusEvent: EventEmitter<boolean>;
    ngOnChanges(changes?: any): void;
    focus(focus?: boolean): void;
    init(): void;
    connectControl(): void;
    /** writes value to editor on outside model change. */
    writeValue(value: any): void;
    propagateChange: (_: any) => void;
    /** Registers change callback */
    registerOnChange(fn: any): void;
    registerOnTouched(): void;
    setDisabledState(isDisabled: any): void;
}
