import { EventEmitter, OnChanges, ChangeDetectorRef } from '@angular/core';
import { Collection, List, ListConfig, Selection, Pagination } from '@ec.components/core';
import { Item } from '@ec.components/core';
import { PaginationConfig } from './pagination/pagination-config.interface';
import { ListConfigService } from './list-config.service';
/**
 * The ListComponent will render a list containing the given items or collection.
 *
 * <example-url>https://components.entrecode.de/ui/list/basic?e=1</example-url>
 * <example-url>https://components.entrecode.de/ui/list/transforms?e=1</example-url>
 * */
export declare class ListComponent<T> implements OnChanges {
    listConfig: ListConfigService;
    cdr: ChangeDetectorRef;
    /** The current list config */
    config: ListConfig<T>;
    /** Config input for List */
    /** Flag that flips true when loading. */
    isLoading: boolean;
    configInput: ListConfig<T>;
    /** The visible items */
    items: Array<T>;
    /** The used collection */
    collection: Collection<T>;
    /** The used selection */
    selection: Selection<T>;
    /** If true, only one item is selectable next */
    solo: boolean;
    /** Event emitter on item selection */
    columnClicked: EventEmitter<Item<T>>;
    /** Event emitter on selection change */
    selected: EventEmitter<Selection<T>>;
    /** The Instance of the List */
    list: List<T>;
    /** Pagination that should be used */
    pagination: Pagination<T>;
    /** Custom PaginationConfig */
    paginationConfig: PaginationConfig;
    /** If true, the first item in the list will always be focused after changed */
    autoFocusFirst: boolean;
    /** Current focus */
    focusItem: Item<T>;
    /** emits after the list changed */
    changed: EventEmitter<List<T>>;
    constructor(listConfig: ListConfigService, cdr: ChangeDetectorRef);
    /** Changing items or collection will trigger reconstructing the list with the new items.
     * Changing the selection will reconstruct the selection */
    ngOnChanges(changes?: any): void;
    init(list: List<T>): void;
    /** Column click handler. Triggers select.emit(item) with fallback to selection.toggle*/
    columnClick(item: any): void;
    /** Decides if the header should be visible or not */
    showHeader(): string | number;
    /** Selects the item with the given index */
    selectIndex(index: number): void;
    focusFirst(): void;
    /** Selects the next item */
    focusNext(): void;
    /** Selects the previous item */
    focusPrev(): void;
    /** Filters the list */
    filter(property: any, value: any): void;
}
