import { AfterViewInit, EventEmitter, OnInit, OnChanges, ChangeDetectorRef } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { List } from '@ec.components/core';
import { SymbolService } from '../../symbol/symbol.service';
import { Subject } from 'rxjs';
import { Focus } from '../../utility/focus/focus.interface';
import { ListComponent } from '../list.component';
/** Genereic Searchbar component. Filters a given list its label property (or given property).
 * Supports autofocus and arrow navigation. */
export declare class SearchbarComponent implements AfterViewInit, Focus, OnInit, OnChanges {
    route: ActivatedRoute;
    symbol: SymbolService;
    cdr: ChangeDetectorRef;
    /** If true, the input wont be editable */
    disabled: boolean;
    /** Searchbar placeholder */
    placeholder: string;
    /** Default placeholder when no placeholder is given */
    defaultPlaceholder: string;
    /** The input query that should be prefilled */
    query: string;
    /** Property that should be filtered */
    property: string;
    /** If true, the input will be autofocused */
    autofocus: boolean;
    /** The event that focuses the input */
    focusEvent: EventEmitter<boolean>;
    /** Delay until search is fired */
    debounceTime: number;
    /** Subject that is triggered on keyup */
    queryValue: Subject<any>;
    /** Subject that is triggered on key trigger */
    keySubject: Subject<any>;
    /** Subject that is nexted when something is pasted */
    paste: Subject<any>;
    /** The list that should be filtered */
    list: List<any>;
    /** The list component that should be controled */
    listComponent: ListComponent<any>;
    /** Output that emits when enter is pressed on a selected item */
    selected: EventEmitter<any>;
    /** Emits when enter key is pressed */
    enter: EventEmitter<any>;
    /** Emits on keyup*/
    keyup: EventEmitter<any>;
    /** Emits on keypress */
    keypressed: EventEmitter<any>;
    /** Emits on blur */
    blur: EventEmitter<any>;
    /** Emits on focus */
    focus: EventEmitter<any>;
    /** Emits on paste */
    pasted: EventEmitter<any>;
    /** Emitted when the query changes, including debounce */
    queryChanged: EventEmitter<any>;
    /** timestamp of latest keypress that has been emitted */
    latestQuery: any;
    constructor(route: ActivatedRoute, symbol: SymbolService, cdr: ChangeDetectorRef);
    updatedList(list: any): void;
    initList(): void;
    ngOnInit(): void;
    ngOnChanges(): void;
    /** clears the input query */
    clear(): void;
    /** Updates the query string if the change happened outside */
    updateQueryFromOutside(query: any): void;
    /** prevents the event default and disables propagation */
    preventDefault(e: any): void;
    /** After the view is ready, the searchbar needs to be focused (if autofocus is true) */
    ngAfterViewInit(): void;
    /** Filters the list by the given value, either uses property or list.config.label.
     * If paste is true and the value matches the list.config.identifierPattern,
     * select is emitted immediately with a pseudo item containing the value as item identifier. */
    filterList(value: any): void;
    /** called on keydown. if arrow keys are pressed, toggle selection of next/prev elements of list */
    handleKey(e: any, listComponent?: ListComponent<any>): void;
}
