import { OnInit, ElementRef, OnChanges, TemplateRef, ChangeDetectorRef } from '@angular/core';
import { PopComponent } from '../pop/pop.component';
import { PopService } from '../pop/pop.service';
/**
 * A modal is an extension of a pop. It adds different style options that apply x.ui markup.
 * <example-url>https://components.entrecode.de/ui/modal?e=1</example-url>
 *
 * https://medium.com/claritydesignsystem/ng-content-the-hidden-docs-96a29d70d11b
 */
export declare class ModalComponent extends PopComponent implements OnInit, OnChanges {
    popService: PopService;
    elementRef: ElementRef;
    cdr: ChangeDetectorRef;
    /** all possible modes that can be set */
    types: string[];
    /** This property sets the mode + additional options.
     * It expects the type at first and non mandatory options like opens-left afterwards. */
    mode: string;
    /** If true, the modal will have a dark backdrop that disables clicking outside. */
    backdrop: boolean;
    /** Header Template */
    header: TemplateRef<any>;
    /** Body Template */
    body: TemplateRef<any>;
    /** Footer Template */
    footer: TemplateRef<any>;
    /** Templates for header body and footer */
    templates: TemplateRef<any>[];
    /** Sets data-col. If specified, the width of the modal is fixed to the given value (1-12). */
    columns: number | string;
    /** Will contain the classes (mode - type) */
    classes: string;
    /** Constructs the modal, injects pop service */
    constructor(popService: PopService, elementRef: ElementRef, cdr: ChangeDetectorRef);
    /** Is called on init and change. Parses mode input and throws warning if type is not supported. */
    initMode(): void;
    /** calls initMode */
    ngOnInit(): void;
    /** calls initMode */
    ngOnChanges(): void;
}
