import { EventEmitter, OnChanges, OnInit, ElementRef, ChangeDetectorRef } from '@angular/core';
import { ControlValueAccessor, FormControl } from '@angular/forms';
import { List, ListConfig, Selection } from '@ec.components/core';
import { Item } from '@ec.components/core';
import { PopComponent } from '../pop/pop.component';
import { SearchbarComponent } from '../list/searchbar/searchbar.component';
import { ListComponent } from '../list/list.component';
import { Subject } from 'rxjs';
import { LoaderComponent } from '../loader/loader.component';
/**
 * The SelectComponent will render a dropdown of a given list.
 *
 * <example-url>https://components.entrecode.de/ui/select?e=1</example-url>
 * */
export declare class SelectComponent<T> implements ControlValueAccessor, OnInit, OnChanges {
    elementRef: ElementRef;
    cdr: ChangeDetectorRef;
    /** the current dragged element */
    dragged: Item<T>;
    /** Configuration Object for List */
    config: ListConfig<T>;
    /** If true, the input will be disabled */
    disabled: ListConfig<T>;
    /** The visible items */
    value: Array<T> | T;
    /** The used selection */
    selection: Selection<T>;
    /** Input placeholder */
    placeholder: string;
    /** Event emitter on item selection */
    changed: EventEmitter<Selection<T>>;
    /** Event emitter on selected item click */
    itemClick: EventEmitter<Item<T>>;
    /** Emits when an item is being removed */
    remove: EventEmitter<Item<T>>;
    /** Emits when an item is being added */
    add: EventEmitter<Item<T>>;
    /** Emits the query when enter is pressed */
    enter: EventEmitter<SelectComponent<T>>;
    /** Subject that is nexted when enter is pressed */
    enterPressed: Subject<string>;
    /** The Instance of the List */
    list: List<T>;
    /** Available Items */
    values: Array<T>;
    /** Wether or not the selection should be solo */
    solo: boolean;
    /** Event emitter to focus input */
    focusEvent: EventEmitter<boolean>;
    /** The selection dropdown */
    dropdown: PopComponent;
    /** The loader inside the dropdown */
    dropdownLoader: LoaderComponent;
    /** The list in the dropdown */
    dropdownList: ListComponent<any>;
    /** The nested searchbar */
    searchbar: SearchbarComponent;
    /** Subject that is nexted when an item is being selected (clicked or entered on) */
    toggleItem: Subject<Item<T>>;
    /** The formControl that is used. */
    formControl: FormControl;
    constructor(elementRef: ElementRef, cdr: ChangeDetectorRef);
    getParentTree(el: any, tree?: any[]): any[];
    ngOnInit(): void;
    ngOnChanges(): void;
    /** creates the collection from the config */
    initSelection(): void;
    /** Called when the model changes */
    writeValue(value: any): void;
    /** Removes the given item from selection */
    removeItem(item: Item<any>, e?: any): void;
    /** Adds the given ite, emits add output if observed */
    addItem(item: Item<any>): void;
    getArray(value: any): any[];
    /** Uses the given value as selection items */
    use(value: any, event?: boolean): void;
    /** Initializes either with values, collection or list. Creates Selection with config. */
    useConfig(config?: ListConfig<T>): void;
    /** Is called when a selected item is clicked*/
    clickItem(item: any, e?: any): void;
    /** Select handler. Toggles selection. */
    listItemClicked(item: any, list?: any): void;
    focus(e: any): void;
    hasSoloSelection(): boolean;
    focusSearchbar(): void;
    /** Fires on selection change. Hides dropdown if solo */
    onChange(): void;
    /** Propagates formControl/ngModel changes */
    propagateChange: (_: any) => void;
    /** registers change method. (handled by angular) */
    registerOnChange(fn: any): void;
    registerOnTouched(): void;
    /** is called when an element is dragged by the user. hides element in selection */
    onDragStart(item: any, e: any, target?: any): void;
    /** called when the element is dropped. moves item in selection. */
    onDrop(e: any): void;
    /** is called when the drag stops in any kind of way. */
    cancelDrag(item: any, e: any, target?: any): void;
    activate(e: any): void;
    preventDefault(e: any): void;
    canRemove(): boolean;
    handleKey(e: any, list: any): void;
    filterDropdownList(listComponent: ListComponent<any>, query: any): void;
    setDisabledState(isDisabled: any): void;
}
