import { EventEmitter, OnInit } from '@angular/core';
import { FormBuilder, FormGroup } from '@angular/forms';
import { LoaderComponent } from '../../loader/loader.component';
import { WithLoader } from '../../loader/with-loader.interface';
import { SymbolService } from '../../symbol/symbol.service';
/** Login Form Component with validation. Fires success event with credentials on submit.
 * <example-url>https://components.entrecode.de/ui/login?e=1</example-url>
 */
export declare class LoginFormComponent implements OnInit, WithLoader {
    protected fb: FormBuilder;
    symbol: SymbolService;
    /** The login's form group.*/
    form: FormGroup;
    /** Flips true when submitted. */
    protected submitted: boolean;
    /** Contains possible error messages. */
    errorMessage: string;
    /** Event that emits on succesful submit of the form, passing the login credentials. */
    success: EventEmitter<any>;
    /** Event that emits when calling showError. */
    error: EventEmitter<any>;
    /** The loader that should be shown during login */
    loader: LoaderComponent;
    /** If true, email and password wont have labels */
    showLabels: boolean;
    /** The Label of the Mail field */
    emailLabel: string;
    /** The Placeholder of the mail Field */
    emailPlaceholder: string;
    /** The Label of the password field. */
    passwordLabel: string;
    /** The Placeholder of the password field */
    passwordPlaceholder: string;
    /** The Label of the submit button. Defaults to Login */
    buttonLabel: string;
    /** Additional Button classes */
    buttonClasses: string;
    /** Recent error Notifications */
    notifications: Notification[];
    /** Injects the FormBuilder*/
    constructor(fb: FormBuilder, symbol: SymbolService);
    /** Initializes the form */
    ngOnInit(): void;
    /** Shows the given error in the form. Clears the password field and emits the error event. */
    showError(err: any): any;
    /** Method that is meant to be overwritten by a subclass to communicate with an API. */
    login(value: any): Promise<any>;
    /** Is called when the form has been successfully submitted. Calls login and resets the form after. */
    onSubmit(): void;
}
