(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/router'), require('@angular/forms'), require('rxjs'), require('@angular/common'), require('@ec.components/core'), require('rxjs/operators'), require('@ec.components/calendar'), require('ngx-drag-drop')) :
    typeof define === 'function' && define.amd ? define('@ec.components/ui', ['exports', '@angular/core', '@angular/router', '@angular/forms', 'rxjs', '@angular/common', '@ec.components/core', 'rxjs/operators', '@ec.components/calendar', 'ngx-drag-drop'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory((global.ec = global.ec || {}, global.ec.components = global.ec.components || {}, global.ec.components.ui = {}), global.ng.core, global.ng.router, global.ng.forms, global.rxjs, global.ng.common, global['']['']['/core/dist'], global.rxjs.operators, global['']['']['/calendar/dist'], global.ngxDragDrop));
}(this, (function (exports, core, router, forms, rxjs, common, core$1, operators, calendar, ngxDragDrop) { 'use strict';

    /** A Tab is meant to be placed inside TabsComponent */
    var TabComponent = /** @class */ (function () {
        /** The constructor adds the tab itself to its TabsComponent parent. */
        function TabComponent(el) {
            this.el = el;
            /** Output that emits when the tab is activated */
            this.activated = new core.EventEmitter();
            /** Output that emits when the tab is deactivated */
            this.deactivated = new core.EventEmitter();
        }
        /** Selects the tab and nexts activated */
        TabComponent.prototype.activate = function () {
            this.selected = true;
            this.activated.next();
        };
        /** Deselects the tab and nexts activated */
        TabComponent.prototype.deactivate = function () {
            this.selected = false;
            this.deactivated.next();
        };
        return TabComponent;
    }());
    TabComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-tab',
                    template: "<div class=\"ec-tab\" *ngIf=\"selected\">\n  <ng-content></ng-content>\n</div>"
                },] }
    ];
    TabComponent.ctorParameters = function () { return [
        { type: core.ElementRef }
    ]; };
    TabComponent.propDecorators = {
        label: [{ type: core.Input }],
        selected: [{ type: core.Input }],
        route: [{ type: core.Input }],
        activated: [{ type: core.Output }],
        deactivated: [{ type: core.Output }]
    };

    /** The TabsComponent holds serveral instances of TabComponent.
     * <example-url>https://components.entrecode.de/ui/tabs?e=1</example-url>
     */
    var TabsComponent = /** @class */ (function () {
        function TabsComponent(router$1, route) {
            var _this = this;
            this.router = router$1;
            this.route = route;
            this.router.events.subscribe(function (event) {
                if (event instanceof router.NavigationEnd) {
                    _this.selectByUrl(event.url);
                }
            });
        }
        /** Selects the tab associated with the route present in the given url */
        TabsComponent.prototype.selectByUrl = function (url) {
            if (!url || !this.tabs) {
                return;
            }
            var paths = new URL(url, window.location.origin).pathname.split('/');
            var match = this.tabs.find(function (tab) { return paths[paths.length - 1].indexOf(tab.route) !== -1; });
            if (match) {
                this.select(match, true);
            }
        };
        TabsComponent.prototype.initTabs = function () {
            var _this = this;
            this.tabs.forEach(function (tab) {
                tab.parent = _this;
                if (tab.el.nativeElement.getAttribute('selected') !== null) {
                    _this.select(tab);
                }
            });
            this.selectByUrl(this.router.url);
        };
        TabsComponent.prototype.ngAfterContentInit = function () {
            this.initTabs();
        };
        /** Selects the given tab (Component). */
        TabsComponent.prototype.select = function (tab, skipRoute) {
            if (skipRoute === void 0) { skipRoute = false; }
            if (this.selected) {
                this.selected.deactivate();
            }
            this.selected = tab;
            tab.activate();
            if (tab.route && !skipRoute) {
                this.router.navigate(['../' + tab.route], { relativeTo: this.route });
            }
        };
        return TabsComponent;
    }());
    TabsComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-tabs',
                    template: "<div class=\"ec-tabs\">\n  <div class=\"ec-tabs-nav\">\n    <div *ngFor=\"let tab of tabs; let i = index\" class=\"ec-tabs-nav__item\">\n      <a (click)=\"select(tab)\" class=\"ec-tabs-nav__link\" [class.is-active]=\"tab.selected\">{{ tab.label }}</a>\n    </div>\n  </div>\n  <ng-content select=\"ec-tab\" #tab></ng-content>\n</div>\n"
                },] }
    ];
    TabsComponent.ctorParameters = function () { return [
        { type: router.Router },
        { type: router.ActivatedRoute }
    ]; };
    TabsComponent.propDecorators = {
        tabs: [{ type: core.ContentChildren, args: [TabComponent,] }],
        selected: [{ type: core.Input }]
    };

    var de = [
        {
            name: 'symbol.language',
            content: 'Deutsch',
        },
        {
            name: 'moment.locale',
            content: 'de',
        },
        {
            name: 'moment.format.date',
            content: 'DD.MM.YY',
        },
        {
            name: 'moment.format.month',
            content: 'MMMM YYYY',
        },
        {
            name: 'moment.format.time',
            content: 'HH:mm',
        },
        {
            name: 'datetime.local',
            content: '(Lokalzeit)',
        },
        {
            name: 'success.save',
            content: 'Speichern erfolgreich',
        },
        {
            name: 'success.delete',
            content: 'Löschen erfolgreich',
        },
        {
            name: 'error.delete',
            content: 'Fehler beim Löschen',
        },
        {
            name: 'error.save',
            content: 'Fehler beim Speichern',
        },
        {
            name: 'error.load',
            content: 'Fehler beim Laden',
        },
        {
            name: 'success.upload',
            content: 'Upload erfolgreich',
        },
        {
            name: 'error.upload',
            content: 'Fehler beim Hochladen',
        },
        {
            name: 'error.input.emailUnavailable',
            content: 'Diese Email ist schon vergeben',
        },
        {
            name: 'error.input.required',
            content: 'Dieses Feld ist ein Pflichtfeld',
        },
        {
            name: 'error.input.pattern',
            content: 'Ungültige Eingabe',
        },
        {
            name: 'error.input.minlength',
            content: 'Die Eingabe ist kurz',
        },
        {
            name: 'error.input.invalid',
            content: 'Ungültige Eingabe',
        },
        {
            name: 'error.2460.account_not_found',
            content: 'Der Login war ungültig',
        },
        {
            name: 'error.1404',
            content: 'Der Login war ungültig',
        },
        {
            name: 'error.2213',
            content: 'Falsches Dateiformat',
        },
        {
            name: 'error.2211',
            content: 'Validierungsfehler',
        },
        {
            name: 'error.2375',
            content: 'Die Datei existiert bereits. Duplikate werden ignoriert.',
        },
        {
            name: 'error.2353',
            content: 'Der eingegebene Name ist bereits vorhanden',
        },
        {
            name: 'login.email.label',
            content: 'E-Mail',
        },
        {
            name: 'login.email.placeholder',
            content: 'E-Mail Adresse',
        },
        {
            name: 'login.password.label',
            content: 'Passwort',
        },
        {
            name: 'login.password.placeholder',
            content: 'Passwort',
        },
        {
            name: 'login.button.label',
            content: 'Login',
        },
        {
            name: 'login.success',
            content: 'Erfolgreich eingeloggt',
        },
        {
            name: 'login.error',
            content: 'Fehler beim Login',
        },
        {
            name: 'signup.button.label',
            content: 'Signup',
        },
        {
            name: 'signup.invite.placeholder',
            content: 'Einladungs Code',
        },
        {
            name: 'signup.success',
            content: 'Die Registrierung war erfolgreich',
        },
        {
            name: 'signup.error',
            content: 'Die Registrierung ist fehlgeschlagen',
        },
        {
            name: 'passwordReset.button',
            content: 'Passwort zurücksetzen',
        },
        {
            name: 'resource.delete.question',
            content: 'Wirklich löschen?',
        },
        {
            name: 'resource.delete.safety',
            content: 'Gib zum Bestätigen das Sicherheitswort ein',
        },
        {
            name: 'resource.delete.yes',
            content: 'Ja',
        },
        {
            name: 'resource.delete.no',
            content: 'Nein',
        },
        {
            name: 'resource.delete.confirm',
            content: 'Löschen',
        },
        {
            name: 'resource.delete.cancel',
            content: 'Abbrechen',
        },
        {
            name: 'resource.edit',
            content: 'Bearbeiten:',
        },
        {
            name: 'resource.create',
            content: 'Erstellen:',
        },
        {
            name: 'resource.generic',
            content: 'Resource',
        },
        {
            name: 'resource.select.placeholder.new',
            content: 'Hinzufügen...',
        },
        {
            name: 'resource.select.placeholder.select',
            content: 'Auswählen...',
        },
        {
            name: 'pagination.first',
            content: '«',
        },
        {
            name: 'pagination.prev',
            content: '‹',
        },
        {
            name: 'pagination.next',
            content: '›',
        },
        {
            name: 'pagination.last',
            content: '»',
        },
        {
            name: 'pagination.of',
            content: 'von',
        },
        {
            name: 'searchbar.placeholder',
            content: 'Suchen..',
        },
        {
            name: 'pagination.size',
            content: 'Pro Seite',
        },
        {
            name: 'upload.assetGroup',
            content: 'Gruppe',
        },
        {
            name: 'upload.preserveFilenames',
            content: 'Dateinamen einkochen',
        },
        {
            name: 'upload.includeAssetIDInPath',
            content: 'AssetID in Pfad',
        },
        {
            name: 'upload.ignoreDuplicates',
            content: 'Duplikate ignorieren',
        },
        {
            name: 'upload.deduplicate',
            content: 'Deduplizieren',
        },
        {
            name: 'upload.dropToUpload',
            content: 'Loslassen zum Hochladen',
        },
        {
            name: 'upload.link',
            content: 'Hochladen',
        },
        {
            name: 'upload.or',
            content: 'oder',
        },
        {
            name: 'upload.browse',
            content: 'durchsuchen',
        },
        {
            name: 'upload.url',
            content: 'URL eingeben',
        },
        {
            name: 'upload.url.start',
            content: 'Upload',
        },
        {
            name: 'tag-select.placeholder',
            content: 'Tag suchen...',
        },
        {
            name: 'field.label.id',
            content: 'ID',
        },
        {
            name: 'field.label.created',
            content: 'Erstellt',
        },
        {
            name: 'field.label.modified',
            content: 'Stand',
        },
        {
            name: 'field.label.creator',
            content: 'Urheber',
        },
        {
            name: 'field.creator.ecuser',
            content: 'Admin',
        },
        {
            name: 'field.label.type',
            content: 'Typ',
        },
        {
            name: 'field.label.title',
            content: 'Titel',
        },
        {
            name: 'field.label.name',
            content: 'Name',
        },
        {
            name: 'field.label.label',
            content: 'Label',
        },
        {
            name: 'field.label.description',
            content: 'Beschreibung',
        },
        {
            name: 'field.label.config',
            content: 'Config',
        },
        {
            name: 'field.label.locales',
            content: 'Locales',
        },
        {
            name: 'field.label.email',
            content: 'Mail',
        },
        {
            name: 'field.label.password',
            content: 'Passwort',
        },
        {
            name: 'field.label.shortID',
            content: 'Short ID',
        },
        {
            name: 'datamanager.field.label.publicAssetRights',
            content: 'publicAssetRights',
        },
        {
            name: 'account.field.label.hasPendingEmail',
            content: 'Pending',
        },
        {
            name: 'account.field.label.language',
            content: 'Sprache',
        },
        {
            name: 'account.field.label.permissions',
            content: 'Permissions',
        },
        {
            name: 'account.field.label.groups',
            content: 'Gruppen',
        },
        {
            name: 'account.field.label.state',
            content: 'Status',
        },
        {
            name: 'dmAccount.field.label.hasPasswort',
            content: 'Passwort',
        },
        {
            name: 'dmAccount.field.label.pending',
            content: 'Pending',
        },
        {
            name: 'template.field.label.template',
            content: 'Template',
        },
        {
            name: 'template.field.label.version',
            content: 'Version',
        },
        {
            name: 'app.field.label.app',
            content: 'App',
        },
        {
            name: 'platform.field.label.platform',
            content: 'Platform',
        },
        {
            name: 'platform.field.label.platformType',
            content: 'Typ',
        },
        {
            name: 'asset.field.label.thumb',
            content: 'Vorschau',
        },
        {
            name: 'asset.field.label.files',
            content: 'Dateien',
        },
        {
            name: 'asset.field.label.tags',
            content: 'Tags',
        },
        {
            name: 'assetGroup.field.label.assetGroupID',
            content: 'assetGroupID',
        },
        {
            name: 'dmAsset.field.label.file',
            content: 'Vorschau',
        },
        {
            name: 'dmAsset.field.label.assetID',
            content: 'ID',
        },
        {
            name: 'dmAsset.field.label.caption',
            content: 'Caption',
        },
        {
            name: 'dmAsset.field.label.duplicates',
            content: 'Duplikate',
        },
        {
            name: 'dmAsset.field.label.thumbnails',
            content: 'Thumbnails',
        },
        {
            name: 'dmAsset.field.label.type',
            content: 'Typ',
        },
        {
            name: 'dmAsset.field.label.type.image',
            content: 'Bild',
        },
        {
            name: 'dmAsset.field.label.type.audio',
            content: 'Ton',
        },
        {
            name: 'dmAsset.field.label.type.video',
            content: 'Video',
        },
        {
            name: 'dmAsset.field.label.type.plain',
            content: 'Text',
        },
        {
            name: 'dmAsset.field.label.type.document',
            content: 'Dokument',
        },
        {
            name: 'dmAsset.field.label.type.spreadsheet',
            content: 'Tabelle',
        },
        {
            name: 'dmAsset.field.label.type.other',
            content: 'Andere',
        },
        {
            name: 'dmAsset.field.label.tags',
            content: 'Tags',
        },
        {
            name: 'client.field.label.clientID',
            content: 'ID',
        },
        {
            name: 'client.field.label.callbackURL',
            content: 'Callback URL',
        },
        {
            name: 'client.field.label.tokenMethod',
            content: 'Token Methode',
        },
        {
            name: 'client.field.label.disableStrategies',
            content: 'disableStrategies',
        },
        {
            name: 'role.field.label.accounts',
            content: 'Accounts',
        },
        {
            name: 'role.field.label.addRegistered',
            content: 'addRegistered',
        },
        {
            name: 'role.field.label.addUnregistered',
            content: 'addUnregistered',
        },
        {
            name: 'entries.load.error',
            content: 'Die Entries konnten nicht geladen werden',
        },
        {
            name: 'entry.load.error',
            content: 'Der Entry konnte nicht geladen werden',
        },
        {
            name: 'entry.select.delete.question',
            content: 'Soll der Entry auch gelöscht werden?',
        },
        {
            name: 'entry.select.placeholder.new',
            content: 'Hinzufügen...',
        },
        {
            name: 'entry.select.placeholder.select',
            content: 'Auswählen...',
        },
        {
            name: 'entry.select.placeholder.model',
            content: 'Model wählen...',
        },
        {
            name: 'entry.select.remove',
            content: 'Entfernen',
        },
        {
            name: 'entry.generic',
            content: 'Entry',
        },
        {
            name: 'list.empty',
            content: 'Noch keine Einträge..',
        },
        {
            name: 'list.loading',
            content: 'Lade Liste..',
        },
        {
            name: 'list.filter.noResults',
            content: 'Keine Einträge gefunden',
        },
        {
            name: 'list.filter.reset',
            content: 'Filter aufheben',
        },
        {
            name: 'image-select-pop.header',
            content: 'Bild hinzufügen',
        },
        {
            name: 'image-select-pop.submitButtonLabel',
            content: 'Hinzufügen',
        },
        {
            name: 'image-select-pop.alt',
            content: 'Alternativ Text',
        },
        {
            name: 'image-select-pop.keepRatio',
            content: 'Seitenverhältnis beibehalten',
        },
        {
            name: 'image-select-pop.width',
            content: 'Breite',
        },
        {
            name: 'image-select-pop.height',
            content: 'Höhe',
        },
    ];

    var en = [
        {
            name: 'symbol.language',
            content: 'English',
        },
        {
            name: 'moment.locale',
            content: 'en',
        },
        {
            name: 'moment.format.date',
            content: 'DD.MM.YYYY',
        },
        {
            name: 'moment.format.month',
            content: 'MMMM YYYY',
        },
        {
            name: 'moment.format.time',
            content: 'HH:mm',
        },
        {
            name: 'datetime.local',
            content: '(local time)',
        },
        {
            name: 'success.save',
            content: 'Saved successfully',
        },
        {
            name: 'success.delete',
            content: 'Deleted successfully',
        },
        {
            name: 'error.delete',
            content: 'Error while deleting',
        },
        {
            name: 'error.save',
            content: 'Error while saving',
        },
        {
            name: 'error.load',
            content: 'Error while loading',
        },
        {
            name: 'success.upload',
            content: 'Upload successful',
        },
        {
            name: 'error.upload',
            content: 'Error while uploading',
        },
        {
            name: 'error.input.emailUnavailable',
            content: 'This Email is already in use',
        },
        {
            name: 'error.input.required',
            content: 'Field is required',
        },
        {
            name: 'error.input.pattern',
            content: 'Invalid Input',
        },
        {
            name: 'error.input.minlength',
            content: 'Input is too short',
        },
        {
            name: 'error.input.invalid',
            content: 'Invalid Input',
        },
        {
            name: 'error.2460.account_not_found',
            content: 'Invalid Login Data',
        },
        {
            name: 'error.1404',
            content: 'Invalid Login Data',
        },
        {
            name: 'error.2213',
            content: 'Wrong File Format',
        },
        {
            name: 'error.2211',
            content: 'Validation Error',
        },
        {
            name: 'error.2375',
            content: 'The File already exists. Duplicates are ignored.',
        },
        {
            name: 'error.2353',
            content: 'The entered name is already in use',
        },
        {
            name: 'login.email.label',
            content: 'Mail',
        },
        {
            name: 'login.email.placeholder',
            content: 'Mail Address',
        },
        {
            name: 'login.password.label',
            content: 'Password',
        },
        {
            name: 'login.password.placeholder',
            content: 'Password',
        },
        {
            name: 'login.button.label',
            content: 'Login',
        },
        {
            name: 'login.success',
            content: 'Login was successful',
        },
        {
            name: 'login.error',
            content: 'Could not login',
        },
        {
            name: 'signup.button.label',
            content: 'Signup',
        },
        {
            name: 'signup.invite.placeholder',
            content: 'Invite Code',
        },
        {
            name: 'signup.success',
            content: 'Registration was successful',
        },
        {
            name: 'signup.error',
            content: 'Registration failed',
        },
        {
            name: 'passwordReset.button',
            content: 'Reset Password',
        },
        {
            name: 'resource.delete.question',
            content: 'Really Delete?',
        },
        {
            name: 'resource.delete.safety',
            content: 'To confirm deletion, enter the safety word',
        },
        {
            name: 'resource.delete.yes',
            content: 'Yes',
        },
        {
            name: 'resource.delete.no',
            content: 'No',
        },
        {
            name: 'resource.delete.confirm',
            content: 'Delete',
        },
        {
            name: 'resource.delete.cancel',
            content: 'Cancel',
        },
        {
            name: 'resource.edit',
            content: 'Edit',
        },
        {
            name: 'resource.create',
            content: 'Create',
        },
        {
            name: 'resource.generic',
            content: 'Resource',
        },
        {
            name: 'pagination.first',
            content: '«',
        },
        {
            name: 'pagination.prev',
            content: '‹',
        },
        {
            name: 'pagination.next',
            content: '›',
        },
        {
            name: 'pagination.last',
            content: '»',
        },
        {
            name: 'pagination.of',
            content: 'of',
        },
        {
            name: 'pagination.size',
            content: 'per page',
        },
        {
            name: 'searchbar.placeholder',
            content: 'Search..',
        },
        {
            name: 'upload.assetGroup',
            content: 'Group',
        },
        {
            name: 'upload.preserveFilenames',
            content: 'Preserve Filenames',
        },
        {
            name: 'upload.includeAssetIDInPath',
            content: 'Include AssetID in Path',
        },
        {
            name: 'upload.ignoreDuplicates',
            content: 'Ignore Duplicates',
        },
        {
            name: 'upload.deduplicate',
            content: 'Deduplicate',
        },
        {
            name: 'upload.dropToUpload',
            content: 'drop to upload',
        },
        {
            name: 'upload.link',
            content: 'upload',
        },
        {
            name: 'upload.or',
            content: 'or',
        },
        {
            name: 'upload.browse',
            content: 'browse',
        },
        {
            name: 'upload.url',
            content: 'enter URL',
        },
        {
            name: 'upload.url.start',
            content: 'upload',
        },
        {
            name: 'tag-select.placeholder',
            content: 'Search Tag...',
        },
        {
            name: 'field.label.id',
            content: 'ID',
        },
        {
            name: 'field.label.created',
            content: 'Created',
        },
        {
            name: 'field.label.modified',
            content: 'Modified',
        },
        {
            name: 'field.label.creator',
            content: 'Creator',
        },
        {
            name: 'field.creator.ecuser',
            content: 'Admin',
        },
        {
            name: 'field.label.type',
            content: 'Type',
        },
        {
            name: 'field.label.title',
            content: 'Title',
        },
        {
            name: 'field.label.name',
            content: 'Name',
        },
        {
            name: 'field.label.label',
            content: 'Label',
        },
        {
            name: 'field.label.description',
            content: 'Description',
        },
        {
            name: 'field.label.config',
            content: 'Config',
        },
        {
            name: 'field.label.locales',
            content: 'Locales',
        },
        {
            name: 'field.label.email',
            content: 'Mail',
        },
        {
            name: 'field.label.password',
            content: 'Password',
        },
        {
            name: 'field.label.shortID',
            content: 'Short ID',
        },
        {
            name: 'datamanager.field.label.publicAssetRights',
            content: 'publicAssetRights',
        },
        {
            name: 'account.field.label.hasPendingEmail',
            content: 'Pending',
        },
        {
            name: 'account.field.label.language',
            content: 'Language',
        },
        {
            name: 'account.field.label.permissions',
            content: 'Permissions',
        },
        {
            name: 'account.field.label.groups',
            content: 'Groups',
        },
        {
            name: 'account.field.label.state',
            content: 'Status',
        },
        {
            name: 'dmAccount.field.label.hasPasswort',
            content: 'Password',
        },
        {
            name: 'dmAccount.field.label.pending',
            content: 'Pending',
        },
        {
            name: 'template.field.label.template',
            content: 'Template',
        },
        {
            name: 'template.field.label.version',
            content: 'Version',
        },
        {
            name: 'app.field.label.app',
            content: 'App',
        },
        {
            name: 'platform.field.label.platform',
            content: 'Platform',
        },
        {
            name: 'platform.field.label.platformType',
            content: 'Type',
        },
        {
            name: 'asset.field.label.thumb',
            content: 'Preview',
        },
        {
            name: 'asset.field.label.files',
            content: 'Files',
        },
        {
            name: 'asset.field.label.tags',
            content: 'Tags',
        },
        {
            name: 'assetGroup.field.label.assetGroupID',
            content: 'assetGroupID',
        },
        {
            name: 'dmAsset.field.label.file',
            content: 'Preview',
        },
        {
            name: 'dmAsset.field.label.assetID',
            content: 'ID',
        },
        {
            name: 'dmAsset.field.label.caption',
            content: 'Caption',
        },
        {
            name: 'dmAsset.field.label.duplicates',
            content: 'Duplicates',
        },
        {
            name: 'dmAsset.field.label.thumbnails',
            content: 'Thumbnails',
        },
        {
            name: 'dmAsset.field.label.type',
            content: 'Type',
        },
        {
            name: 'dmAsset.field.label.type.image',
            content: 'Image',
        },
        {
            name: 'dmAsset.field.label.type.audio',
            content: 'Audio',
        },
        {
            name: 'dmAsset.field.label.type.video',
            content: 'Video',
        },
        {
            name: 'dmAsset.field.label.type.plain',
            content: 'Text',
        },
        {
            name: 'dmAsset.field.label.type.document',
            content: 'Document',
        },
        {
            name: 'dmAsset.field.label.type.spreadsheet',
            content: 'Spreadsheet',
        },
        {
            name: 'dmAsset.field.label.type.other',
            content: 'Other',
        },
        {
            name: 'dmAsset.field.label.tags',
            content: 'Tags',
        },
        {
            name: 'client.field.label.clientID',
            content: 'ID',
        },
        {
            name: 'client.field.label.callbackURL',
            content: 'Callback URL',
        },
        {
            name: 'client.field.label.tokenMethod',
            content: 'Token Method',
        },
        {
            name: 'client.field.label.disableStrategies',
            content: 'disableStrategies',
        },
        {
            name: 'role.field.label.accounts',
            content: 'Accounts',
        },
        {
            name: 'role.field.label.addRegistered',
            content: 'addRegistered',
        },
        {
            name: 'role.field.label.addUnregistered',
            content: 'addUnregistered',
        },
        {
            name: 'entries.load.error',
            content: 'Entries could not be loaded',
        },
        {
            name: 'entry.load.error',
            content: 'The entry could not be loaded',
        },
        {
            name: 'entry.select.delete.question',
            content: 'Should the entry also be deleted?',
        },
        {
            name: 'entry.select.placeholder.new',
            content: 'add new...',
        },
        {
            name: 'entry.select.placeholder.select',
            content: 'select...',
        },
        {
            name: 'entry.select.placeholder.model',
            content: 'select model...',
        },
        {
            name: 'entry.select.remove',
            content: 'Remove',
        },
        {
            name: 'entry.generic',
            content: 'Entry',
        },
        {
            name: 'list.empty',
            content: 'No Item yet..',
        },
        {
            name: 'list.loading',
            content: 'Loading List..',
        },
        {
            name: 'list.filter.noResults',
            content: 'No Items found',
        },
        {
            name: 'list.filter.reset',
            content: 'Clear filter',
        },
        {
            name: 'image-select-pop.header',
            content: 'Add Image',
        },
        {
            name: 'image-select-pop.submitButtonLabel',
            content: 'Add',
        },
        {
            name: 'image-select-pop.alt',
            content: 'Alternative Text',
        },
        {
            name: 'image-select-pop.keepRatio',
            content: 'Keep Ratio',
        },
        {
            name: 'image-select-pop.width',
            content: 'Width',
        },
        {
            name: 'image-select-pop.height',
            content: 'Height',
        },
    ];

    /** Service to register symbols for localization. The default set is de.
     * <example-url>https://components.entrecode.de/ui/symbols?e=1</example-url>
     */
    // https://github.com/ng-packagr/ng-packagr/issues/696
    var SymbolService = /** @class */ (function () {
        function SymbolService() {
            this.sets = {
                en: en,
                de: de,
            };
            this.registry = Object.keys(this.sets).length ? this.sets[Object.keys(this.sets)[0]] : [];
        }
        /** finds a symbol in the registry by name */
        SymbolService.get = function (name, registry) {
            if (registry === void 0) { registry = SymbolService.registry; }
            var symbol = registry.find(function (s) { return s.name === name; });
            return symbol;
        };
        SymbolService.resolve = function (name, registry) {
            if (registry === void 0) { registry = SymbolService.registry; }
            var symbol = SymbolService.get(name, registry);
            if (symbol) {
                return symbol.content;
            }
            return null;
        };
        /** Uses the given symbol set to enhance the current registry.
         * All duplicates will be overriden. Non specified symbols will stay in the registry. */
        SymbolService.set = function (symbols, registry) {
            var _this = this;
            if (symbols === void 0) { symbols = []; }
            if (registry === void 0) { registry = SymbolService.registry; }
            symbols.map(function (symbol) {
                var index = registry.indexOf(_this.get(symbol.name));
                if (index === -1) {
                    registry.push(symbol);
                }
                else {
                    registry[index] = symbol;
                }
            });
        };
        /** Uses the given symbol set. Replaces registry. */
        SymbolService.prototype.use = function (symbols) {
            this.registry = symbols;
        };
        /** uses the set with the given key */
        SymbolService.prototype.useSet = function (key) {
            if (!this.sets[key]) {
                throw new Error('the symbol set with the key "' + key + '" does not exist');
            }
            this.use(this.sets[key]);
        };
        /** finds a symbol in the registry by name */
        SymbolService.prototype.get = function (name) {
            return SymbolService.get(name, this.registry);
        };
        /** resolves a symbols content by name */
        SymbolService.prototype.resolve = function (name) {
            return SymbolService.resolve(name, this.registry);
        };
        /** Uses the given symbol set to enhance the current registry.
         * All duplicates will be overriden. Non specified symbols will stay in the registry. */
        SymbolService.prototype.set = function (symbols) {
            if (symbols === void 0) { symbols = []; }
            SymbolService.set(symbols, this.registry);
        };
        return SymbolService;
    }());
    /** The current symbol set that is registered to the service. It will be used to resolve strings from. */
    SymbolService.sets = {
        en: en,
        de: de,
    };
    SymbolService.registry = Object.keys(SymbolService.sets).length
        ? SymbolService.sets[Object.keys(SymbolService.sets)[0]]
        : [];
    SymbolService.decorators = [
        { type: core.Injectable }
    ];
    SymbolService.ctorParameters = function () { return []; };

    /** Validates an email. Used for email inputs */
    var emailValidator = forms.Validators.pattern(/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/);

    /** Groups together all validators that are meant to be used on fields. */
    var FieldValidators = {
        email: emailValidator,
    };

    /** Login Form Component with validation. Fires success event with credentials on submit.
     * <example-url>https://components.entrecode.de/ui/login?e=1</example-url>
     */
    var LoginFormComponent = /** @class */ (function () {
        /** Injects the FormBuilder*/
        function LoginFormComponent(fb, symbol) {
            this.fb = fb;
            this.symbol = symbol;
            /** Event that emits on succesful submit of the form, passing the login credentials. */
            this.success = new core.EventEmitter();
            /** Event that emits when calling showError. */
            this.error = new core.EventEmitter();
            /** If true, email and password wont have labels */
            this.showLabels = true;
            /** The Label of the Mail field */
            this.emailLabel = this.symbol.resolve('login.email.label');
            /** The Placeholder of the mail Field */
            this.emailPlaceholder = this.symbol.resolve('login.email.placeholder');
            /** The Label of the password field. */
            this.passwordLabel = this.symbol.resolve('login.password.label');
            /** The Placeholder of the password field */
            this.passwordPlaceholder = this.symbol.resolve('login.password.placeholder');
            /** The Label of the submit button. Defaults to Login */
            this.buttonLabel = this.symbol.resolve('login.button.label');
            /** Additional Button classes */
            this.buttonClasses = '';
        }
        /** Initializes the form */
        LoginFormComponent.prototype.ngOnInit = function () {
            this.form = this.fb.group({
                email: ['', [forms.Validators.required, FieldValidators.email]],
                password: ['', [forms.Validators.required]],
            });
        };
        /** Shows the given error in the form. Clears the password field and emits the error event. */
        LoginFormComponent.prototype.showError = function (err) {
            this.errorMessage = err.message;
            this.form.get('password').setValue('');
            this.error.emit(err);
            rxjs.throwError(err);
        };
        /** Method that is meant to be overwritten by a subclass to communicate with an API. */
        LoginFormComponent.prototype.login = function (value) {
            // meant to be overridden
            return Promise.resolve(value);
        };
        /** Is called when the form has been successfully submitted. Calls login and resets the form after. */
        LoginFormComponent.prototype.onSubmit = function () {
            var _this = this;
            this.submitted = true;
            delete this.errorMessage;
            if (!this.form.valid) {
                return;
            }
            var login = this.login(this.form.value).then(function (res) {
                _this.form.reset();
                _this.success.emit(res);
            });
            if (this.loader) {
                this.loader.wait(login);
            }
        };
        return LoginFormComponent;
    }());
    LoginFormComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-login-form',
                    template: "<form novalidate [formGroup]=\"form\" (ngSubmit)=\"onSubmit()\" class=\"ec-auth ec-auth_login\">\n  <p class=\"error\" *ngIf=\"errorMessage\">\n    {{ errorMessage }}\n  </p>\n  <div class=\"field-group ec-auth__email\">\n    <label *ngIf=\"showLabels\" for=\"ecAuthEmail\" class=\"field-group__label\">{{ emailLabel }}</label>\n    <input type=\"email\" id=\"ecAuthEmail\" formControlName=\"email\" class=\"input\" [placeholder]=\"emailPlaceholder\" />\n    <ec-input-errors [control]=\"form.get('email')\"></ec-input-errors>\n  </div>\n  <div class=\"field-group ec-auth__password\">\n    <label *ngIf=\"showLabels\" for=\"ecAuthPassword\" class=\"field-group__label\">Passwort</label>\n    <input type=\"password\" id=\"ecAuthPassword\" formControlName=\"password\" class=\"input\" [placeholder]=\"passwordPlaceholder\" />\n    <ec-input-errors [control]=\"form.get('password')\"></ec-input-errors>\n  </div>\n  <button\n    type=\"submit\"\n    [disabled]=\"form.invalid\"\n    [class.is-disabled]=\"form.invalid\"\n    class=\"btn ec-auth__btn\"\n    [ngClass]=\"buttonClasses\"\n  >\n    {{ buttonLabel }}\n  </button>\n</form>\n"
                },] }
    ];
    LoginFormComponent.ctorParameters = function () { return [
        { type: forms.FormBuilder },
        { type: SymbolService }
    ]; };
    LoginFormComponent.propDecorators = {
        success: [{ type: core.Output }],
        error: [{ type: core.Output }],
        loader: [{ type: core.Input }],
        showLabels: [{ type: core.Input }],
        emailLabel: [{ type: core.Input }],
        emailPlaceholder: [{ type: core.Input }],
        passwordLabel: [{ type: core.Input }],
        passwordPlaceholder: [{ type: core.Input }],
        buttonLabel: [{ type: core.Input }],
        buttonClasses: [{ type: core.Input }]
    };

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */
    /* global Reflect, Promise */
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b)
                if (Object.prototype.hasOwnProperty.call(b, p))
                    d[p] = b[p]; };
        return extendStatics(d, b);
    };
    function __extends(d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }
    var __assign = function () {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p))
                        t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };
    function __rest(s, e) {
        var t = {};
        for (var p in s)
            if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    }
    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
            r = Reflect.decorate(decorators, target, key, desc);
        else
            for (var i = decorators.length - 1; i >= 0; i--)
                if (d = decorators[i])
                    r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }
    function __param(paramIndex, decorator) {
        return function (target, key) { decorator(target, key, paramIndex); };
    }
    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
            return Reflect.metadata(metadataKey, metadataValue);
    }
    function __awaiter(thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try {
                step(generator.next(value));
            }
            catch (e) {
                reject(e);
            } }
            function rejected(value) { try {
                step(generator["throw"](value));
            }
            catch (e) {
                reject(e);
            } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    }
    function __generator(thisArg, body) {
        var _ = { label: 0, sent: function () { if (t[0] & 1)
                throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function () { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f)
                throw new TypeError("Generator is already executing.");
            while (_)
                try {
                    if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
                        return t;
                    if (y = 0, t)
                        op = [op[0] & 2, t.value];
                    switch (op[0]) {
                        case 0:
                        case 1:
                            t = op;
                            break;
                        case 4:
                            _.label++;
                            return { value: op[1], done: false };
                        case 5:
                            _.label++;
                            y = op[1];
                            op = [0];
                            continue;
                        case 7:
                            op = _.ops.pop();
                            _.trys.pop();
                            continue;
                        default:
                            if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                                _ = 0;
                                continue;
                            }
                            if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) {
                                _.label = op[1];
                                break;
                            }
                            if (op[0] === 6 && _.label < t[1]) {
                                _.label = t[1];
                                t = op;
                                break;
                            }
                            if (t && _.label < t[2]) {
                                _.label = t[2];
                                _.ops.push(op);
                                break;
                            }
                            if (t[2])
                                _.ops.pop();
                            _.trys.pop();
                            continue;
                    }
                    op = body.call(thisArg, _);
                }
                catch (e) {
                    op = [6, e];
                    y = 0;
                }
                finally {
                    f = t = 0;
                }
            if (op[0] & 5)
                throw op[1];
            return { value: op[0] ? op[1] : void 0, done: true };
        }
    }
    var __createBinding = Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        Object.defineProperty(o, k2, { enumerable: true, get: function () { return m[k]; } });
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    });
    function __exportStar(m, o) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p))
                __createBinding(o, m, p);
    }
    function __values(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m)
            return m.call(o);
        if (o && typeof o.length === "number")
            return {
                next: function () {
                    if (o && i >= o.length)
                        o = void 0;
                    return { value: o && o[i++], done: !o };
                }
            };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    }
    function __read(o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m)
            return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
                ar.push(r.value);
        }
        catch (error) {
            e = { error: error };
        }
        finally {
            try {
                if (r && !r.done && (m = i["return"]))
                    m.call(i);
            }
            finally {
                if (e)
                    throw e.error;
            }
        }
        return ar;
    }
    /** @deprecated */
    function __spread() {
        for (var ar = [], i = 0; i < arguments.length; i++)
            ar = ar.concat(__read(arguments[i]));
        return ar;
    }
    /** @deprecated */
    function __spreadArrays() {
        for (var s = 0, i = 0, il = arguments.length; i < il; i++)
            s += arguments[i].length;
        for (var r = Array(s), k = 0, i = 0; i < il; i++)
            for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
                r[k] = a[j];
        return r;
    }
    function __spreadArray(to, from, pack) {
        if (pack || arguments.length === 2)
            for (var i = 0, l = from.length, ar; i < l; i++) {
                if (ar || !(i in from)) {
                    if (!ar)
                        ar = Array.prototype.slice.call(from, 0, i);
                    ar[i] = from[i];
                }
            }
        return to.concat(ar || from);
    }
    function __await(v) {
        return this instanceof __await ? (this.v = v, this) : new __await(v);
    }
    function __asyncGenerator(thisArg, _arguments, generator) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var g = generator.apply(thisArg, _arguments || []), i, q = [];
        return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
        function verb(n) { if (g[n])
            i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
        function resume(n, v) { try {
            step(g[n](v));
        }
        catch (e) {
            settle(q[0][3], e);
        } }
        function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
        function fulfill(value) { resume("next", value); }
        function reject(value) { resume("throw", value); }
        function settle(f, v) { if (f(v), q.shift(), q.length)
            resume(q[0][0], q[0][1]); }
    }
    function __asyncDelegator(o) {
        var i, p;
        return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
        function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
    }
    function __asyncValues(o) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var m = o[Symbol.asyncIterator], i;
        return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
        function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
        function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
    }
    function __makeTemplateObject(cooked, raw) {
        if (Object.defineProperty) {
            Object.defineProperty(cooked, "raw", { value: raw });
        }
        else {
            cooked.raw = raw;
        }
        return cooked;
    }
    ;
    var __setModuleDefault = Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    };
    function __importStar(mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    }
    function __importDefault(mod) {
        return (mod && mod.__esModule) ? mod : { default: mod };
    }
    function __classPrivateFieldGet(receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    }
    function __classPrivateFieldSet(receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    }

    /** Login Form Component with validation. Fires success event with credentials on submit.
     * <example-url>https://components.entrecode.de/ui/login?e=1</example-url>
     */
    var SignupFormComponent = /** @class */ (function (_super) {
        __extends(SignupFormComponent, _super);
        function SignupFormComponent() {
            var _this = _super.apply(this, __spread(arguments)) || this;
            /** The Label of the submit button. Defaults to Login */
            _this.buttonLabel = _this.symbol.resolve('signup.button.label');
            /** The Placeholder of the mail Field */
            _this.invitePlaceholder = _this.symbol.resolve('signup.invite.placeholder');
            /** If set, the invite field will be hidden and the given code will be used for signup */
            _this.invite = '';
            return _this;
        }
        /** Method that is meant to be overwritten by a subclass to communicate with an API. */
        SignupFormComponent.prototype.signup = function (value) {
            // meant to be overridden
            return Promise.resolve(value);
        };
        /** Initializes the form */
        SignupFormComponent.prototype.ngOnInit = function () {
            this.form = this.fb.group({
                email: ['', [forms.Validators.required, FieldValidators.email]],
                password: ['', [forms.Validators.required]],
                invite: [this.invite, [forms.Validators.required]],
            });
        };
        /** Is called when the form has been successfully submitted. Calls login and resets the form after. */
        SignupFormComponent.prototype.onSubmit = function () {
            var _this = this;
            this.submitted = true;
            delete this.errorMessage;
            if (!this.form.valid) {
                return;
            }
            var login = this.signup(this.form.value).then(function (res) {
                // this.form.reset();
                _this.success.emit(res);
            });
            if (this.loader) {
                this.loader.wait(login);
            }
        };
        return SignupFormComponent;
    }(LoginFormComponent));
    SignupFormComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-signup-form',
                    template: "<form novalidate [formGroup]=\"form\" (ngSubmit)=\"onSubmit()\" class=\"ec-auth ec-auth_signup\">\n  <p class=\"error\" *ngIf=\"errorMessage\">\n    {{errorMessage}}\n  </p>\n  <div class=\"field-group ec-auth__email\">\n    <label class=\"field-group__label\" for=\"ecAuthEmail\" *ngIf=\"showLabels\">{{emailLabel}}</label>\n    <input type=\"email\" formControlName=\"email\" id=\"ecAuthEmail\" class=\"input\" [placeholder]=\"emailPlaceholder\">\n    <ec-input-errors [control]=\"form?.get('email')\"></ec-input-errors>\n  </div>\n  <div class=\"field-group ec-auth__password\">\n    <label class=\"field-group__label\" for=\"ecAuthPassword\" *ngIf=\"showLabels\">Passwort</label>\n    <input type=\"password\" formControlName=\"password\" id=\"ecAuthPassword\" class=\"input\" [placeholder]=\"passwordPlaceholder\">\n    <ec-input-errors [control]=\"form?.get('password')\"></ec-input-errors>\n  </div>\n  <div class=\"field-group ec-auth__invite\" *ngIf=\"!invite\">\n    <label class=\"field-group__label\" for=\"ecAuthInvite\" *ngIf=\"showLabels\">Invite</label>\n    <input type=\"text\" formControlName=\"invite\" id=\"ecAuthInvite\" class=\"input\" [placeholder]=\"invitePlaceholder\">\n    <ec-input-errors [control]=\"form?.get('invite')\"></ec-input-errors>\n  </div>\n\n  <button type=\"submit\" [disabled]=\"form?.invalid\" [class.is-disabled]=\"form?.invalid\" class=\"btn ec-auth__btn\" [ngClass]=\"buttonClasses\">\n    {{buttonLabel}}\n  </button>\n</form>"
                },] }
    ];
    SignupFormComponent.propDecorators = {
        buttonLabel: [{ type: core.Input }],
        invitePlaceholder: [{ type: core.Input }],
        invite: [{ type: core.Input }]
    };

    var FocusDirective = /** @class */ (function () {
        function FocusDirective(element) {
            this.element = element;
        }
        FocusDirective.prototype.ngAfterViewInit = function () {
            if (this.autofocus) {
                this.ecFocus.emit(true);
            }
        };
        FocusDirective.prototype.ngOnInit = function () {
            var _this = this;
            this.ecFocus.subscribe(function (event) {
                if (event) {
                    _this.element.nativeElement.focus();
                }
                else {
                    _this.element.nativeElement.blur();
                }
            });
        };
        return FocusDirective;
    }());
    FocusDirective.decorators = [
        { type: core.Directive, args: [{
                    // tslint:disable-next-line:directive-selector
                    selector: '[ecFocus]',
                },] }
    ];
    FocusDirective.ctorParameters = function () { return [
        { type: core.ElementRef }
    ]; };
    FocusDirective.propDecorators = {
        ecFocus: [{ type: core.Input }],
        autofocus: [{ type: core.Input }]
    };

    /** A Notification is used inside NotificationService and NotificationComponent to display any information to the user.*/
    var Notification = /** @class */ (function () {
        /** The constructor just looks if an error is set, and if yes, sets the type to error. */
        function Notification(notification) {
            if (notification.error) {
                this.type = 'error';
            }
            Object.assign(this, notification);
        }
        return Notification;
    }());

    /** This service is the main interaction layer for the developer to show notifications.
     * You can use desktop notifications by default by providing:
     * ```json
     {
       provide: "useDesktopNotifications",
       useValue: true
     }```
     * in your module's providers.
     *
     * */
    var NotificationsService = /** @class */ (function () {
        /** The constructors injects the useDesktopNotifications flag from the module.
         * If true, all notifications will be shown as desktop notifications instead. */
        function NotificationsService(useDesktopNotifications) {
            this.useDesktopNotifications = useDesktopNotifications;
            /** The emitter subject to fire notifications. */
            this.emitter = new rxjs.Subject();
            /** Observable that is nexted when a new notification comes in. */
            this.emitter$ = this.emitter.asObservable();
            /** The default view time for a notification. */
            this.defaultTime = 5000;
        }
        /** Emits a notification to all ec-notification components. If host is set, it is only pushed to the specified host.*/
        NotificationsService.prototype.emit = function (notification, desktop) {
            var instance = new Notification(notification);
            if (desktop || this.useDesktopNotifications) {
                this.desktopNotification(instance);
            }
            else {
                this.emitter.next(instance);
            }
            if (notification && notification.error) {
                console.error(notification.error);
            }
            return instance;
        };
        /** Asks for permission to show desktop notifications, if not already granted. */
        NotificationsService.prototype.getPermission = function () {
            if (window.Notification.permission === 'granted') {
                return Promise.resolve();
            }
            return window.Notification.requestPermission().then(function (permission) {
                // If the user accepts, let's create a notification
                if (permission !== 'granted') {
                    return Promise.reject('Desktop Notification Permission Denied!');
                }
            });
        };
        /** Emits a desktop notification after asking for permission (if not already granted). */
        NotificationsService.prototype.desktopNotification = function (notification) {
            var _this = this;
            if (!('Notification' in window)) {
                console.warn('This browser does not support desktop notification');
            }
            this.getPermission().then(function () {
                var message = new window.Notification(notification.title, { body: notification.message });
                if (notification.sticky) {
                    if (notification.time) {
                        console.warn('notification.time is ignored because it was set sticky');
                    }
                    return;
                }
                setTimeout(function () { return message.close(); }, notification.time || _this.defaultTime);
            });
        };
        return NotificationsService;
    }());
    NotificationsService.decorators = [
        { type: core.Injectable }
    ];
    NotificationsService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: core.Inject, args: ['useDesktopNotifications',] }] }
    ]; };

    var KeycommandsService = /** @class */ (function () {
        function KeycommandsService(router, notificationsService) {
            var _this = this;
            this.router = router;
            this.notificationsService = notificationsService;
            this.keys = {};
            this.muted = false;
            this.meta = false;
            this.shift = false;
            window.addEventListener('keydown', function (e) {
                if (e.altKey && _this.keys[e.key]) {
                    e.preventDefault();
                    e.stopImmediatePropagation();
                    e.stopPropagation();
                }
            });
            window.addEventListener('keyup', function (e) {
                if ((!_this.muted || e.altKey) && _this.keys[e.key]) {
                    _this.activate(_this.keys[e.key], e);
                }
            });
            window.addEventListener('mousedown', function (e) {
                _this.meta = e.metaKey;
            });
            // prevents shortcuts to be fired when inputs are focused
            document.addEventListener('focus', function (e) {
                _this.mute(e);
            }, true);
            document.addEventListener('blur', function (e) {
                _this.unmute(e);
            }, true);
        }
        KeycommandsService.prototype.mute = function (e) {
            this.input = e.target;
            this.muted = true;
        };
        KeycommandsService.prototype.unmute = function (e) {
            delete this.input;
            this.muted = false;
        };
        KeycommandsService.prototype.register = function (keyconfig) {
            this.keys[keyconfig.key] = keyconfig;
            return this;
        };
        KeycommandsService.prototype.activate = function (keyconfig, e) {
            if (!keyconfig.canActivate(e)) {
                return;
            }
            keyconfig.action(e);
        };
        KeycommandsService.prototype.copyToClipBoard = function (value, label) {
            var el = document.createElement('textarea');
            el.value = value;
            document.body.appendChild(el);
            el.select();
            document.execCommand('copy');
            document.body.removeChild(el);
            this.notificationsService.emit({
                title: label + " has been copied to the clipboard",
                message: value,
                type: 'info',
            });
        };
        KeycommandsService.prototype.copyCellToClipboard = function (label) {
            var _this = this;
            if (label === void 0) { label = 'Cell'; }
            return function (item, property) {
                _this.copyToClipBoard(JSON.stringify(item.resolve(property) || ''), label);
            };
        };
        KeycommandsService.prototype.openUrl = function (url) {
            window.open(url, '_blank');
        };
        KeycommandsService.prototype.navigate = function (path, options) {
            if (options === void 0) { options = {}; }
            if (this.meta) {
                this.openUrl(this.router.serializeUrl(this.router.createUrlTree(path, options)));
            }
            else {
                this.router.navigate(path, options);
            }
        };
        return KeycommandsService;
    }());
    KeycommandsService.decorators = [
        { type: core.Injectable }
    ];
    KeycommandsService.ctorParameters = function () { return [
        { type: router.Router },
        { type: NotificationsService }
    ]; };

    /** The field host is a helper to load components inside its view container.
     * see https://angular.io/guide/dynamic-component-loader
     * */
    var SlotHostDirective = /** @class */ (function () {
        /** The constructor exposes the viewContainer that is used to load components into from outside.*/
        function SlotHostDirective(viewContainerRef) {
            this.viewContainerRef = viewContainerRef;
        }
        return SlotHostDirective;
    }());
    SlotHostDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[ecSlotHost]',
                },] }
    ];
    SlotHostDirective.ctorParameters = function () { return [
        { type: core.ViewContainerRef }
    ]; };

    /** This directive can be used to display a field. It is used inside ec-form as well as ec-list. */
    var DynamicSlotComponent = /** @class */ (function () {
        /** The constructor provides the instance of ViewContainerRef which is later used to create embedded views*/
        function DynamicSlotComponent(componentFactoryResolver) {
            this.componentFactoryResolver = componentFactoryResolver;
        }
        /** Loads the given component inside the fieldHost. Sets current item and field by default. */
        DynamicSlotComponent.prototype.loadComponent = function (component, attributes) {
            if (attributes === void 0) { attributes = {}; }
            var componentFactory = this.componentFactoryResolver.resolveComponentFactory(component);
            var viewContainerRef = this.fieldHost.viewContainerRef;
            viewContainerRef.clear();
            var componentRef = viewContainerRef.createComponent(componentFactory);
            Object.assign(componentRef.instance, attributes);
            return componentRef;
        };
        return DynamicSlotComponent;
    }());
    DynamicSlotComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-dynamic-slot',
                    template: "<ng-template ecSlotHost></ng-template>"
                },] }
    ];
    DynamicSlotComponent.ctorParameters = function () { return [
        { type: core.ComponentFactoryResolver }
    ]; };
    DynamicSlotComponent.propDecorators = {
        fieldHost: [{ type: core.ViewChild, args: [SlotHostDirective, { static: true },] }]
    };

    /** Holds the templates to output item field values. */
    var DefaultOutputComponent = /** @class */ (function () {
        function DefaultOutputComponent() {
        }
        return DefaultOutputComponent;
    }());
    DefaultOutputComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-default-output',
                    template: "<div [ngSwitch]=\"field.getView('output')\" *ngIf=\"item\">\n  <ul class=\"ec-output-tags\" *ngSwitchCase=\"'tags'\">\n    <li *ngFor=\"let label of item?.display(field.property) | maxItems: field.maxItems || 10\">\n      <span class=\"ec-output-tag tag\">{{ label }}</span>\n    </li>\n    <li *ngIf=\"item?.display(field.property)?.length > (field.maxItems || 10)\">\n      <span class=\"ec-output-tag tag\">&hellip;</span>\n    </li>\n  </ul>\n\n  <div class=\"ec-output-strings\" *ngSwitchCase=\"'strings'\">\n    <span *ngFor=\"let label of item?.display(field.property) | maxItems: field.maxItems || 10\">\n      {{ label }}\n    </span>\n    <span *ngIf=\"item?.display(field.property)?.length > (field.maxItems || 10)\">\n      &hellip;\n    </span>\n  </div>\n\n  <div class=\"ec-output-tag\" *ngSwitchCase=\"'tag'\">\n    <div class=\"span\" class=\"tag\" *ngIf=\"item?.display(field.property)\">{{ item?.display(field.property) }}</div>\n  </div>\n\n  <div *ngSwitchCase=\"'boolean'\" class=\"ec-output-boolean\" [class.is-true]=\"item?.resolve(field.property)\">\n    <span>&#10004;</span>\n  </div>\n\n  <div class=\"ec-output-mail\" *ngSwitchCase=\"'email'\">\n    <a [href]=\"'mailto:' + item?.display(field.property)\">{{ item?.display(field.property) }}</a>\n  </div>\n  <div class=\"ec-output-url\" *ngSwitchCase=\"'url'\">\n    <a [href]=\"item?.display(field.property)\">{{ item?.display(field.property) }}</a>\n  </div>\n\n  <div class=\"ec-output-color\" *ngSwitchCase=\"'color'\">\n    <span class=\"ec-output-color__sample\" [style.backgroundColor]=\"item?.display(field.property)\"></span>\n    <span class=\"ec-output-color__property\">{{ item?.display(field.property) }}</span>\n  </div>\n\n  <div class=\"ec-output-asset\" *ngSwitchCase=\"'image'\" [class.is-true]=\"item?.resolve(field.property)\">\n    <ec-icon name=\"image\"></ec-icon>\n  </div>\n\n  <div class=\"ec-output-assets\" *ngSwitchCase=\"'images'\" [class.is-true]=\"item?.resolve(field.property)\">\n    <ec-icon name=\"images\"></ec-icon>\n    <strong>{{ item?.resolve(field.property)?.length }}</strong>\n  </div>\n\n  <div class=\"ec-output-avatar avatar\" *ngSwitchCase=\"'avatar'\">\n    <img *ngIf=\"item?.display(field.property)\" [src]=\"item?.display(field.property)\" />\n  </div>\n\n  <div class=\"ec-output-avatars\" *ngSwitchCase=\"'avatars'\">\n    <div class=\"ec-output-avatar avatar\" *ngFor=\"let url of item?.display(field.property)\">\n      <img [src]=\"url\" />\n    </div>\n  </div>\n\n  <div class=\"ec-output-preview\" *ngSwitchCase=\"'preview'\">\n    <img [src]=\"item?.display(field.property)\" *ngIf=\"item?.display(field.property)\" />\n  </div>\n\n  <a *ngSwitchCase=\"'link'\" (click)=\"item?.action(field.property, $event)\" [ngClass]=\"field.class\">\n    <span>{{ item?.display(field.property) }}</span>\n    <ec-icon *ngIf=\"field.icon\" [name]=\"field.icon\"></ec-icon>\n  </a>\n\n  <div *ngSwitchCase=\"'textarea'\" class=\"ec-output-textarea\">\n    <span class=\"tag tag_small\">text</span>\n  </div>\n  <code *ngSwitchCase=\"'json'\" class=\"ec-output-json\">\n    <span class=\"tag\">JSON</span>\n  </code>\n  <span *ngSwitchDefault [class]=\"'ec-output-' + field.getView('output')\" [title]=\"item?.display(field.property)\">\n    {{ item?.display(field.property) }}\n  </span>\n</div>\n"
                },] }
    ];

    /** Outputs the given field of the given item, rendering the component dynamically. */
    var OutputComponent = /** @class */ (function (_super) {
        __extends(OutputComponent, _super);
        function OutputComponent() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        /** The component is loade as soon as the field and item are known.
         * If the field has no output property set, the DefaultOutputComponent will be rendered. */
        OutputComponent.prototype.ngOnChanges = function () {
            if (this.field && this.item) {
                this.loadComponent(this.component || this.field.output || DefaultOutputComponent, {
                    item: this.item,
                    field: this.field
                });
            }
        };
        return OutputComponent;
    }(DynamicSlotComponent));
    OutputComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-output',
                    template: "<ng-template ecSlotHost></ng-template>",
                    changeDetection: core.ChangeDetectionStrategy.OnPush
                },] }
    ];
    OutputComponent.propDecorators = {
        field: [{ type: core.Input }],
        item: [{ type: core.Input }],
        component: [{ type: core.Input }]
    };

    /** This service is the interface between Angular Forms and ec.components core classes. */
    var FormService = /** @class */ (function () {
        function FormService(symbol) {
            this.symbol = symbol;
        }
        /** Returns true if the field should be included in the form.
         * Decides based on field config values form, edit and create */
        FormService.prototype.shouldBePartOfForm = function (field, form) {
            if (field.create === false && !form.getBody()) {
                return false;
            }
            if (field.edit === false && !!form.getBody()) {
                return false;
            }
            return field.form !== false;
        };
        /** Initializes the form group from the form fields*/
        FormService.prototype.getGroup = function (form) {
            var _this = this;
            var controls = {};
            form.fields
                .filter(function (field) { return _this.shouldBePartOfForm(field, form); })
                .forEach(function (field) {
                var validators = _this.getValidators(field);
                var value = form.getValue(field.property);
                value = value === undefined ? null : value;
                controls[field.property] = new forms.FormControl({
                    value: value,
                    disabled: _this.isReadOnly(field, form),
                }, validators);
                // TODO use { updateOn: blur } when updating to angular 5.0.0
                // see https://github.com/angular/angular/commit/333a708bb632d4258ecb5fd4a0e86229fe9d26e4
            });
            return new forms.FormGroup(controls);
        };
        /** adds a new field to a form. handles form group and control */
        FormService.prototype.addField = function (field, form, group) {
            console.warn('addField is experimental!');
            var validators = this.getValidators(field);
            var control = new forms.FormControl({ value: form.getValue(field.property) }, validators);
            group.addControl(field.property, control);
        };
        /** Extracts all validators from a given Field instance. */
        FormService.prototype.getValidators = function (field) {
            var validators = [];
            if (field.required) {
                validators.push(forms.Validators.required);
            }
            if (field.validate) {
                validators.push(this.validateFactory(field));
            }
            return validators;
        };
        /** Returns a Validation function from the given field (using field.validate) */
        FormService.prototype.validateFactory = function (field) {
            return function (control) {
                if (!field.validate) {
                    return;
                }
                var error = field.validate(control.value, field);
                if (error) {
                    return {
                        custom: error,
                    };
                }
            };
        };
        /** Returns true if the field should be readOnly, depending on its config and the form state. */
        FormService.prototype.isReadOnly = function (field, form) {
            return field.disabled || (field.readOnly && form && !!form.getBody());
        };
        /** Returns label for given form (e.g. Edit label) */
        FormService.prototype.getFormLabel = function (form, label) {
            if (label === void 0) { label = this.symbol.resolve('resource.generic'); }
            if (!form || !form.form) {
                return '';
            }
            return this.symbol.resolve('resource.' + (form.form.isEditing() ? 'edit' : 'create')) + "\n    " + label + " " + (form.form.display() ? "\"" + form.form.display() + "\"" : '');
        };
        return FormService;
    }());
    FormService.decorators = [
        { type: core.Injectable }
    ];
    FormService.ctorParameters = function () { return [
        { type: SymbolService }
    ]; };

    /** This component holds the templates for all basic field types. */
    var DefaultInputComponent = /** @class */ (function () {
        /** Injects the services. */
        function DefaultInputComponent(formService, keycommands) {
            this.formService = formService;
            this.keycommands = keycommands;
            /** Emitter to focus the input field */
            this.focusEvent = new core.EventEmitter();
        }
        DefaultInputComponent.prototype.ngAfterViewInit = function () {
            if (this.field && this.field.autofocus) {
                this.focus();
            }
        };
        DefaultInputComponent.prototype.focus = function (focus) {
            var _this = this;
            if (focus === void 0) { focus = true; }
            setTimeout(function () {
                _this.focusEvent.emit(focus);
            }, 100);
        };
        return DefaultInputComponent;
    }());
    DefaultInputComponent.decorators = [
        { type: core.Component, args: [{
                    template: "<div [ngSwitch]=\"field.getView('input')\" *ngIf=\"group\" [formGroup]=\"group\" class=\"ec-input\">\n  <input\n    [id]=\"field.id\"\n    *ngSwitchCase=\"'string'\"\n    type=\"text\"\n    [formControl]=\"control\"\n    [placeholder]=\"field.getPlaceholder()\"\n    class=\"input\"\n    [ecFocus]=\"focusEvent\"\n  />\n  <textarea\n    [id]=\"field.id\"\n    *ngSwitchCase=\"'textarea'\"\n    type=\"text\"\n    [formControl]=\"control\"\n    [placeholder]=\"field.getPlaceholder()\"\n    class=\"input\"\n    [ecFocus]=\"focusEvent\"\n  ></textarea>\n\n  <input\n    [id]=\"field.id\"\n    *ngSwitchCase=\"'number'\"\n    type=\"number\"\n    [formControl]=\"control\"\n    [placeholder]=\"field.getPlaceholder()\"\n    class=\"input\"\n    [ecFocus]=\"focusEvent\"\n  />\n\n  <div class=\"ec-input-color\" *ngSwitchCase=\"'color'\">\n    <div class=\"ec-input-color__preview\" [style.backgroundColor]=\"control.value\">\n      <input [id]=\"field.id\" type=\"color\" [value]=\"group.value[field.property]\" [formControl]=\"control\" />\n    </div>\n    <input\n      type=\"text\"\n      [formControl]=\"control\"\n      [value]=\"group.value[field.property]\"\n      [placeholder]=\"field.getPlaceholder()\"\n      class=\"input\"\n    />\n  </div>\n\n  <label *ngSwitchCase=\"'boolean'\">\n    <input [id]=\"field.id\" type=\"checkbox\" [formControl]=\"control\" />\n    {{ field.getPlaceholder() }}\n  </label>\n\n  <input\n    [id]=\"field.id\"\n    *ngSwitchCase=\"'email'\"\n    type=\"email\"\n    [formControl]=\"control\"\n    [placeholder]=\"field.getPlaceholder()\"\n    class=\"input\"\n    [ecFocus]=\"focusEvent\"\n  />\n\n  <input\n    [id]=\"field.id\"\n    *ngSwitchCase=\"'url'\"\n    type=\"url\"\n    [formControl]=\"control\"\n    [placeholder]=\"field.getPlaceholder()\"\n    class=\"input\"\n    [ecFocus]=\"focusEvent\"\n  />\n\n  <ec-toggle [id]=\"field.id\" *ngSwitchCase=\"'toggle'\" [formControl]=\"control\" [placeholder]=\"field.getPlaceholder()\">\n  </ec-toggle>\n\n  <ec-datetime *ngSwitchCase=\"'date'\" [formControl]=\"control\" [placeholder]=\"field.getPlaceholder()\"></ec-datetime>\n\n  <ec-period *ngSwitchCase=\"'period'\" [formControl]=\"control\" [disableTime]=\"false\" [placeholder]=\"field.getPlaceholder()\"></ec-period>\n  <ec-period *ngSwitchCase=\"'period-date'\" [formControl]=\"control\" [disableTime]=\"true\" [placeholder]=\"field.getPlaceholder()\"></ec-period>\n\n  <ec-datetime\n    *ngSwitchCase=\"'date-only'\"\n    [formControl]=\"control\"\n    [placeholder]=\"field.getPlaceholder()\"\n    [disableTime]=\"true\"\n    [dateOnly]=\"true\"\n  ></ec-datetime>\n\n  <div *ngSwitchCase=\"'select'\">\n    <select\n      [id]=\"field.id\"\n      [formControl]=\"control\"\n      [ecFocus]=\"focusEvent\"\n      (change)=\"control.patchValue($event.target.value)\"\n      class=\"input\"\n      *ngIf=\"!formService.isReadOnly(field, item)\"\n    >\n      <option>{{ field.getPlaceholder() }}</option>\n      <option\n        *ngFor=\"let option of field.values\"\n        [selected]=\"control.value === (option.value ? option.value : option)\"\n        [value]=\"option.value ? option.value : option\"\n      >\n        {{ option.label ? option.label : option }}\n      </option>\n    </select>\n    <input type=\"text\" [formControl]=\"control\" [id]=\"field.id\" class=\"is-hidden-input\" />\n    {{ formService.isReadOnly(field, item) ? field.display() : '' }}\n  </div>\n\n  <div *ngSwitchCase=\"'copy'\">\n    <div\n      *ngIf=\"!!item?.display(field.property)\"\n      class=\"tag\"\n      style=\"cursor: pointer\"\n      (click)=\"keycommands.copyToClipBoard(item?.transform('copy', field.property), field.getLabel())\"\n      [attr.data-tooltip-bottom]=\"'click to copy ' + field.getLabel()\"\n    >\n      {{ item?.display(field.property) }}\n    </div>\n  </div>\n\n  <div *ngSwitchCase=\"'none'\">\n    <marquee>\uD83D\uDE82\uD83D\uDE83\uD83D\uDE83\uD83D\uDE83 {{ field?.type }} has no input yet. </marquee>\n  </div>\n\n  <div *ngSwitchDefault>\n    <ec-output [field]=\"field\" [item]=\"item\"></ec-output>\n  </div>\n  <ec-input-errors [control]=\"group.get(field.property)\"></ec-input-errors>\n</div>\n",
                    styles: [":host{flex:1}"]
                },] }
    ];
    DefaultInputComponent.ctorParameters = function () { return [
        { type: FormService },
        { type: KeycommandsService }
    ]; };

    /** This directive can be used to display a field. It is used inside ec-form as well as ec-list. */
    var InputComponent = /** @class */ (function (_super) {
        __extends(InputComponent, _super);
        function InputComponent() {
            var _this = _super.apply(this, __spread(arguments)) || this;
            /** The changed ouput emits whenever the form control of the input changes. */
            _this.changed = new core.EventEmitter();
            /** Emits when the component has been loaded */
            _this.ready = new core.EventEmitter();
            /** Debounce time in ms before the changed event emits. */
            _this.debounce = 0;
            /** Emitter to focus the input field */
            _this.focusEvent = new core.EventEmitter();
            _this.propagateChange = function (_) { };
            return _this;
        }
        InputComponent.prototype.ngOnChanges = function (changes) {
            if (!this.lazy || !this.componentInstance || changes.field) {
                this.init();
            }
        };
        InputComponent.prototype.focus = function (focus) {
            if (focus === void 0) { focus = true; }
            if (this.componentInstance && this.componentInstance.focusEvent) {
                this.componentInstance.focusEvent.emit(focus);
            }
            else {
                console.warn('could not focus component', this.componentInstance);
            }
        };
        InputComponent.prototype.init = function () {
            var _a;
            var _this = this;
            if (this.property && this.item instanceof core$1.Form) {
                this.field = this.item.getField(this.property);
            }
            else if (!this.field && this.config) {
                this.field = new core$1.Field(this.property || 'input', this.config);
            }
            if (!this.field) {
                return;
            }
            if (!this.control) {
                this.control = this.group ? this.group.get(this.field.property) : new forms.FormControl();
            }
            if (!this.group) {
                this.group = new forms.FormGroup((_a = {},
                    _a[this.property || this.field.property || 'input'] = this.control,
                    _a));
            }
            var data = {
                group: this.group,
                control: this.control || this.group ? this.group.get(this.field.property) : null,
                item: this.item,
                field: this.field,
                input: this,
                config: this.config || this.field.config || {},
                focusEvent: this.focusEvent,
            };
            var componentRef = this.loadComponent(this.component || this.field.input || DefaultInputComponent, data);
            this.componentInstance = componentRef.instance;
            this.connectControl();
            this.ready.emit(this);
            if (this.componentInstance.control) {
                this.componentInstance.control.valueChanges.pipe(operators.debounceTime(this.debounce)).subscribe(function (change) {
                    _this.changed.emit(change);
                    _this.propagateChange(change);
                });
            }
            if (this.field && typeof this.field.init === 'function') {
                this.field.init(this.componentInstance, this);
            }
        };
        InputComponent.prototype.connectControl = function () {
            if (!this.componentInstance) {
                // console.warn('could not connect control: no instance loaded');
                return;
            }
            this.componentInstance.disabled = this.disabled;
            if (this.componentInstance.registerOnChange && this.propagateChange) {
                this.componentInstance.registerOnChange(this.propagateChange);
            }
            if (this.value !== undefined) {
                this.writeValue(this.value);
            }
        };
        /** writes value to editor on outside model change. */
        InputComponent.prototype.writeValue = function (value) {
            if (this.componentInstance && this.componentInstance.writeValue) {
                this.componentInstance.writeValue(value);
            }
            this.value = value;
        };
        /** Registers change callback */
        InputComponent.prototype.registerOnChange = function (fn) {
            this.propagateChange = fn;
            this.connectControl();
        };
        InputComponent.prototype.registerOnTouched = function () { };
        InputComponent.prototype.setDisabledState = function (isDisabled) {
            this.disabled = isDisabled;
            if (this.componentInstance) {
                if (this.componentInstance.setDisabledState) {
                    this.componentInstance.setDisabledState(isDisabled);
                }
                else {
                    this.componentInstance.disabled = isDisabled;
                }
            }
        };
        return InputComponent;
    }(DynamicSlotComponent));
    InputComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-input',
                    template: "<ng-template ecSlotHost></ng-template>",
                    changeDetection: core.ChangeDetectionStrategy.OnPush,
                    providers: [
                        {
                            provide: forms.NG_VALUE_ACCESSOR,
                            useExisting: core.forwardRef(function () { return InputComponent; }),
                            multi: true,
                        },
                    ]
                },] }
    ];
    InputComponent.propDecorators = {
        group: [{ type: core.Input }],
        control: [{ type: core.Input }],
        changed: [{ type: core.Output }],
        ready: [{ type: core.Output }],
        debounce: [{ type: core.Input }],
        field: [{ type: core.Input }],
        property: [{ type: core.Input }],
        item: [{ type: core.Input }],
        config: [{ type: core.Input }],
        component: [{ type: core.Input }],
        lazy: [{ type: core.Input }]
    };

    /** This component keeps track of a form control's errors and displays them. It is meant to be used beneath a form control. */
    var InputErrorsComponent = /** @class */ (function () {
        /** Imported error messages. */
        function InputErrorsComponent(symbol) {
            this.symbol = symbol;
        }
        /** This method will iterate over the control errors and generate objects for the template. */
        InputErrorsComponent.prototype.getErrors = function () {
            var _this = this;
            return Object.keys(this.control.errors).reduce(function (errs, key) {
                var message;
                if (key === 'custom') {
                    message = _this.control.errors[key];
                }
                else {
                    message = _this.symbol.resolve('error.input.' + key) || _this.symbol.resolve('error.input.invalid');
                }
                errs.push({
                    key: key,
                    error: _this.control.errors[key],
                    message: message,
                });
                return errs;
            }, []);
        };
        return InputErrorsComponent;
    }());
    InputErrorsComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-input-errors',
                    template: "<ul *ngIf=\"control?.errors&&control.touched\" class=\"ec-input-errors\">\n  <li *ngFor=\"let error of getErrors()\" class=\"ec-input-error\">{{error.message}}</li>\n</ul>\n"
                },] }
    ];
    InputErrorsComponent.ctorParameters = function () { return [
        { type: SymbolService }
    ]; };
    InputErrorsComponent.propDecorators = {
        control: [{ type: core.Input }]
    };

    // import { CustomFieldComponent } from './custom-field.component';
    /** This directive can be used to display a field. It is used inside ec-form as well as ec-list. */
    var DynamicRackComponent = /** @class */ (function () {
        /** The constructor provides the instance of ViewContainerRef which is later used to create embedded views*/
        function DynamicRackComponent(componentFactoryResolver) {
            this.componentFactoryResolver = componentFactoryResolver;
        }
        return DynamicRackComponent;
    }());
    DynamicRackComponent.decorators = [
        { type: core.Component, args: [{
                    // selector: 'ec-dynamic-rack',
                    template: "<div>\n  <ul>\n    <!--<li *ngFor=\"let slot of slots\">-->\n    <!--</li>-->\n  </ul>\n</div>"
                },] }
    ];
    DynamicRackComponent.ctorParameters = function () { return [
        { type: core.ComponentFactoryResolver }
    ]; };

    var IoModule = /** @class */ (function () {
        function IoModule() {
        }
        return IoModule;
    }());
    IoModule.decorators = [
        { type: core.NgModule, args: [{
                    entryComponents: [InputComponent, OutputComponent, InputErrorsComponent],
                    declarations: [
                        InputErrorsComponent,
                        SlotHostDirective,
                        DynamicSlotComponent,
                        DynamicRackComponent,
                        InputComponent,
                        OutputComponent,
                    ],
                    imports: [common.CommonModule, forms.ReactiveFormsModule],
                    exports: [
                        SlotHostDirective,
                        DynamicSlotComponent,
                        DynamicRackComponent,
                        InputComponent,
                        OutputComponent,
                        InputErrorsComponent,
                        forms.ReactiveFormsModule,
                    ],
                    providers: [],
                },] }
    ];

    var UtilityModule = /** @class */ (function () {
        function UtilityModule() {
        }
        return UtilityModule;
    }());
    UtilityModule.decorators = [
        { type: core.NgModule, args: [{
                    entryComponents: [],
                    declarations: [TabsComponent, TabComponent, LoginFormComponent, SignupFormComponent, FocusDirective],
                    imports: [forms.FormsModule, forms.ReactiveFormsModule, IoModule, common.CommonModule, router.RouterModule],
                    exports: [
                        /* FormsModule,
                        ReactiveFormsModule,
                        IoModule,
                        */
                        TabsComponent,
                        TabComponent,
                        LoginFormComponent,
                        SignupFormComponent,
                        FocusDirective,
                        router.RouterModule,
                    ],
                    providers: [KeycommandsService],
                },] }
    ];

    function componentDestroyed(component) {
        var destroyed = new rxjs.Subject();
        var originalDestroy = component.ngOnDestroy;
        component.ngOnDestroy = function () {
            if (originalDestroy) {
                originalDestroy();
            }
            destroyed.next();
            destroyed.unsubscribe();
        };
        return destroyed;
    }

    /** Holds a stack of all open pops. listens for escape keydown events to close the latest opened pop. */
    var PopService = /** @class */ (function () {
        /** Listens for escape keys and hides latest pop + removes the pop from stack */
        function PopService() {
            var _this = this;
            /** default value for columns of any pop */
            this.defaultColumns = 9;
            /** Stack of current opened pops */
            this.stack = new core$1.Collection();
            window.addEventListener('keydown', function (event) {
                if ((event.keyCode === 27 || event.key === 'Escape') && _this.stack.items.length) {
                    var latestPop = _this.stack.items[_this.stack.items.length - 1];
                    latestPop.hide();
                    _this.stack.remove(latestPop);
                }
            });
        }
        return PopService;
    }());
    PopService.decorators = [
        { type: core.Injectable }
    ];
    PopService.ctorParameters = function () { return []; };

    /**
     * Created by felix on 26.05.17.
     */
    /** A Pop is an area of content whose visibility can be toggled.
     * It can be used e.g as dialog, drawer or dialog.
     * <example-url>https://components.entrecode.de/ui/pop?e=1</example-url>
     * */
    var PopComponent = /** @class */ (function () {
        function PopComponent(popService, elementRef, cdr) {
            this.popService = popService;
            this.elementRef = elementRef;
            this.cdr = cdr;
            /** Flip and stays true after first show */
            this.activated = false;
            /** If set to true, the pop will hide when a click happens outside the pop. */
            this.hideOnClickOutside = false;
            /** If set to false, esc will not close the pop */
            this.hideOnEscape = true;
            // tslint:disable-next-line:no-output-rename
            this._toggle = new core.EventEmitter();
        }
        /** Listens for document:click and hides */
        PopComponent.prototype.clickedOutside = function ($event) {
            if (this.hideOnClickOutside &&
                this.active &&
                (!this.clickEvent || $event !== this.clickEvent) && // to ensure the show event wont hide immediately
                this.elementRef &&
                this.isOutside($event.target)) {
                this.hide();
            }
        };
        /** yields true if the given element is outside the pop / or is the wrapper element itself (the backdrop) */
        PopComponent.prototype.isOutside = function (element) {
            return !this.elementRef.nativeElement.contains(element) /*  ||
              element === this.elementRef.nativeElement */;
        }; // active: boolean = !this.active, emit: boolean = false
        /** Shows if not active, hides if active. */ PopComponent.prototype.toggle = function (e) {
            if (this.active) {
                this.hide();
            }
            else {
                this.show(e);
            }
        };
        /** Shows the pop. Sets active true and adds pop to popService.stack */
        PopComponent.prototype.show = function (e) {
            this.active = true;
            this.activated = true;
            if (this.hideOnEscape) {
                this.popService.stack.add(this);
            }
            if (e) {
                this.clickEvent = e;
            }
            else if (this.hideOnClickOutside) {
                // console.warn('To use hideOnClickOutside, you need to pass the click event to the show method of ec-pop!');
            }
            this._toggle.emit(this.active);
            this.cdr.markForCheck();
        };
        /** Hides the pop. Sets active false and removes pop from popService.stack */
        PopComponent.prototype.hide = function () {
            if (this.hideOnEscape) {
                this.popService.stack.remove(this);
            }
            this.active = false;
            this._toggle.emit(this.active);
            this.cdr.markForCheck();
        };
        return PopComponent;
    }());
    PopComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-pop',
                    template: "<ng-content *ngIf=\"active\"></ng-content>",
                    changeDetection: core.ChangeDetectionStrategy.OnPush
                },] }
    ];
    PopComponent.ctorParameters = function () { return [
        { type: PopService },
        { type: core.ElementRef },
        { type: core.ChangeDetectorRef }
    ]; };
    PopComponent.propDecorators = {
        active: [{ type: core.Input }, { type: core.HostBinding, args: ['class.is-active',] }],
        type: [{ type: core.Input }],
        hideOnClickOutside: [{ type: core.Input }],
        hideOnEscape: [{ type: core.Input }],
        _toggle: [{ type: core.Output, args: ['toggle',] }],
        clickedOutside: [{ type: core.HostListener, args: ['document:click', ['$event'],] }]
    };

    /**
     * A modal is an extension of a pop. It adds different style options that apply x.ui markup.
     * <example-url>https://components.entrecode.de/ui/modal?e=1</example-url>
     *
     * https://medium.com/claritydesignsystem/ng-content-the-hidden-docs-96a29d70d11b
     */
    var ModalComponent = /** @class */ (function (_super) {
        __extends(ModalComponent, _super);
        /** Constructs the modal, injects pop service */
        function ModalComponent(popService, elementRef, cdr) {
            var _this = _super.call(this, popService, elementRef, cdr) || this;
            _this.popService = popService;
            _this.elementRef = elementRef;
            _this.cdr = cdr;
            /** all possible modes that can be set */
            _this.types = ['', 'overlay', 'deck', 'toast'];
            /** If true, the modal will have a dark backdrop that disables clicking outside. */
            _this.backdrop = false;
            return _this;
        }
        /** Is called on init and change. Parses mode input and throws warning if type is not supported. */
        ModalComponent.prototype.initMode = function () {
            var _this = this;
            this.elementRef.nativeElement.classList.add('modal-wrapper');
            this.mode = this.mode || '';
            this.type = this.mode.split(' ')[0];
            if (!this.types.includes(this.type)) {
                var fallback = this.mode.replace(this.type, '');
                console.warn("ec-modal does not support the mode \"" + this.type + "\".\n            Use one of " + this.types.join(', ') + ".\n            Falling back to " + fallback + ".");
                this.type = fallback;
            }
            this.classes = this.mode
                .split(' ')
                .splice(1)
                .join(' ');
            this.types.forEach(function (type) {
                _this.elementRef.nativeElement.classList.remove(type + "-wrapper");
            });
            if (this.backdrop) {
                this.elementRef.nativeElement.classList.add("modal-wrapper_backdrop");
            }
        };
        /** calls initMode */
        ModalComponent.prototype.ngOnInit = function () {
            this.initMode();
        };
        /** calls initMode */
        ModalComponent.prototype.ngOnChanges = function () {
            this.initMode();
        };
        return ModalComponent;
    }(PopComponent));
    ModalComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-modal',
                    template: "<div *ngIf=\"active\" [attr.data-col]=\"columns\" class=\"modal ec-modal\">\n  <button (click)=\"hide()\" type=\"button\" class=\"modal__dismiss\">\n    <ec-icon name=\"close\"></ec-icon>\n  </button>\n  <div class=\"modal__header\">\n    <ng-content select=\".modal-header,header\"></ng-content>\n    <ng-container [ngTemplateOutlet]=\"header\"></ng-container>\n  </div>\n  <div class=\"modal__body\">\n    <ng-content></ng-content>\n    <ng-container [ngTemplateOutlet]=\"body\"></ng-container>\n  </div>\n  <div class=\"modal__footer\">\n    <ng-content select=\".modal-footer,footer\"></ng-content>\n    <ng-container [ngTemplateOutlet]=\"footer\"></ng-container>\n  </div>\n</div>\n"
                },] }
    ];
    ModalComponent.ctorParameters = function () { return [
        { type: PopService },
        { type: core.ElementRef },
        { type: core.ChangeDetectorRef }
    ]; };
    ModalComponent.propDecorators = {
        mode: [{ type: core.Input }],
        backdrop: [{ type: core.Input }],
        header: [{ type: core.Input }],
        body: [{ type: core.Input }],
        footer: [{ type: core.Input }],
        templates: [{ type: core.ContentChildren, args: [core.TemplateRef,] }],
        columns: [{ type: core.Input }]
    };

    /** Contains all icons that are available in ec-icons font. */
    // tslint:disable:max-line-length
    var ixo = [
        {
            name: 'add',
            path: 'M19 11h-6v-6c0-0.553-0.448-1-1-1s-1 0.447-1 1v6h-6c-0.552 0-1 0.447-1 1s0.448 1 1 1h6v6c0 0.553 0.448 1 1 1s1-0.447 1-1v-6h6c0.552 0 1-0.447 1-1s-0.448-1-1-1z',
        },
        {
            name: 'calendar',
            path: 'M8 15c0.55 0 1 0.45 1 1s-0.45 1-1 1c-0.55 0-1-0.45-1-1s0.45-1 1-1zM16 15c0.55 0 1 0.45 1 1s-0.45 1-1 1h-4c-0.55 0-1-0.45-1-1s0.45-1 1-1h4zM18 20c0.551 0 1-0.449 1-1v-6h-14v6c0 0.551 0.449 1 1 1h12zM6 6c-0.551 0-1 0.449-1 1v4h14v-4c0-0.551-0.449-1-1-1h-1v1c0 0.55-0.45 1-1 1s-1-0.45-1-1v-1h-6v1c0 0.55-0.45 1-1 1s-1-0.45-1-1v-1h-1zM18 4c1.654 0 3 1.346 3 3v12c0 1.654-1.346 3-3 3h-12c-1.654 0-3-1.346-3-3v-12c0-1.654 1.346-3 3-3h1v-1c0-0.55 0.45-1 1-1s1 0.45 1 1v1h6v-1c0-0.55 0.45-1 1-1s1 0.45 1 1v1h1z',
        },
        {
            name: 'close',
            path: 'M13.414 12l4.293-4.293c0.391-0.391 0.391-1.023 0-1.414s-1.023-0.391-1.414 0l-4.293 4.293-4.293-4.293c-0.391-0.391-1.023-0.391-1.414 0s-0.391 1.023 0 1.414l4.293 4.293-4.293 4.293c-0.391 0.391-0.391 1.023 0 1.414 0.195 0.195 0.451 0.293 0.707 0.293s0.512-0.098 0.707-0.293l4.293-4.293 4.293 4.293c0.195 0.195 0.451 0.293 0.707 0.293s0.512-0.098 0.707-0.293c0.391-0.391 0.391-1.023 0-1.414l-4.293-4.293z',
        },
        {
            name: 'checkbox',
            path: 'M14.705 8.394l-3.784 4.969-1.633-2.086c-0.341-0.436-0.969-0.512-1.404-0.171s-0.512 0.969-0.171 1.403l2.431 3.107c0.19 0.242 0.48 0.383 0.788 0.383h0.007c0.309-0.001 0.601-0.147 0.788-0.394l4.569-6c0.335-0.44 0.25-1.066-0.19-1.401s-1.068-0.249-1.401 0.19zM19 18c0 0.552-0.449 1-1 1h-12c-0.551 0-1-0.448-1-1v-12c0-0.552 0.449-1 1-1h12c0.551 0 1 0.448 1 1v12zM18 3h-12c-1.654 0-3 1.346-3 3v12c0 1.654 1.346 3 3 3h12c1.654 0 3-1.346 3-3v-12c0-1.654-1.346-3-3-3z',
        },
        {
            name: 'checkbox-off',
            path: 'M6 5c-0.551 0-1 0.449-1 1v12c0 0.551 0.449 1 1 1h12c0.551 0 1-0.449 1-1v-12c0-0.551-0.449-1-1-1h-12zM18 21h-12c-1.654 0-3-1.346-3-3v-12c0-1.654 1.346-3 3-3h12c1.654 0 3 1.346 3 3v12c0 1.654-1.346 3-3 3z',
        },
        {
            name: 'checkmark',
            path: 'M9.863 18c-0.276 0-0.54-0.114-0.729-0.315l-4.863-5.179c-0.379-0.402-0.358-1.035 0.044-1.413 0.403-0.378 1.036-0.358 1.413 0.044l4.125 4.391 8.408-9.202c0.374-0.409 1.006-0.436 1.414-0.064 0.407 0.372 0.435 1.005 0.063 1.412l-9.137 10c-0.187 0.206-0.453 0.324-0.731 0.326h-0.007z',
        },
        {
            name: 'code',
            path: 'M8.641 5.231c0.424 0.354 0.481 0.984 0.128 1.409l-4.477 5.37 4.316 5.363c0.345 0.43 0.278 1.059-0.153 1.406-0.184 0.148-0.406 0.221-0.626 0.221-0.292 0-0.582-0.128-0.78-0.373l-4.828-6c-0.299-0.372-0.294-0.902 0.011-1.268l5-6c0.353-0.424 0.982-0.481 1.409-0.128zM21.779 11.373c0.299 0.371 0.294 0.901-0.011 1.268l-5 6c-0.198 0.237-0.482 0.359-0.769 0.359-0.226 0-0.452-0.076-0.64-0.231-0.424-0.354-0.481-0.985-0.128-1.41l4.477-5.37-4.316-5.362c-0.345-0.431-0.278-1.060 0.153-1.406 0.43-0.348 1.059-0.278 1.406 0.152l4.828 6z',
        },
        {
            name: 'database',
            path: 'M19 14v-4h-14v-2h14v-3c0-0.552-0.448-1-1-1h-12c-0.552 0-1 0.448-1 1v14c0 0.552 0.448 1 1 1h12c0.552 0 1-0.448 1-1v-3h-14v-2h14zM6 2h12c1.657 0 3 1.343 3 3v14c0 1.657-1.343 3-3 3h-12c-1.657 0-3-1.343-3-3v-14c0-1.657 1.343-3 3-3zM16.5 11h1c0.276 0 0.5 0.224 0.5 0.5v1c0 0.276-0.224 0.5-0.5 0.5h-1c-0.276 0-0.5-0.224-0.5-0.5v-1c0-0.276 0.224-0.5 0.5-0.5zM16.5 5h1c0.276 0 0.5 0.224 0.5 0.5v1c0 0.276-0.224 0.5-0.5 0.5h-1c-0.276 0-0.5-0.224-0.5-0.5v-1c0-0.276 0.224-0.5 0.5-0.5zM16.5 17h1c0.276 0 0.5 0.224 0.5 0.5v1c0 0.276-0.224 0.5-0.5 0.5h-1c-0.276 0-0.5-0.224-0.5-0.5v-1c0-0.276 0.224-0.5 0.5-0.5z',
        },
        {
            name: 'edit',
            path: 'M16.019 10.679l-2.695-2.695 1.948-1.949 2.694 2.694-1.947 1.95zM9.080 17.625l-2.977 0.271 0.264-2.956 5.617-5.617 2.696 2.696-5.6 5.606zM19.404 7.338l-2.739-2.739c-0.741-0.739-2.014-0.774-2.716-0.069l-8.996 8.996c-0.326 0.325-0.528 0.757-0.57 1.214l-0.379 4.17c-0.026 0.295 0.079 0.587 0.289 0.797 0.189 0.189 0.444 0.293 0.707 0.293 0.031 0 0.061-0.001 0.091-0.004l4.17-0.379c0.458-0.042 0.889-0.243 1.214-0.568l8.997-8.997c0.728-0.73 0.697-1.948-0.068-2.714z',
        },
        {
            name: 'eye-closed',
            path: 'M12 13.5c-0.827 0-1.5-0.673-1.5-1.5 0-0.025 0.011-0.049 0.012-0.074l1.562 1.562c-0.025 0.001-0.049 0.012-0.074 0.012zM4.707 3.293l16 16c0.391 0.391 0.391 1.023 0 1.414-0.195 0.195-0.451 0.293-0.707 0.293s-0.512-0.098-0.707-0.293l-5.63-5.63c-0.509 0.276-1.074 0.423-1.663 0.423-1.93 0-3.5-1.57-3.5-3.5 0-0.589 0.147-1.154 0.423-1.663l-5.63-5.63c-0.391-0.391-0.391-1.023 0-1.414s1.023-0.391 1.414 0zM12.22 16.998c0.6-0.015 1.163-0.109 1.698-0.251l1.58 1.58c-0.971 0.384-2.043 0.64-3.227 0.67-0.082 0.002-0.164 0.003-0.246 0.003-5.863 0-9.263-5.405-9.892-6.502-0.177-0.308-0.177-0.687 0-0.995 0.414-0.723 1.39-2.241 2.912-3.63l1.411 1.412c-1.060 0.951-1.826 1.997-2.283 2.711 0.932 1.419 3.742 5.102 8.047 5.002zM21.868 11.502c0.176 0.308 0.176 0.687 0 0.995-0.415 0.723-1.391 2.241-2.913 3.63l-1.411-1.412c1.060-0.951 1.827-1.997 2.283-2.711-0.932-1.419-3.755-5.11-8.046-5.002-0.6 0.015-1.163 0.109-1.699 0.251l-1.58-1.58c0.972-0.384 2.043-0.64 3.228-0.67 5.975-0.187 9.5 5.387 10.138 6.499z',
        },
        {
            name: 'eye-open',
            path: 'M12 13.5c-0.827 0-1.5-0.673-1.5-1.5s0.673-1.5 1.5-1.5c0.827 0 1.5 0.673 1.5 1.5s-0.673 1.5-1.5 1.5zM12 8.5c-1.93 0-3.5 1.57-3.5 3.5s1.57 3.5 3.5 3.5c1.93 0 3.5-1.57 3.5-3.5s-1.57-3.5-3.5-3.5zM12.22 16.998c-4.306 0.1-7.115-3.583-8.047-5.002 1.026-1.605 3.61-4.891 7.608-4.993 4.289-0.109 7.114 3.583 8.046 5.002-1.025 1.605-3.61 4.891-7.607 4.993zM21.868 11.503c-0.638-1.112-4.162-6.686-10.138-6.499-5.528 0.14-8.743 5.010-9.597 6.499-0.177 0.308-0.177 0.687 0 0.995 0.629 1.097 4.029 6.502 9.892 6.502 0.082 0 0.164-0.001 0.246-0.003 5.527-0.141 8.743-5.010 9.597-6.499 0.176-0.308 0.176-0.687 0-0.995z',
        },
        {
            name: 'filter',
            path: 'M3.5 6h17c0.276 0 0.5 0.224 0.5 0.5v1c0 0.276-0.224 0.5-0.5 0.5h-17c-0.276 0-0.5-0.224-0.5-0.5v-1c0-0.276 0.224-0.5 0.5-0.5zM6.5 11h11c0.276 0 0.5 0.224 0.5 0.5v1c0 0.276-0.224 0.5-0.5 0.5h-11c-0.276 0-0.5-0.224-0.5-0.5v-1c0-0.276 0.224-0.5 0.5-0.5zM10.5 16h3c0.276 0 0.5 0.224 0.5 0.5v1c0 0.276-0.224 0.5-0.5 0.5h-3c-0.276 0-0.5-0.224-0.5-0.5v-1c0-0.276 0.224-0.5 0.5-0.5z',
        },
        {
            name: 'image',
            path: 'M5 17.805l7.031-6.117c1.129-0.982 2.809-0.982 3.938 0l3.031 2.637v-8.325c0-0.552-0.448-1-1-1h-12c-0.552 0-1 0.448-1 1v11.805zM6.673 19h11.327c0.552 0 1-0.448 1-1v-1.025l-4.344-3.779c-0.376-0.327-0.936-0.327-1.313 0l-6.671 5.803zM6 3h12c1.657 0 3 1.343 3 3v12c0 1.657-1.343 3-3 3h-12c-1.657 0-3-1.343-3-3v-12c0-1.657 1.343-3 3-3zM7.5 10c-0.828 0-1.5-0.672-1.5-1.5s0.672-1.5 1.5-1.5c0.828 0 1.5 0.672 1.5 1.5s-0.672 1.5-1.5 1.5z',
        },
        {
            name: 'images',
            path: 'M6 16.8045l7.0309-6.1169c1.129-.9822 2.8092-.9822 3.9382 0L20 13.3246V5c0-.5523-.4477-1-1-1H7c-.5523 0-1 .4477-1 1v11.8045zM7.673 18H19c.5523 0 1-.4477 1-1v-1.0245l-4.3436-3.779a1 1 0 0 0-1.3128 0L7.673 18zM7 2h12c1.6569 0 3 1.3431 3 3v12c0 1.6569-1.3431 3-3 3H7c-1.6569 0-3-1.3431-3-3V5c0-1.6569 1.3431-3 3-3zm1.5 7C7.6716 9 7 8.3284 7 7.5S7.6716 6 8.5 6s1.5.6716 1.5 1.5S9.3284 9 8.5 9zM0 7c0-.5523.4477-1 1-1s1 .4477 1 1v13c0 1.1046.8954 2 2 2h13c.5523 0 1 .4477 1 1s-.4477 1-1 1H4c-2.2091 0-4-1.7909-4-4V7z',
        },
        {
            name: 'save',
            path: 'M20.121 8.707c0.566 0.566 0.879 1.32 0.879 2.122v7.171c0 1.654-1.346 3-3 3h-12c-1.654 0-3-1.346-3-3v-12c0-1.654 1.346-3 3-3h7.172c0.801 0 1.555 0.312 2.121 0.879l4.828 4.828zM19 18v-7.171c0-0.267-0.104-0.519-0.293-0.708l-4.828-4.828c-0.187-0.186-0.444-0.293-0.707-0.293h-3.172v4h3c0.553 0 1 0.448 1 1s-0.447 1-1 1h-4c-0.553 0-1-0.448-1-1v-5h-2c-0.552 0-1 0.449-1 1v12c0 0.551 0.448 1 1 1h2v-3c0-0.552 0.447-1 1-1h6c0.553 0 1 0.448 1 1v3h2c0.552 0 1-0.449 1-1zM10 19h4v-2h-4v2z',
        },
        {
            name: 'search',
            path: 'M5 11c0-3.309 2.691-6 6-6s6 2.691 6 6c0 3.309-2.691 6-6 6s-6-2.691-6-6zM20.707 19.293l-3.395-3.396c1.053-1.354 1.688-3.051 1.688-4.897 0-4.411-3.589-8-8-8s-8 3.589-8 8c0 4.411 3.589 8 8 8 1.846 0 3.543-0.635 4.897-1.688l3.396 3.395c0.195 0.195 0.451 0.293 0.707 0.293s0.512-0.098 0.707-0.293c0.391-0.391 0.391-1.023 0-1.414z',
        },
        {
            name: 'trash',
            path: 'M11 16c0 0.55-0.45 1-1 1s-1-0.45-1-1v-4c0-0.55 0.45-1 1-1s1 0.45 1 1v4zM15 16c0 0.55-0.45 1-1 1s-1-0.45-1-1v-4c0-0.55 0.45-1 1-1s1 0.45 1 1v4zM17 19c0 0.551-0.448 1-1 1h-8c-0.552 0-1-0.449-1-1v-11h10v11zM10 4.328c0-0.155 0.214-0.328 0.5-0.328h3c0.286 0 0.5 0.173 0.5 0.328v1.672h-4v-1.672zM16 6v-1.672c0-1.284-1.121-2.328-2.5-2.328h-3c-1.379 0-2.5 1.044-2.5 2.328v1.672h-3c-0.55 0-1 0.45-1 1s0.45 1 1 1v11c0 1.654 1.346 3 3 3h8c1.654 0 3-1.346 3-3v-11c0.55 0 1-0.45 1-1s-0.45-1-1-1h-3z',
        },
        {
            name: 'clear',
            path: 'M14.707 9.293c-0.391-0.391-1.023-0.391-1.414 0l-1.293 1.293-1.293-1.293c-0.391-0.391-1.023-0.391-1.414 0s-0.391 1.023 0 1.414l1.293 1.293-1.293 1.293c-0.391 0.391-0.391 1.023 0 1.414 0.195 0.195 0.451 0.293 0.707 0.293s0.512-0.098 0.707-0.293l1.293-1.293 1.293 1.293c0.195 0.195 0.451 0.293 0.707 0.293s0.512-0.098 0.707-0.293c0.391-0.391 0.391-1.023 0-1.414l-1.293-1.293 1.293-1.293c0.391-0.391 0.391-1.023 0-1.414zM12 20c-4.411 0-8-3.589-8-8s3.589-8 8-8c4.411 0 8 3.589 8 8s-3.589 8-8 8zM12 2c-5.514 0-10 4.486-10 10s4.486 10 10 10c5.514 0 10-4.486 10-10s-4.486-10-10-10z',
        },
    ];

    /** Service to register icons and icon sets. The default set is ec-icons. (Requires including ec-icons)
     * <example-url>https://components.entrecode.de/ui/icons?e=1</example-url>
     */
    var IconService = /** @class */ (function (_super) {
        __extends(IconService, _super);
        function IconService() {
            var _this = _super.apply(this, __spread(arguments)) || this;
            /** The current icon set that is registered to the service. It will be used to resolve icons from. */
            _this.registry = ixo;
            return _this;
        }
        return IconService;
    }(SymbolService));
    IconService.decorators = [
        { type: core.Injectable }
    ];

    /** Displays icons by name. If the matching Icon (from registry contains a content, the content is shown.
     * If not, is is expected to be a ec-icon.
     * <example-url>https://components.entrecode.de/ui/icons?e=1</example-url>
     */
    var IconComponent = /** @class */ (function () {
        function IconComponent(iconService) {
            this.iconService = iconService;
        }
        /** The component will resolve the icon from the current iconService registry. A warning is logged if no icon can be found. */
        IconComponent.prototype.resolve = function () {
            this.icon = this.iconService.get(this.name);
            if (!this.icon) {
                console.warn("Icon " + this.name + " cannot be found. Using the following icon registry:", this.iconService.registry);
            }
        };
        IconComponent.prototype.ngOnInit = function () {
            this.resolve();
        };
        IconComponent.prototype.ngOnChanges = function () {
            this.resolve();
        };
        return IconComponent;
    }());
    IconComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-icon',
                    template: "<span *ngIf=\"icon?.content\">{{ icon.content }}</span>\n<svg *ngIf=\"!icon?.content\" [id]=\"icon?.name\" class=\"ixo\" viewBox=\"0 0 24 24\">\n  <path [attr.d]=\"icon?.path\" />\n</svg>\n",
                    changeDetection: core.ChangeDetectionStrategy.OnPush,
                    styles: [":host{display:flex;align-items:center;justify-content:center}"]
                },] }
    ];
    IconComponent.ctorParameters = function () { return [
        { type: IconService }
    ]; };
    IconComponent.propDecorators = {
        name: [{ type: core.Input }]
    };

    var IconModule = /** @class */ (function () {
        function IconModule() {
        }
        return IconModule;
    }());
    IconModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [common.CommonModule],
                    declarations: [IconComponent],
                    exports: [IconComponent],
                    providers: [IconService],
                },] }
    ];

    var PopModule = /** @class */ (function () {
        function PopModule() {
        }
        return PopModule;
    }());
    PopModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [PopComponent, ModalComponent],
                    imports: [common.CommonModule, IconModule],
                    exports: [PopComponent, ModalComponent],
                    providers: [PopService],
                },] }
    ];

    /**
     * Created by felix on 26.05.17.
     */
    /** Displays any kind of Notification inside the DOM.
     * It listens on the notificationService.$emitter for notifications.
     * <example-url>https://components.entrecode.de/ui/notifications?e=1</example-url>
     * */
    var NotificationsComponent = /** @class */ (function () {
        /** Listens on the NotificationService and shows each notification that has this component set as host, or none at all. */
        function NotificationsComponent(notificationService) {
            var _this = this;
            this.notificationService = notificationService;
            /** The current stack of notifications that are visible. */
            this.notifications = new core$1.Collection([]);
            this.time = this.time || this.notificationService.defaultTime;
            this.notificationService.emitter$.subscribe(function (notification) {
                if (notification.hide) {
                    _this.notifications.removeAll(notification.hide);
                }
                if (!notification.title && !notification.message) {
                    // console.warn('tried to emit notification without message and title', notification);
                    return;
                }
                if (notification.append) {
                    notification.append.push(notification);
                }
                if (notification.replace) {
                    notification.replace.length = 0;
                    notification.replace.push(notification);
                }
                if (!notification.host || notification.host === _this) {
                    _this.notifications.add(notification);
                    if (notification.sticky) {
                        if (notification.time) {
                            console.warn('notification.time is ignored because it was set sticky');
                        }
                        return;
                    }
                    setTimeout(function () { return _this.notifications.remove(notification); }, notification.time || _this.time);
                }
            });
        }
        return NotificationsComponent;
    }());
    NotificationsComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-notifications',
                    template: "<div class=\"ec-notifications\">\n  <ec-pop *ngFor=\"let notification of notifications?.items\" [active]=\"true\" class=\"ec-notification\" [ngClass]=\"'is-' + notification.type\">\n    <h6 class=\"ec-notification__title\">{{notification.title}}</h6>\n    <p class=\"ec-notification__message\">{{notification.message}}</p>\n    <ec-error *ngIf=\"notification.error\" [error]=\"notification.error\"></ec-error>\n    <ul *ngIf=\"notification.error?.errors\" class=\"ec-notification-errors-list\">\n      <li *ngFor=\"let error of notification.error?.errors\">\n        <ec-error [error]=\"error\"></ec-error>\n      </li>\n    </ul>\n    <a class=\"ec-notification__dismiss\" (click)=\"notifications.remove(notification)\">\n      <ec-icon name=\"close\"></ec-icon>\n    </a>\n  </ec-pop>\n</div>"
                },] }
    ];
    NotificationsComponent.ctorParameters = function () { return [
        { type: NotificationsService }
    ]; };
    NotificationsComponent.propDecorators = {
        time: [{ type: core.Input }]
    };

    /** The CrudComponent takes at least a model name to render an entry list with create/edit/delete functionality out of the box.  */
    /** Displays an error thrown by the SDK. */
    var ErrorComponent = /** @class */ (function () {
        function ErrorComponent(symbol) {
            this.symbol = symbol;
        }
        /** initial update */
        ErrorComponent.prototype.ngOnInit = function () {
            this.update();
        };
        /** change update */
        ErrorComponent.prototype.ngOnChanges = function () {
            this.update();
        };
        /** updates error message  */
        ErrorComponent.prototype.update = function () {
            if (!this.error) {
                return;
            }
            var message = this.symbol.resolve('error.' + this.error.code);
            if (message) {
                this.error.message = message;
            }
        };
        return ErrorComponent;
    }());
    ErrorComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-error',
                    template: "<span *ngIf=\"error?.code\">{{error.code}}</span>\n<span *ngIf=\"error?.dataPath\">{{error.dataPath}}</span>\n{{error?.message}}\n<small>{{error.detail}}{{error.verbose?': '+error.verbose:''}}</small>\n<ul *ngIf=\"error?.subErrors\">\n  <li *ngFor=\"let subError of error.subErrors\">\n    <ec-error [error]=\"subError\"></ec-error>\n  </li>\n</ul>"
                },] }
    ];
    ErrorComponent.ctorParameters = function () { return [
        { type: SymbolService }
    ]; };
    ErrorComponent.propDecorators = {
        error: [{ type: core.Input }]
    };

    var NotificationsModule = /** @class */ (function () {
        function NotificationsModule() {
        }
        return NotificationsModule;
    }());
    NotificationsModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [NotificationsComponent, ErrorComponent],
                    imports: [common.CommonModule, PopModule, IconModule],
                    exports: [NotificationsComponent, ErrorComponent],
                    providers: [
                        {
                            provide: 'useDesktopNotifications',
                            useValue: false,
                        },
                        NotificationsService,
                    ],
                },] }
    ];

    /** The loader service registers promises */
    var LoaderService = /** @class */ (function () {
        function LoaderService() {
        }
        /** Sets a global loader that can be triggered without having the reference. */
        LoaderService.prototype.use = function (loader) {
            this.loader = loader;
        };
        /** Tells the given loader to wait for the given promise. If no loader is given, the global loader is used (if set)*/
        LoaderService.prototype.wait = function (promise, loader) {
            if (loader === void 0) { loader = this.loader; }
            if (!loader || !promise) {
                console.warn('cannot trigger loader: no promise or loader given');
                return;
            }
            return loader.wait(promise);
        };
        return LoaderService;
    }());
    LoaderService.decorators = [
        { type: core.Injectable }
    ];

    /** The ec-loader can be plugged into various components to be triggered when they load stuff.
     * <example-url>https://components.entrecode.de/ui/loader?e=1</example-url>
     */
    var LoaderComponent = /** @class */ (function () {
        /** Injects the host element. */
        function LoaderComponent(host) {
            this.host = host;
            /** The current stack of loading promises.*/
            this.stack = new core$1.Collection([]);
            /** The loader's visibility status. */
            this.visible = false;
        }
        /** Shows the loader by setting .visible to the host. This method is NOT meant to be used from outside, */
        LoaderComponent.prototype.show = function () {
            this.visible = true; // show loader
            this.host.nativeElement.classList.add('is-active');
        };
        /** Hide the loader by removing .visible from the host. This method is NOT meant to be used from outside, */
        LoaderComponent.prototype.hide = function () {
            this.visible = false; // hide loader
            this.host.nativeElement.classList.remove('is-active');
        };
        /** Tells loader to show until the given promise resolves. (includes all other promises that are waited upon)
         * Make sure the given promise is catched (so the loader will stop loading on error)! */
        LoaderComponent.prototype.wait = function (promise) {
            var _this = this;
            this.stack.add(promise); // add promise to stack
            this.show();
            var timestamp = Date.now();
            this.timestamp = timestamp; // get timestamp
            Promise.all(this.stack.items).catch(function (error) {
            }).then(function () {
                if (timestamp === _this.timestamp) {
                    _this.hide();
                    _this.stack.removeAll();
                }
            });
            return promise;
        };
        return LoaderComponent;
    }());
    LoaderComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-loader',
                    template: "<ng-content></ng-content>\n",
                    changeDetection: core.ChangeDetectionStrategy.OnPush
                },] }
    ];
    LoaderComponent.ctorParameters = function () { return [
        { type: core.ElementRef }
    ]; };

    var LoaderModule = /** @class */ (function () {
        function LoaderModule() {
        }
        return LoaderModule;
    }());
    LoaderModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [LoaderComponent],
                    imports: [common.CommonModule],
                    exports: [LoaderComponent],
                    providers: [LoaderService],
                },] }
    ];

    var ListConfigService = /** @class */ (function () {
        function ListConfigService() {
        }
        ListConfigService.prototype.retrieve = function (key) {
            var config = localStorage.getItem(key);
            return config ? JSON.parse(config) : null;
        };
        ListConfigService.prototype.set = function (key, value) {
            localStorage.setItem(key, JSON.stringify(value));
        };
        ListConfigService.prototype.store = function (key, config) {
            var existing = this.retrieve(key) || {};
            localStorage.setItem(key, JSON.stringify(Object.assign(existing, config)));
        };
        ListConfigService.prototype.getStorageKey = function (list) {
            if (!list || !list.fields || !list.config || !list.config.storageKey) {
                return;
            }
            var resolveFn = list.config.storageKey || this.storageKeyResolver;
            if (typeof resolveFn === 'function') {
                return resolveFn(list);
            }
            return list.config.storageKey;
        };
        ListConfigService.prototype.storeConfig = function (list) {
            var key = this.getStorageKey(list);
            if (!key) {
                return;
            }
            var config = { hide: list.fields.filter(function (f) { return f.hideInList; }).map(function (f) { return f.property; }) };
            this.store(key, config);
        };
        ListConfigService.prototype.applyConfig = function (list) {
            var key = this.getStorageKey(list);
            if (!key) {
                return;
            }
            var existing = this.retrieve(key);
            if (existing && existing.hide) {
                list.fields.forEach(function (field) { return (field.hideInList = false); });
                existing.hide.forEach(function (property) {
                    var field = list.fields.find(function (f) { return f.property === property; });
                    if (!field) {
                        console.warn('field ', property, ' not found');
                        return;
                    }
                    field.hideInList = true;
                });
            }
        };
        ListConfigService.prototype.getFilteredID = function (list) {
            if (!list || !list.config || !list.config.filter) {
                return;
            }
            return Object.keys(list.config.filter).reduce(function (id, property) {
                if (!id && list.config.identifierPattern && list.config.filter &&
                    typeof list.config.filter[property] === 'string' &&
                    list.config.filter[property].match(list.config.identifierPattern)) {
                    return list.config.filter[property];
                }
                return id;
            }, null);
        };
        return ListConfigService;
    }());
    ListConfigService.decorators = [
        { type: core.Injectable }
    ];

    var listTemplate = "<div class=\"ec-list\">\n  <ec-list-header [list]=\"list\" [selection]=\"selection\" *ngIf=\"showHeader()\"></ec-list-header>\n  <div class=\"ec-list-body\">\n    <div class=\"ec-list-group\" *ngFor=\"let group of list?.groups\">\n      <div class=\"ec-list-group-header\" *ngIf=\"group.value\" (click)=\"selection?.toggleAll(listItems?.items)\">\n        <div class=\"ec-list-cell ec-list-item__selector\" *ngIf=\"list?.config?.selectMode\">\n          <input type=\"checkbox\" [checked]=\"selection?.hasAll(listItems?.items)\">\n        </div>\n        <div class=\"ec-list-cell\">\n          <span class=\"ec-list-group-header__title\">{{group.value}}</span>\n        </div>\n      </div>\n      <ec-list-items [focusItem]=\"focusItem\" [list]=\"list\" [selection]=\"selection\" (columnClicked)=\"columnClick($event)\"\n        #listItems [items]=\"list?.page | group: group.property: group.value\"></ec-list-items>\n    </div>\n\n    <div class=\"ec-list-empty\" *ngIf=\"list?.isEmpty()&&!isLoading\">\n      <div *ngIf=\"list?.isFiltered()\">\n        <div #noResults>\n          <ng-content select=\"[data-ec-list-empty-filtered]\"></ng-content>\n        </div>\n        <div *ngIf=\"!noResults?.children?.length\">\n          {{'list.filter.noResults' | symbol}}\n          <a (click)=\"list.clearFilter()\">{{'list.filter.reset' | symbol}}</a>\n        </div>\n      </div>\n      <div *ngIf=\"!list.isFiltered()\">\n        <div #emptySlot>\n          <ng-content select=\"[data-ec-list-empty]\"></ng-content>\n        </div>\n        <div *ngIf=\"!emptySlot?.children?.length\">\n          {{'list.empty' | symbol}}\n        </div>\n      </div>\n    </div>\n    <div class=\"ec-list-empty\" *ngIf=\"list?.isEmpty()&&isLoading\">\n      <div #loadingSlot>\n        <ng-content select=\"[data-ec-list-loading]\"></ng-content>\n      </div>\n      <div *ngIf=\"!loadingSlot?.children?.length\">\n        {{'list.loading' | symbol}}\n      </div>\n    </div>\n  </div>\n</div>\n<ec-pagination [hidden]=\"list?.config?.hidePagination\" [config]=\"paginationConfig\" [pagination]=\"list?.pagination\"></ec-pagination>";

    /**
     * The ListComponent will render a list containing the given items or collection.
     *
     * <example-url>https://components.entrecode.de/ui/list/basic?e=1</example-url>
     * <example-url>https://components.entrecode.de/ui/list/transforms?e=1</example-url>
     * */
    var ListComponent = /** @class */ (function () {
        function ListComponent(listConfig, cdr) {
            this.listConfig = listConfig;
            this.cdr = cdr;
            /** The current list config */
            this.config = {};
            /** Config input for List */
            /** Flag that flips true when loading. */
            this.isLoading = false;
            /** Event emitter on item selection */
            this.columnClicked = new core.EventEmitter();
            /** Event emitter on selection change */
            this.selected = new core.EventEmitter();
            /** If true, the first item in the list will always be focused after changed */
            this.autoFocusFirst = false;
            /** emits after the list changed */
            this.changed = new core.EventEmitter();
        }
        /** Changing items or collection will trigger reconstructing the list with the new items.
         * Changing the selection will reconstruct the selection */
        ListComponent.prototype.ngOnChanges = function (changes) {
            this.config = Object.assign(this.config || {}, this.configInput || {});
            if (this.items) {
                this.init(new core$1.List(this.items, this.config, this.pagination));
            }
            else if (this.collection) {
                this.init(new core$1.List(this.collection.items, this.config, this.pagination));
            }
        };
        ListComponent.prototype.init = function (list) {
            var _this = this;
            if (!list) {
                console.warn('tried to init list.component with undefined list');
                return;
            }
            this.list = list;
            this.listConfig.applyConfig(this.list);
            this.list.change$.subscribe(function () {
                if (_this.autoFocusFirst || _this.list.isFiltered()) {
                    _this.focusFirst();
                }
                else {
                    delete _this.focusItem;
                }
                _this.cdr.markForCheck();
                _this.changed.emit(_this.list);
            });
            if (!this.selection) {
                this.selection = new core$1.Selection([], this.list.config);
            }
            if (this.selection) {
                this.selection.update$.subscribe(function (selection) {
                    _this.selected.emit(selection);
                });
            }
        };
        /** Column click handler. Triggers select.emit(item) with fallback to selection.toggle*/
        ListComponent.prototype.columnClick = function (item) {
            if (this.list.config.selectMode && this.selection) {
                this.selection.toggle(item, this.solo);
            }
            else if (this.columnClicked.observers.length) {
                return this.columnClicked.emit(item);
            }
        };
        /** Decides if the header should be visible or not */
        ListComponent.prototype.showHeader = function () {
            return (this.list &&
                this.list.config &&
                !this.list.config.disableHeader &&
                (this.list.fields.length || this.list.config.title));
            /* && (this.list.config.alwaysShowHeader || !this.list.isEmpty()); */
        };
        /** Selects the item with the given index */
        ListComponent.prototype.selectIndex = function (index) {
            if (!this.selection || this.list.isEmpty() || !this.list.items[index]) {
                return;
            }
            this.selection.select(this.list.items[index]);
        };
        ListComponent.prototype.focusFirst = function () {
            delete this.focusItem;
            this.focusNext();
        };
        /** Selects the next item */
        ListComponent.prototype.focusNext = function () {
            if (!this.list) {
                return;
            }
            var index = 0;
            if (this.focusItem) {
                index = this.list.page.indexOf(this.focusItem) + 1;
            }
            this.focusItem = this.list.page[index % this.list.page.length];
            this.cdr.markForCheck();
        };
        /** Selects the previous item */
        ListComponent.prototype.focusPrev = function () {
            if (!this.list) {
                return;
            }
            var index = this.list.page.length - 1;
            if (this.focusItem) {
                index = this.list.page.indexOf(this.focusItem) + this.list.page.length - 1;
            }
            this.focusItem = this.list.page[index % this.list.page.length];
            this.cdr.markForCheck();
        };
        /** Filters the list */
        ListComponent.prototype.filter = function (property, value) {
            this.list.filter(property, value);
        };
        return ListComponent;
    }());
    ListComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-list',
                    /* templateUrl: './list.component.html', */
                    template: listTemplate,
                    encapsulation: core.ViewEncapsulation.None,
                    changeDetection: core.ChangeDetectionStrategy.OnPush
                },] }
    ];
    ListComponent.ctorParameters = function () { return [
        { type: ListConfigService },
        { type: core.ChangeDetectorRef }
    ]; };
    ListComponent.propDecorators = {
        configInput: [{ type: core.Input, args: ['config',] }],
        items: [{ type: core.Input }],
        collection: [{ type: core.Input }],
        selection: [{ type: core.Input }],
        solo: [{ type: core.Input }],
        columnClicked: [{ type: core.Output }],
        selected: [{ type: core.Output }],
        list: [{ type: core.Input }],
        pagination: [{ type: core.Input }],
        paginationConfig: [{ type: core.Input }],
        autoFocusFirst: [{ type: core.Input }],
        changed: [{ type: core.Output }]
    };

    /** The ListItemsComponent displays the actual list, without all peripherals (header, pagination etc.).
     * It can either be given an Array of Items or just the list parent to control the shown items. */
    var ListItemsComponent = /** @class */ (function () {
        function ListItemsComponent(cdr) {
            this.cdr = cdr;
            /** Event emitter on item clicked */
            this.columnClicked = new core.EventEmitter();
        }
        /** Checks for host and uses its list. */
        ListItemsComponent.prototype.ngOnChanges = function () {
            var _this = this;
            if (!this.items && this.list) {
                this.items = this.list.page;
            }
            if (this.list) {
                this.list.change$.subscribe(function (newList) {
                    _this.cdr.markForCheck();
                });
            }
            if (this.selection) {
                this.selection.update$.subscribe(function (newList) {
                    _this.cdr.markForCheck();
                });
            }
        };
        /** yields true if the item is focussed */
        ListItemsComponent.prototype.hasFocus = function (item) {
            return this.focusItem === item;
        };
        ListItemsComponent.prototype.isClickable = function () {
            return this.columnClicked.observers.length || (this.selection && this.list && this.list.config.selectMode);
        };
        /** Propagate clicked item to host or toggle selection. */
        ListItemsComponent.prototype.columnClick = function (item, e) {
            e.stopPropagation();
            e.stopImmediatePropagation();
            if (this.selection && this.list && this.list.config.selectMode) {
                this.selection.toggle(item, this.solo);
            }
            else if (this.columnClicked.observers.length) {
                this.columnClicked.emit(item);
            }
        };
        return ListItemsComponent;
    }());
    ListItemsComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-list-items',
                    template: "<ul class=\"ec-list-items\">\n  <li\n    *ngFor=\"let item of items; trackBy: list?.trackItem\"\n    (click)=\"columnClick(item, $event)\"\n    class=\"ec-list-item\"\n    [ngClass]=\"item.classes()\"\n    [class.is-clickable]=\"isClickable()\"\n    [class.is-focus]=\"hasFocus(item)\"\n    [class.is-selected]=\"selection?.has(item)\"\n  >\n    <div\n      class=\"ec-list-cell ec-list-item__selector\"\n      *ngIf=\"list?.config?.selectMode\"\n    >\n      <input type=\"checkbox\" [checked]=\"selection?.has(item)\" />\n    </div>\n    <div\n      *ngFor=\"let field of list?.fields; let i = index\"\n      class=\"ec-list-cell\"\n      [ngClass]=\"'ec-list-cell_' + field.getView('output') + ' ' + (field.classes || '') +' ec-list-field_' + field.property\"\n      [class.is-hidden]=\"field.hideInList\"\n      [class.is-sortable]=\"field.sortable\"\n      [class.is-filtered]=\"list.isFiltered(field.property)\"\n      [class.is-sorted]=\"list.config?.sortBy === field.property\"\n    >\n      <ec-output\n        [field]=\"field\"\n        [item]=\"item\"\n        [component]=\"field.getComponent('list') || field.output\"\n      ></ec-output>\n    </div>\n  </li>\n</ul>\n",
                    changeDetection: core.ChangeDetectionStrategy.OnPush
                },] }
    ];
    ListItemsComponent.ctorParameters = function () { return [
        { type: core.ChangeDetectorRef }
    ]; };
    ListItemsComponent.propDecorators = {
        list: [{ type: core.Input }],
        selection: [{ type: core.Input }],
        items: [{ type: core.Input }],
        solo: [{ type: core.Input }],
        focusItem: [{ type: core.Input }],
        columnClicked: [{ type: core.Output }]
    };

    /** This component renders, as the name states, the header of a list.*/
    var ListHeaderComponent = /** @class */ (function () {
        function ListHeaderComponent(listConfig, cdr) {
            this.listConfig = listConfig;
            this.cdr = cdr;
        }
        ListHeaderComponent.prototype.setFilter = function (field, value) {
            var _a;
            this.list.setFilter((_a = {}, _a[field.property] = value, _a));
        };
        ListHeaderComponent.prototype.inputReady = function (input) {
            this.filterInput = input;
            input.focus(true);
        };
        ListHeaderComponent.prototype.initFilterForm = function (filterForm) {
            // is called when form is ready
            this.filterForm = filterForm;
            if (this.list.config.defaultFilter) {
                this.filterField(this.list.config.defaultFilter);
            }
        };
        ListHeaderComponent.prototype.ngOnChanges = function (changes) {
            var _this = this;
            if (!changes.list) {
                return;
            }
            if (!this.list || !this.list.config || !this.list.config.fields) {
                return;
            }
            /* this.list.change$.subscribe(() => {
              if (this.filterInput) {
                // this.filterInput.focus(true);
              }
            }); */
            this.filterFormConfig = Object.assign(Object.assign({}, this.list.config), { fields: this.list.filterableFields().reduce(function (fields, field) {
                    var _a;
                    return Object.assign(Object.assign({}, fields), (_a = {}, _a[field.property] = Object.assign(Object.assign({}, _this.list.config.fields[field.property]), { view: field.getView('filter'), required: false, readOnly: false, immutable: false, disabled: false, create: true, form: true, autofocus: true, nestedCrudConfig: Object.assign(Object.assign({}, field.nestedCrudConfig), { methods: ['get'] }) }), _a));
                }, {}) });
        };
        /** opens the given filter pop and closes all others */
        ListHeaderComponent.prototype.filterField = function (property) {
            var _this = this;
            if (this.filteredField) {
                if (this.filteredField.property === property) {
                    /* this.filterPop.hide(); */
                    if (this.filterInput) {
                        this.filterInput.focus(true);
                    }
                    return;
                }
                this.clearFilter();
            }
            // patch current filter value to control
            var control = this.filterForm.group.get(property);
            if (!control) {
                console.warn('no control found for ' + property + '. Is it filterable?', this.list.config, this.filterForm.group);
                return;
            }
            this.filterForm.group.get(property).patchValue(this.list.getFilterValue(property));
            this.filteredField = this.filterForm.form.getField(property);
            setTimeout(function () { return _this.filterPop.show(); });
        };
        ListHeaderComponent.prototype.resetFilter = function () {
            if (!this.filteredField || !this.list || !this.list.isFiltered(this.filteredField.property)) {
                return;
            }
            this.filterForm.group.get(this.filteredField.property).reset();
            this.list.clearFilter();
        };
        ListHeaderComponent.prototype.clearFilter = function () {
            if (!this.filteredField || !this.list.isFiltered(this.filteredField.property)) {
                delete this.filteredField;
                return;
            }
            this.resetFilter();
            delete this.filteredField;
        };
        ListHeaderComponent.prototype.toggledFilterPop = function (active) {
            if (!active) {
                this.clearFilter();
            }
            if (this.filterInput) {
                this.filterInput.focus(true);
            }
        };
        /** Toggles the fields visibility in the list */
        ListHeaderComponent.prototype.toggleVisibility = function (field) {
            this.list.toggleVisibility(field);
            this.listConfig.storeConfig(this.list);
        };
        /** Yields true if the given field is the last column of the current list header */
        ListHeaderComponent.prototype.isLastColumn = function (field) {
            if (!this.list || !this.list.fields) {
                return;
            }
            var visibleColumns = this.list.fields.filter(function (f) { return !f.hideInList; });
            return field.property === visibleColumns[visibleColumns.length - 1].property;
        };
        return ListHeaderComponent;
    }());
    ListHeaderComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-list-header',
                    template: "<ec-pop (toggle)=\"toggledFilterPop($event)\" [hideOnEscape]=\"false\" #filterPop>\n  <div class=\"ec-searchbar\">\n    <div *ngIf=\"filteredField\" data-grid=\"no-gutter\">\n      <div data-col=\"auto\">\n        <div class=\"input-group\">\n          <div class=\"input-group__addon\" data-flex=\"center\">\n            <ec-icon name=\"search\"></ec-icon>\n          </div>\n          <ec-input\n            (ready)=\"inputReady($event)\"\n            (changed)=\"setFilter(filteredField, $event)\"\n            [lazy]=\"true\"\n            [component]=\"filteredField.getComponent('filter') || filteredField.input\"\n            [field]=\"filteredField\"\n            [group]=\"filterForm?.group\"\n            [debounce]=\"200\"\n            *ngIf=\"filterPop.active && filterForm?.group\"\n            #filterInput\n            data-col=\"auto\"\n          ></ec-input>\n          <div\n            class=\"input-group__addon\"\n            *ngIf=\"list?.isFiltered(filteredField.property)\"\n            data-flex=\"center center-items\"\n          >\n            <a class=\"btn btn_clear btn_square btn_small is-ink-light\" (click)=\"resetFilter()\">\n              <ec-icon name=\"clear\"></ec-icon>\n            </a>\n          </div>\n        </div>\n      </div>\n      <div data-col=\"fit\">\n        <div tabindex=\"0\" class=\"dropdown dropdown_right\">\n          <span class=\"btn btn_clear btn_square\">\n            <ec-icon name=\"filter\"></ec-icon>\n          </span>\n          <div class=\"dropdown-options\">\n            <div *ngFor=\"let field of list?.sortableFields()\">\n              <a\n                class=\"dropdown-option sorting-option\"\n                [class.is-sorted-desc]=\"list.isSorted(field.property, true)\"\n                [class.is-sorted-asc]=\"list.isSorted(field.property, false)\"\n              >\n                <span class=\"sorting-option-indicator\">\n                  <span class=\"asc\" (click)=\"list.toggleSort(field.property, false)\"></span>\n                  <span class=\"desc\" (click)=\"list.toggleSort(field.property, true)\"></span>\n                </span>\n                <span (click)=\"list.toggleSort(field.property)\">{{ field.getLabel() }}</span>\n              </a>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n</ec-pop>\n<div *ngIf=\"filterFormConfig\">\n  <ec-form\n    [config]=\"filterFormConfig\"\n    [value]=\"list?.config?.filter\"\n    [empty]=\"true\"\n    #filterForm\n    (ready)=\"initFilterForm($event)\"\n    [lazy]=\"true\"\n  ></ec-form>\n  <div class=\"ec-list-header\">\n    <div class=\"ec-list-cell ec-list-item__selector\" *ngIf=\"list?.config?.selectMode && !list?.isEmpty()\">\n      <input\n        type=\"checkbox\"\n        (click)=\"selection?.toggleAll(list?.page)\"\n        [checked]=\"selection?.hasAll(list?.page)\"\n        [disabled]=\"selection?.config?.solo\"\n      />\n    </div>\n    <div\n      class=\"ec-list-cell\"\n      *ngFor=\"let field of list?.fields; let i = index\"\n      [ngClass]=\"'ec-list-cell_' + field.getView('output') + ' ' + (field?.classes || '')\"\n      [class.is-hidden]=\"field.hideInList\"\n      [class.is-sortable]=\"field.sortable\"\n      [class.is-sorted]=\"list.isSorted(field.property)\"\n      [class.is-filterable]=\"field.filterable\"\n      [class.is-filtered]=\"list.isFiltered(field.property)\"\n      [class.is-last-column]=\"isLastColumn(field)\"\n      [class.is-sorted-desc]=\"list.isSorted(field.property, true)\"\n      [class.is-sorted-asc]=\"list.isSorted(field.property, false)\"\n    >\n      <!-- [class.is-filter-active]=\"filterPop.active\"-->\n      <a (click)=\"filterField(field.property)\" class=\"is-filterable-control\" *ngIf=\"field.filterable\">\n        <ec-icon name=\"search\"></ec-icon>\n      </a>\n      <!-- <a (click)=\"toggleVisibility(field)\" class=\"is-visibility-control\">\n        <ec-icon name=\"eye-closed\"></ec-icon>\n      </a> -->\n\n      <span\n        class=\"ec-list-column-title\"\n        (click)=\"field.sortable && list.toggleSort(field.property)\"\n        [title]=\"field.property\"\n      >\n        {{ field.getLabel() }}\n      </span>\n      <span class=\"is-sortable-indicator\" *ngIf=\"field.sortable\">\n        <span class=\"asc\" (click)=\"list.toggleSort(field.property, false)\"></span>\n        <span class=\"desc\" (click)=\"list.toggleSort(field.property, true)\"></span>\n      </span>\n    </div>\n\n    <div class=\"dropdown dropdown_right ec-list-column-filter\" tabindex=\"0\" *ngIf=\"!list?.config?.disableColumnFilter\">\n      <span>&#9776;</span>\n      <div class=\"dropdown-options\">\n        <div\n          class=\"dropdown-option\"\n          *ngFor=\"let field of list?.fields\"\n          (click)=\"toggleVisibility(field)\"\n          [class.is-active]=\"!field.hideInList\"\n          [class.is-hidden]=\"field.hideInColumnFilter\"\n        >\n          {{ field.getLabel() }}\n        </div>\n      </div>\n    </div>\n  </div>\n</div>\n",
                    changeDetection: core.ChangeDetectionStrategy.OnPush
                },] }
    ];
    ListHeaderComponent.ctorParameters = function () { return [
        { type: ListConfigService },
        { type: core.ChangeDetectorRef }
    ]; };
    ListHeaderComponent.propDecorators = {
        list: [{ type: core.Input }],
        selection: [{ type: core.Input }],
        filterPop: [{ type: core.ViewChild, args: ['filterPop', { static: true },] }]
    };

    /** Configuration for a pagination component */
    var PaginationConfig = /** @class */ (function () {
        /** The constructor assigns the config */
        function PaginationConfig(config) {
            /** Range of displayed pages in the UI. Controls the number of pages before and after the current page. Defaults to 3.
             * NOTE: For a smoother UX, there are minimum ```2 * range + 1``` pages visible.*/
            this.range = 2;
            Object.assign(this, config);
        }
        return PaginationConfig;
    }());

    /**
     * The Pagination component renders a given instance of the Pagination class.
     */
    var PaginationComponent = /** @class */ (function () {
        function PaginationComponent() {
        }
        /** Init config. */
        PaginationComponent.prototype.ngOnInit = function () {
            this.config = new PaginationConfig(this.config);
        };
        /** As soon as the pagination is known, the change$ event is subscribed to translate the container on change.*/
        PaginationComponent.prototype.ngOnChanges = function () {
            if (!this.pagination) {
                return;
            }
            this.config = new PaginationConfig(this.config);
        };
        /** Determines if a page should be visible */
        PaginationComponent.prototype.isVisible = function (page) {
            var current = this.pagination.getPage();
            return (Math.abs(current - page) <
                this.config.range +
                    1 +
                    Math.max(0, this.config.range - current + 1) +
                    Math.max(0, current - this.pagination.getPages() + this.config.range));
        };
        PaginationComponent.prototype.updateSize = function (value) {
            if (!value) {
                return;
            }
            // tslint:disable-next-line:radix
            this.pagination.updateSize(parseInt(value));
        };
        return PaginationComponent;
    }());
    PaginationComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-pagination',
                    template: "<nav class=\"ec-pagination\">\n  <ul class=\"ec-pagination-controls\" *ngIf=\"pagination?.getPages()>1&&!pagination?.isFirst()\">\n    <li class=\"ec-pagination-control ec-pagination-control_first\" [class.is-disabled]=\"pagination?.isFirst()\" [hidden]=\"config.hideFirstLast\">\n      <a (click)=\"pagination.first()\" class=\"ec-pagination__item\">\n        <span>{{'pagination.first' | symbol}}</span>\n      </a>\n    </li>\n    <li class=\"ec-pagination-control ec-pagination-control_prev\" *ngIf=\"!pagination?.isFirst()\">\n      <a (click)=\"pagination.prev()\" class=\"ec-pagination__item\">\n        <span>{{'pagination.prev' | symbol}}</span>\n      </a>\n    </li>\n  </ul>\n  <div #container class=\"ec-pagination-pages\" [hidden]=\"config?.hidePages\" *ngIf=\"pagination?.getPages()>1\">\n    <ul #pageContainer *ngIf=\"pagination?.pages\">\n      <li *ngFor=\"let page of pagination.pages;let i = index\" #page [hidden]=\"!isVisible(i+1)\">\n        <a (click)=\"pagination.select(i+1)\" [class.is-active]=\"pagination.isActive(i+1)\" class=\"ec-pagination__item\">\n          <span>{{i+1}}</span>\n        </a>\n      </li>\n    </ul>\n  </div>\n  <ul class=\"ec-pagination-controls\" *ngIf=\"pagination?.getPages()>1&&!pagination?.isLast()\">\n    <li class=\"ec-pagination-control ec-pagination-control_next\" [class.is-disabled]=\"pagination?.isLast()\">\n      <a (click)=\"pagination.next()\" class=\"ec-pagination__item\">\n        <span>{{'pagination.next' | symbol}}</span>\n      </a>\n    </li>\n    <li class=\"ec-pagination-control ec-pagination-control_last\" *ngIf=\"!pagination?.isLast()\" [hidden]=\"config.hideFirstLast\">\n      <a (click)=\"pagination.last()\" class=\"ec-pagination__item\">\n        <span>{{'pagination.last' | symbol}}</span>\n      </a>\n    </li>\n  </ul>\n  <div class=\"ec-pagination-info\" *ngIf=\"pagination?.params()?.total\">\n    <span>{{pagination?.params()?.from}}-{{pagination?.params()?.to}} {{ 'pagination.of' | symbol}} {{pagination?.params()?.total}}</span>\n  </div>\n  <div class=\"ec-pagination-size-select\" *ngIf=\"pagination?.params()?.total\">\n    <select *ngIf=\"pagination?.params()?.availableSizes?.length > 1\" (change)=\"updateSize($event.target.value)\" class=\"input input_small\">\n      <option *ngFor=\"let size of pagination?.params()?.availableSizes\" [value]=\"size\" [attr.selected]=\"pagination.params().size===size?'selected':null\">\n        {{size}} {{'pagination.size' | symbol}}\n      </option>\n    </select>\n  </div>\n</nav>"
                },] }
    ];
    PaginationComponent.propDecorators = {
        pagination: [{ type: core.Input }],
        container: [{ type: core.ViewChild, args: ['container',] }],
        pageContainer: [{ type: core.ViewChild, args: ['pageContainer',] }],
        page: [{ type: core.ViewChildren, args: ['page',] }],
        config: [{ type: core.Input }]
    };

    /** Genereic Searchbar component. Filters a given list its label property (or given property).
     * Supports autofocus and arrow navigation. */
    var SearchbarComponent = /** @class */ (function () {
        function SearchbarComponent(route, symbol, cdr) {
            var _this = this;
            this.route = route;
            this.symbol = symbol;
            this.cdr = cdr;
            /** If true, the input will be autofocused */
            this.autofocus = true;
            /** The event that focuses the input */
            this.focusEvent = new core.EventEmitter();
            /** Delay until search is fired */
            this.debounceTime = 200;
            /** Subject that is triggered on keyup */
            this.queryValue = new rxjs.Subject();
            /** Subject that is triggered on key trigger */
            this.keySubject = new rxjs.Subject();
            /** Subject that is nexted when something is pasted */
            this.paste = new rxjs.Subject();
            /** Output that emits when enter is pressed on a selected item */
            this.selected = new core.EventEmitter();
            /** Emits when enter key is pressed */
            this.enter = new core.EventEmitter();
            /** Emits on keyup*/
            this.keyup = new core.EventEmitter();
            /** Emits on keypress */
            this.keypressed = new core.EventEmitter();
            /** Emits on blur */
            this.blur = new core.EventEmitter();
            /** Emits on focus */
            this.focus = new core.EventEmitter();
            /** Emits on paste */
            this.pasted = new core.EventEmitter();
            /** Emitted when the query changes, including debounce */
            this.queryChanged = new core.EventEmitter();
            this.defaultPlaceholder = this.symbol.resolve('searchbar.placeholder');
            this.queryValue.next('');
            this.paste.asObservable().subscribe(function (e) {
                var _a;
                var pasted = e.clipboardData.getData('text');
                if (_this.pasted.observers.length) {
                    _this.pasted.emit(e);
                }
                else if (_this.list.config.identifierPattern && pasted.match(_this.list.config.identifierPattern)) {
                    _this.preventDefault(e);
                    _this.clear();
                    _this.selected.emit(new core$1.Item((_a = {},
                        _a[_this.list.config.identifier] = pasted,
                        _a), _this.list.config));
                }
            });
            this.queryValue
                .asObservable()
                .pipe(operators.debounceTime(this.debounceTime))
                .pipe(operators.distinctUntilChanged())
                .subscribe(function (value) { return _this.filterList(value); });
            this.keySubject
                .asObservable()
                .pipe(operators.debounceTime(100))
                .subscribe(function (data) {
                _this.keypressed.emit(data);
            });
            this.route.params.subscribe(function () {
                if (_this.autofocus) {
                    _this.focusEvent.emit(true);
                }
                _this.clear();
            });
        }
        SearchbarComponent.prototype.updatedList = function (list) {
            this.list = list;
            this.updateQueryFromOutside(list.getFilterValue(this.property) || '');
            if (this.autofocus) {
                this.focusEvent.emit(true);
            }
        };
        SearchbarComponent.prototype.initList = function () {
            var _this = this;
            if (this.listComponent && this.listComponent.list) {
                this.list = this.listComponent.list;
            }
            if (!this.list) {
                return;
            }
            this.property = this.property || this.list.config.label;
            if (!this.property) {
                console.warn('searchbar is missing property to filter..');
            }
            var list = this.list;
            if (!list || !list.change$) {
                // console.warn('no change listener', list);
                return;
            }
            list.change$.subscribe(function (newList) {
                if (!_this.list.config.filter || !_this.list.config.filter[_this.property]) {
                    _this.clear();
                }
            });
        };
        SearchbarComponent.prototype.ngOnInit = function () {
            this.initList();
        };
        SearchbarComponent.prototype.ngOnChanges = function () {
            this.initList();
        };
        /** clears the input query */
        SearchbarComponent.prototype.clear = function () {
            this.updateQueryFromOutside('');
        };
        /** Updates the query string if the change happened outside */
        SearchbarComponent.prototype.updateQueryFromOutside = function (query) {
            if (query !== this.latestQuery) {
                this.query = query;
            }
            /* this.queryValue.next(query); */
            this.cdr.markForCheck();
        };
        /** prevents the event default and disables propagation */
        SearchbarComponent.prototype.preventDefault = function (e) {
            e.preventDefault();
            e.stopPropagation();
            e.stopImmediatePropagation();
        };
        /** After the view is ready, the searchbar needs to be focused (if autofocus is true) */
        SearchbarComponent.prototype.ngAfterViewInit = function () {
            if (this.autofocus) {
                this.focusEvent.emit(true);
            }
        };
        /** Filters the list by the given value, either uses property or list.config.label.
         * If paste is true and the value matches the list.config.identifierPattern,
         * select is emitted immediately with a pseudo item containing the value as item identifier. */
        SearchbarComponent.prototype.filterList = function (value) {
            // this.query = value;
            this.latestQuery = value;
            this.updateQueryFromOutside(value);
            if (this.queryChanged.observers.length) {
                this.queryChanged.emit(value);
                return;
            }
            if (!this.list) {
                console.warn('could not search: no list given!', this.list);
                return;
            }
            if (!this.property && !this.list.config.label) {
                console.warn('cannot filter list: no property set and no label property configured');
                return;
            }
            this.list.filter(this.property || this.list.config.label, value);
        };
        /** called on keydown. if arrow keys are pressed, toggle selection of next/prev elements of list */
        SearchbarComponent.prototype.handleKey = function (e, listComponent) {
            if (listComponent === void 0) { listComponent = this.listComponent; }
            this.keySubject.next({ event: e, query: this.query });
            if (!listComponent || !listComponent.selection) {
                // console.warn('Arrow navigation is disabled: no listComponent given to searchbar');
                return;
            }
            switch (e.key) {
                case 'ArrowUp':
                    listComponent.focusPrev();
                    this.preventDefault(e);
                    break;
                case 'ArrowDown':
                    listComponent.focusNext();
                    this.preventDefault(e);
                    break;
                case 'ArrowRight':
                    listComponent.list.pagination.next();
                    break;
                case 'ArrowLeft':
                    listComponent.list.pagination.prev();
                    break;
                case 'Enter':
                    if (listComponent.focusItem) {
                        if (this.selected.observers.length) {
                            this.selected.emit(listComponent.focusItem);
                        }
                        else {
                            listComponent.selection.toggle(listComponent.focusItem);
                        }
                    }
                    this.enter.emit(e);
                    break;
            }
        };
        return SearchbarComponent;
    }());
    SearchbarComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-searchbar',
                    template: "<div class=\"ec-searchbar\">\n  <input\n    novalidate\n    #inputField\n    [ecFocus]=\"focusEvent\"\n    type=\"text\"\n    [placeholder]=\"placeholder || defaultPlaceholder\"\n    class=\"input\"\n    (ngModelChange)=\"queryValue.next($event)\"\n    (paste)=\"paste.next($event)\"\n    [(ngModel)]=\"query\"\n    (keydown)=\"handleKey($event)\"\n    (blur)=\"blur.emit($event)\"\n    (focus)=\"focus.emit($event)\"\n    [disabled]=\"disabled\"\n  />\n</div>\n",
                    changeDetection: core.ChangeDetectionStrategy.OnPush
                },] }
    ];
    SearchbarComponent.ctorParameters = function () { return [
        { type: router.ActivatedRoute },
        { type: SymbolService },
        { type: core.ChangeDetectorRef }
    ]; };
    SearchbarComponent.propDecorators = {
        disabled: [{ type: core.Input }],
        placeholder: [{ type: core.Input }],
        defaultPlaceholder: [{ type: core.Input }],
        query: [{ type: core.Input }],
        property: [{ type: core.Input }],
        autofocus: [{ type: core.Input }],
        focusEvent: [{ type: core.Input }],
        debounceTime: [{ type: core.Input }],
        list: [{ type: core.Input }],
        listComponent: [{ type: core.Input }],
        selected: [{ type: core.Output }],
        enter: [{ type: core.Output }],
        keyup: [{ type: core.Output }],
        keypressed: [{ type: core.Output }],
        blur: [{ type: core.Output }],
        focus: [{ type: core.Output }],
        pasted: [{ type: core.Output }],
        queryChanged: [{ type: core.Output }]
    };

    /** The GroupPipe filters an array of Item instances by a given property value.
     * It is meant to be used to get only the items with the exact same value. */
    var GroupPipe = /** @class */ (function () {
        function GroupPipe() {
        }
        GroupPipe.prototype.transform = function (items, property, value) {
            if (!property) {
                return items;
            }
            return items.filter(function (item) {
                return item.group(property) === value;
            });
        };
        return GroupPipe;
    }());
    GroupPipe.decorators = [
        { type: core.Pipe, args: [{
                    name: 'group',
                },] }
    ];

    var formTemplate = "\n  <form novalidate [formGroup]=\"group\" (ngSubmit)=\"submit()\" *ngIf=\"group\">\n    <div #wrapper>\n      <ng-content></ng-content>\n    </div>\n    <div *ngIf=\"!wrapper.children.length&&!empty\">\n      <div data-grid>\n        <div\n          [attr.data-col]=\"getColumns(field)\"\n          *ngFor=\"let field of form?.fields | visibleFields:form\"\n          [ngSwitch]=\"field?.getView('input')\"\n          [attr.data-type]=\"field?.type\"\n        >\n          <div [ngClass]=\"'ec-field-group_' + field?.getView('input') + ' ' + field?.classes\"\n          [class.is-read-only]=\"formService.isReadOnly(field, form)\" class=\"field-group\">\n            <label\n              *ngIf=\"showLabel(field, form)\"\n              [for]=\"field.id\"\n              [title]=\"field.property\"\n              class=\"field-group__label\"\n              >{{field.label || field.property}}<i *ngIf=\"showTitle(field,form)\"> {{field.property}}</i></label\n            >\n            <ec-input\n              [field]=\"field\"\n              [group]=\"group\"\n              [item]=\"form\"\n              [component]=\"field.getComponent('form')||field.input\"\n              [formControl]=\"group.get(field.property)\"\n            ></ec-input>\n            <p *ngIf=\"field.description && field.showDescription\">{{field.description}}</p>\n          </div>\n        </div>\n      </div>\n      <button\n        type=\"button\"\n        (click)=\"submit()\"\n        *ngIf=\"showSubmitButton()\"\n        [disabled]=\"group.invalid\"\n        class=\"btn btn_save\"\n      >\n        <ec-icon name=\"save\" *ngIf=\"!config?.submitButtonLabel\"></ec-icon>\n        <span *ngIf=\"config?.submitButtonLabel\"\n          >{{config.submitButtonLabel}}</span\n        >\n      </button>\n      <ec-loader\n        class=\"ec-loader loader is-global\"\n        #formLoader\n      ></ec-loader>\n    </div>\n  </form>\n";

    /** This component renders a form using a FieldConfig Object.
     *
     * Example:
     *
     * <example-url>https://components.entrecode.de/ui/form?e=1</example-url>
     */
    var FormComponent = /** @class */ (function () {
        /** The InputComponents that are used to control the fields */
        /** Injects the services. */
        function FormComponent(loaderService, notificationService, formService, symbol, cdr) {
            this.loaderService = loaderService;
            this.notificationService = notificationService;
            this.formService = formService;
            this.symbol = symbol;
            this.cdr = cdr;
            /** Recent Error notification */
            this.notifications = [];
            /** Emits when the form is submitted. The form can only be submitted if all Validators succeeded. */
            this.submitted = new core.EventEmitter();
            /** Emits when the form has been initialized.  */
            this.ready = new core.EventEmitter();
            /** Emits when a new instance of Form is present */
            this.changed = new core.EventEmitter();
            /** debounce time till changed event/callback will be fired */
            this.debounceTime = 200;
        }
        /** On change, the form instance is (re)created by combining all inputs.
         * If no item is given, an empty form is created using the config.
         * You can also pass just an item to use its config and body.*/
        FormComponent.prototype.ngOnChanges = function (changes) {
            this.config = Object.assign({}, this.config || {}, this.configInput || {});
            if (this.lazy && this.group && changes.value) {
                this.patchValue();
            }
            else {
                this.init();
            }
        };
        /** Returns the column class for data-col, based on configured columns */
        FormComponent.prototype.getColumns = function (field) {
            return field.columns ? "" + field.columns : '12';
        };
        FormComponent.prototype.patchValue = function (value) {
            var _this = this;
            if (value === void 0) { value = this.value; }
            this.value = value;
            if (!this.value || Object.keys(this.value).length === 0) {
                this.group.reset();
            }
            else {
                this.form.fields.forEach(function (field) {
                    var control = _this.group.get(field.property);
                    if (control && control.value && control.value !== _this.value[field.property]) {
                        control.patchValue(_this.value[field.property]);
                    }
                });
            }
        };
        /** Inits the form (if ready) */
        FormComponent.prototype.init = function (item, config) {
            if (item === void 0) { item = this.item; }
            if (config === void 0) { config = this.config; }
            if (this.value) {
                // if value is set, create item from value only
                this.form = new core$1.Form(this.value, config);
            }
            else if (item instanceof core$1.Item) {
                this.form = new core$1.Form(item.getBody(), item.getConfig() || config || {});
            }
            else if (config) {
                this.form = new core$1.Form(null, config);
            }
            this.initGroup();
        };
        /** Initializes the FormGroup which is generated from the current form instance. Sets valueChanges listener */
        FormComponent.prototype.initGroup = function () {
            var _this = this;
            if (!this.form) {
                return;
            }
            this.group = this.formService.getGroup(this.form);
            this.cdr.markForCheck();
            Object.keys(this.group.controls).forEach(function (property) {
                var control = _this.group.controls[property];
                control.valueChanges
                    // TODO: remove when fixed: https://github.com/angular/angular/issues/12540
                    .pipe(operators.distinctUntilChanged(function (a, b) { return JSON.stringify(a) === JSON.stringify(b); }), operators.debounceTime(_this.debounceTime))
                    .subscribe(function (value) {
                    var changedField = _this.form.getField(property);
                    if (changedField.changed) {
                        changedField.changed(value, _this, changedField);
                    }
                });
            });
            this.group.valueChanges
                // TODO: remove when fixed: https://github.com/angular/angular/issues/12540
                .pipe(operators.distinctUntilChanged(function (a, b) { return JSON.stringify(a) === JSON.stringify(b); }), operators.debounceTime(this.debounceTime))
                .subscribe(function (change) {
                _this.changed.emit(_this);
            });
            this.ready.emit(this);
        };
        FormComponent.prototype.patchObjectField = function (property, path, value) {
            var control = this.group.get(property);
            control.patchValue(patchObject(control.value, path, value));
        };
        /** Adds a new field with the given config to the form */
        FormComponent.prototype.addField = function (property, config) {
            var field = this.form.createField(property, config);
            if (field) {
                this.formService.addField(field, this.form, this.group);
            }
        };
        /** Clears the current value */
        FormComponent.prototype.clear = function () {
            delete this.value;
        };
        /* clears the form and uses the given config (falls back to existing one). Renders an empty form. */
        FormComponent.prototype.create = function (config) {
            if (config === void 0) { config = this.config; }
            this.clear();
            this.init(null, config);
        };
        /** edits a given Item instance by using its config and body. */
        FormComponent.prototype.edit = function (item) {
            this.init(item);
        };
        /** edits a given value by creating an item and calling edit. */
        FormComponent.prototype.editValue = function (value, config) {
            if (config === void 0) { config = this.config; }
            var item = new core$1.Item(value, config);
            this.edit(item);
        };
        /** Method that is invoked when the form is submitted.*/
        FormComponent.prototype.submit = function () {
            var _this = this;
            var submit = this.form
                .save(this.group.value)
                .then(function (form) {
                _this.edit(form);
                _this.group.markAsPristine();
                _this.submitted.emit(_this.form);
                if (_this.silent) {
                    return;
                }
                _this.notificationService.emit({
                    // TODO pull out to entry-form?
                    title: _this.symbol.resolve('success.save'),
                    type: 'success',
                    hide: _this.notifications,
                });
            })
                .catch(function (err) {
                console.error(err, err.errors);
                if (_this.silent) {
                    return;
                }
                _this.notificationService.emit({
                    title: _this.symbol.resolve('error.save'),
                    error: err,
                    sticky: true,
                    hide: _this.notifications,
                    replace: _this.notifications,
                });
                throw new Error(err);
            });
            this.loaderService.wait(submit, this.loader || this.defaultLoader);
            return submit;
        };
        /** Decides if the submit button should be rendered or not based on config */
        FormComponent.prototype.showSubmitButton = function () {
            return this.submitButton !== false && !this.config.hideSubmitButton;
        };
        /** Determindes if the given field's label should be shown based on hideFormLabel+hideFormLabelIfEmpty flags */
        FormComponent.prototype.showLabel = function (field, form) {
            if (!field || !form) {
                return false;
            }
            return !field.hideFormLabel && (!field.hideFormLabelIfEmpty || !!form.resolve(field.property));
        };
        /** Determines if the field labels should always show the field property (EDITOR-431) */
        FormComponent.prototype.showTitle = function (field, form) {
            if (!field || !form) {
                return false;
            }
            return field.label && field.showTitle && field.property !== field.label;
        };
        /** Returns the current value of the form control group. When passing a property, it directly returns the property value. */
        FormComponent.prototype.getValue = function (property) {
            if (property) {
                return this.group.value[property];
            }
            return this.group.value;
        };
        /** Returns an Error containing all field validator errors as subErrors.  */
        FormComponent.prototype.getErrors = function (formComponent, touchedOnly) {
            if (touchedOnly === void 0) { touchedOnly = true; }
            var errs = Object.keys(formComponent.group.controls).reduce(function (errors, property) {
                var control = formComponent.group.get(property);
                if ((touchedOnly && !control.touched) || !control.errors) {
                    return errors;
                }
                return errors.concat({ property: property, errors: control.errors });
            }, []);
            if (!errs.length) {
                return;
            }
            var error = new Error('Validierungsfehler');
            error.subErrors = errs.map(function (_a) {
                var property = _a.property, errors = _a.errors;
                var label = formComponent.form.getField(property).label || property;
                return new Error(label + ': ' + Object.values(errors).join(', '));
            });
            return error;
        };
        return FormComponent;
    }());
    FormComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-form',
                    template: formTemplate,
                    changeDetection: core.ChangeDetectionStrategy.OnPush
                },] }
    ];
    FormComponent.ctorParameters = function () { return [
        { type: LoaderService },
        { type: NotificationsService },
        { type: FormService },
        { type: SymbolService },
        { type: core.ChangeDetectorRef }
    ]; };
    FormComponent.propDecorators = {
        configInput: [{ type: core.Input, args: ['config',] }],
        item: [{ type: core.Input }],
        value: [{ type: core.Input }],
        empty: [{ type: core.Input }],
        submitButton: [{ type: core.Input }],
        silent: [{ type: core.Input }],
        loader: [{ type: core.Input }],
        submitted: [{ type: core.Output }],
        ready: [{ type: core.Output }],
        changed: [{ type: core.Output }],
        debounceTime: [{ type: core.Input }],
        lazy: [{ type: core.Input }],
        defaultLoader: [{ type: core.ViewChild, args: [LoaderComponent,] }]
    };
    function patchObject(o, path, value) {
        var _a, _b;
        var p = path.split('.');
        if (p.length === 1) {
            return Object.assign(Object.assign({}, (o || {})), (_a = {}, _a[p[0]] = value, _a));
        }
        return Object.assign(Object.assign({}, (o || {})), (_b = {}, _b[p[0]] = patchObject((o || {})[p[0]], p.slice(1).join('.'), value), _b));
    }

    /** The VisibleFieldsPipe filters an array of Fields to only give back the ones that have form NOT set to false. */
    var VisibleFieldsPipe = /** @class */ (function () {
        function VisibleFieldsPipe(formService) {
            this.formService = formService;
        }
        /** Filters out all fields that should not be displayed in a regular form */
        VisibleFieldsPipe.prototype.transform = function (fields, form) {
            var _this = this;
            return fields.filter(function (field) { return _this.formService.shouldBePartOfForm(field, form) && !field.hideInForm; });
        };
        return VisibleFieldsPipe;
    }());
    VisibleFieldsPipe.decorators = [
        { type: core.Pipe, args: [{
                    name: 'visibleFields',
                },] }
    ];
    VisibleFieldsPipe.ctorParameters = function () { return [
        { type: FormService }
    ]; };

    /** Input for a datetime.
     *
     * <example-url>https://components.entrecode.de/ui/datetime?e=1</example-url>
     *
     */
    var DatetimeComponent = /** @class */ (function () {
        function DatetimeComponent() {
            /** The form control that holds the date */
            this.formControl = new forms.FormControl();
            /** If true, the time will not be in the emitted value */
            this.dateOnly = false;
            /** The input's placeholder */
            this.placeholder = '';
            /** Change propagation for ControlValueAccessor */
            this.propagateChange = function (_) { };
        }
        /** Selects the given Date when the model changes. */
        DatetimeComponent.prototype.writeValue = function (value) {
            this.calendar.writeValue(value);
        };
        /** registerOnChange implementation of ControlValueAccessor */
        DatetimeComponent.prototype.registerOnChange = function (fn) {
            this.propagateChange = fn;
        };
        /** registerOnTouched implementation of ControlValueAccessor */
        DatetimeComponent.prototype.registerOnTouched = function () { };
        DatetimeComponent.prototype.setDisabledState = function (isDisabled) {
            this.disabled = isDisabled;
        };
        return DatetimeComponent;
    }());
    DatetimeComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-datetime',
                    template: "<div class=\"ec-datetime-picker\">\n  <div class=\"input-group\">\n    <input\n      class=\"input\"\n      [value]=\"calendar.inputValue\"\n      (input)=\"calendar.input($event.target.value)\"\n      (focus)=\"calendarPop.show()\"\n      (blur)=\"calendarPop.hide()\"\n      [placeholder]=\"placeholder\"\n      [disabled]=\"disabled\"\n    />\n    <div class=\"input-group__addon\">\n      <a (click)=\"calendarPop.toggle()\">\n        <ec-icon name=\"calendar\"></ec-icon>\n      </a>\n    </div>\n  </div>\n  <ec-pop class=\"ec-datetime-select\" #calendarPop (mousedown)=\"$event.preventDefault()\">\n    <ec-calendar\n      #calendar\n      [formControl]=\"formControl\"\n      [disableTime]=\"disableTime\"\n      [dateOnly]=\"dateOnly\"\n      [date]=\"date\"\n    ></ec-calendar>\n  </ec-pop>\n</div>\n",
                    providers: [
                        {
                            provide: forms.NG_VALUE_ACCESSOR,
                            useExisting: core.forwardRef(function () { return DatetimeComponent; }),
                            multi: true,
                        },
                    ]
                },] }
    ];
    DatetimeComponent.propDecorators = {
        date: [{ type: core.Input }],
        formControl: [{ type: core.Input }],
        calendar: [{ type: core.ViewChild, args: [calendar.CalendarComponent, { static: true },] }],
        disableTime: [{ type: core.Input }],
        dateOnly: [{ type: core.Input }],
        placeholder: [{ type: core.Input }]
    };

    /** The toggle component is an alternative to the default boolean checkbox with fancier style.
     * It is used in the default input template for the view 'toggle'. */
    var ToggleComponent = /** @class */ (function () {
        function ToggleComponent() {
            this.id = 'toggle' + Date.now();
            /* Propagates change*/
            this.propagateChange = function (_) { };
        }
        /** Toggles the value */
        ToggleComponent.prototype.toggle = function () {
            this.value = !this.value;
            this.propagateChange(this.value);
        };
        /** writes incoming value */
        ToggleComponent.prototype.writeValue = function (value) {
            this.value = value;
        };
        /** Registers change callback */
        ToggleComponent.prototype.registerOnChange = function (fn) {
            this.propagateChange = fn;
        };
        /** Register Touch */
        ToggleComponent.prototype.registerOnTouched = function () { };
        return ToggleComponent;
    }());
    ToggleComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-toggle',
                    template: "<div class=\"ec-toggle xui-toggle\">\n  <input [id]=\"id\" type=\"checkbox\" [checked]=\"value\" (click)=\"toggle()\" />\n  <label [for]=\"id\" class=\"xui-toggle__label\">\n    <div class=\"xui-toggle__switch\" [class.is-active]=\"value\"></div>\n    {{ placeholder }}\n  </label>\n</div>\n",
                    providers: [
                        {
                            provide: forms.NG_VALUE_ACCESSOR,
                            useExisting: core.forwardRef(function () { return ToggleComponent; }),
                            multi: true,
                        },
                    ]
                },] }
    ];
    ToggleComponent.propDecorators = {
        placeholder: [{ type: core.Input }],
        id: [{ type: core.Input }]
    };

    /** This pipe slices an array after the nth item */
    var MaxItemsPipe = /** @class */ (function () {
        function MaxItemsPipe() {
        }
        MaxItemsPipe.prototype.transform = function (array, maxItems, start) {
            if (array === void 0) { array = []; }
            if (start === void 0) { start = 0; }
            return array.slice(start, maxItems);
        };
        return MaxItemsPipe;
    }());
    MaxItemsPipe.decorators = [
        { type: core.Pipe, args: [{
                    name: 'maxItems',
                },] }
    ];

    /** The symbol pipe translates Symbol names to their content.
     *
     * ```html
     * {{ 'entry.saved' | symbol }}
     * ```
     *
     * See SymbolService for more info about Symbols.
     */
    var SymbolPipe = /** @class */ (function () {
        /** Depends on the SymbolService */
        function SymbolPipe(symbol) {
            this.symbol = symbol;
        }
        /** Calls SymbolService.resolve with the given name */
        SymbolPipe.prototype.transform = function (name) {
            if (!name) {
                return '';
            }
            return this.symbol.resolve(name) || '';
        };
        return SymbolPipe;
    }());
    SymbolPipe.decorators = [
        { type: core.Pipe, args: [{
                    name: 'symbol',
                },] },
        { type: core.Injectable }
    ];
    SymbolPipe.ctorParameters = function () { return [
        { type: SymbolService }
    ]; };

    /**
     * Collects all localization related components and services.
     */
    var SymbolModule = /** @class */ (function () {
        function SymbolModule() {
        }
        return SymbolModule;
    }());
    SymbolModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [common.CommonModule],
                    declarations: [SymbolPipe],
                    exports: [SymbolPipe],
                    providers: [SymbolService],
                },] }
    ];

    var PeriodComponent = /** @class */ (function () {
        function PeriodComponent() {
            /** Output that emits when the value changes */
            this.changed = new core.EventEmitter();
            /** The form control that holds the date */
            this.formControl = new forms.FormControl();
            /** If true, no time values can be selected */
            this.disableTime = new forms.FormControl();
            /** The input's placeholder */
            this.placeholder = '';
            /** The current value */
            this.value = '';
            this.amount = 1;
            this.period = 'D';
            this.customMode = false;
            /** Change propagation for ControlValueAccessor */
            this.propagateChange = function (_) { };
        }
        PeriodComponent.prototype.parseValue = function (value) {
            var _a;
            return ((_a = value === null || value === void 0 ? void 0 : value.match(/^P(?:(\d+(?:\.\d+)?)(D|W|M|Y))?(?:T(\d+(?:\.\d+)?)(S|M|H))?$/)) === null || _a === void 0 ? void 0 : _a.slice(1)) || [];
        };
        // simple mode: update value when amount and period change + propagate change
        PeriodComponent.prototype.updateSimple = function (amount, period) {
            var isTimePeriod = (period === null || period === void 0 ? void 0 : period[0]) === 'T';
            var value = 'P' + (isTimePeriod ? 'T' : '') + (amount !== null && amount !== void 0 ? amount : '') + (isTimePeriod ? period === null || period === void 0 ? void 0 : period.slice(1) : period !== null && period !== void 0 ? period : '');
            // console.log('change', value);
            this.value = value;
            this.propagateChange(value);
        };
        // custom mode: update amount and period when value changes + propagate change
        PeriodComponent.prototype.updateCustom = function () {
            var _this = this;
            setTimeout(function () {
                _this.propagateChange(_this.value);
            });
        };
        PeriodComponent.prototype.clear = function () {
            console.log('clear');
            this.value = null;
            this.period = undefined;
            this.amount = undefined;
            this.propagateChange(this.value);
        };
        // parse current value and update amount and period => should only do if 
        PeriodComponent.prototype.updateAmountAndPeriod = function (value) {
            if (value === void 0) { value = this.value; }
            if (!this.isSimpleValue(value)) {
                throw new Error('cannot update amount and period from a non simple value!');
            }
            if (!value) {
                this.amount = undefined;
                this.period = undefined;
            }
            var _c = __read(this.parseValue(value), 4), dateAmount = _c[0], datePeriod = _c[1], timeAmount = _c[2], timePeriod = _c[3];
            this.amount = dateAmount !== undefined ? +dateAmount : +timeAmount;
            this.period = datePeriod !== undefined ? datePeriod : 'T' + timePeriod;
        };
        PeriodComponent.prototype.toggleMode = function () {
            var _this = this;
            if (this.customMode) {
                try {
                    this.updateAmountAndPeriod(); // before switching to simple mode, update form values
                }
                catch (error) {
                    console.log('cannot switch to simple mode when value is complex!');
                    return;
                }
            }
            this.customMode = !this.customMode;
            if (this.customMode) { // after transitioning to custom mode, focus input
                setTimeout(function () {
                    var _a, _b;
                    (_b = (_a = _this.customInput) === null || _a === void 0 ? void 0 : _a.nativeElement) === null || _b === void 0 ? void 0 : _b.focus();
                });
            }
        };
        PeriodComponent.prototype.isSimpleValue = function (value) {
            var _c = __read(this.parseValue(value), 4), _ = _c[0], datePeriod = _c[1], __ = _c[2], timePeriod = _c[3];
            return !value || !!timePeriod !== !!datePeriod;
        };
        /** Selects the given Date when the model changes. */
        PeriodComponent.prototype.writeValue = function (value) {
            if (!value) {
                this.amount = undefined;
                this.period = undefined;
                this.value = value;
                return;
            }
            this.value = value;
            try {
                this.updateAmountAndPeriod(value);
                this.customMode = false;
            }
            catch (error) {
                console.log('error', error);
                this.customMode = true;
            }
        };
        /** registerOnChange implementation of ControlValueAccessor */
        PeriodComponent.prototype.registerOnChange = function (fn) {
            this.propagateChange = fn;
        };
        /** registerOnTouched implementation of ControlValueAccessor */
        PeriodComponent.prototype.registerOnTouched = function () { };
        PeriodComponent.prototype.setDisabledState = function (isDisabled) {
            this.disabled = isDisabled;
        };
        return PeriodComponent;
    }());
    PeriodComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-period',
                    template: "<div class=\"input-group\">\n  <input\n    class=\"input\"\n    type=\"number\"\n    (ngModelChange)=\"updateSimple($event, period)\"\n    [(ngModel)]=\"amount\"\n    style=\"width: 150px\"\n    *ngIf=\"!customMode\"\n  />\n  <div class=\"x-space-1\" *ngIf=\"!customMode\"></div>\n  <select class=\"input\" (ngModelChange)=\"updateSimple(amount, $event)\" [(ngModel)]=\"period\" *ngIf=\"!customMode\">\n    <option *ngIf=\"!disableTime\" value=\"TS\">Sekunde{{ amount > 1 ? 'n' : '' }}</option>\n    <option *ngIf=\"!disableTime\" value=\"TM\">Minute{{ amount > 1 ? 'n' : '' }}</option>\n    <option *ngIf=\"!disableTime\" value=\"TH\">Stunde{{ amount > 1 ? 'n' : '' }}</option>\n    <option *ngIf=\"!disableTime\" value=\"D\">Tag{{ amount > 1 ? 'e' : '' }}</option>\n    <option value=\"W\">Woche{{ amount > 1 ? 'n' : '' }}</option>\n    <option value=\"M\">Monat{{ amount > 1 ? 'e' : '' }}</option>\n    <option value=\"Y\">Jahr{{ amount > 1 ? 'e' : '' }}</option>\n  </select>\n  <input\n    autocomplete=\"off\"\n    class=\"input\"\n    type=\"text\"\n    (ngModelChange)=\"updateCustom()\"\n    [(ngModel)]=\"value\"\n    [class.is-hidden]=\"!customMode\"\n    [placeholder]=\"placeholder\"\n    #customInput\n  />\n  <a (click)=\"toggleMode()\" class=\"input-group__addon btn btn_minor\" [class.is-disabled]=\"customMode && !isSimpleValue(value)\">\n    <ec-icon name=\"code\"></ec-icon>\n  </a>\n  <a (click)=\"clear()\" class=\"input-group__addon btn btn_minor\" [class.is-disabled]=\"!value\">\n    <ec-icon name=\"trash\"></ec-icon>\n  </a>\n</div>\n",
                    providers: [
                        {
                            provide: forms.NG_VALUE_ACCESSOR,
                            useExisting: core.forwardRef(function () { return PeriodComponent; }),
                            multi: true,
                        },
                    ]
                },] }
    ];
    PeriodComponent.ctorParameters = function () { return []; };
    PeriodComponent.propDecorators = {
        changed: [{ type: core.Output }],
        formControl: [{ type: core.Input }],
        disableTime: [{ type: core.Input }],
        customInput: [{ type: core.ViewChild, args: ['customInput',] }],
        placeholder: [{ type: core.Input }]
    };

    var FormModule = /** @class */ (function () {
        function FormModule() {
        }
        return FormModule;
    }());
    FormModule.decorators = [
        { type: core.NgModule, args: [{
                    entryComponents: [DefaultInputComponent, DefaultOutputComponent],
                    declarations: [
                        FormComponent,
                        DatetimeComponent,
                        VisibleFieldsPipe,
                        MaxItemsPipe,
                        ToggleComponent,
                        DefaultInputComponent,
                        DefaultOutputComponent,
                        PeriodComponent,
                    ],
                    imports: [
                        common.CommonModule,
                        forms.FormsModule,
                        forms.ReactiveFormsModule,
                        PopModule,
                        IoModule,
                        LoaderModule,
                        IconModule,
                        SymbolModule,
                        calendar.CalendarModule,
                        UtilityModule,
                    ],
                    exports: [
                        UtilityModule,
                        forms.ReactiveFormsModule,
                        IoModule,
                        FormComponent,
                        DatetimeComponent,
                        PopModule,
                        VisibleFieldsPipe,
                        MaxItemsPipe,
                        ToggleComponent,
                        PeriodComponent,
                    ],
                    providers: [
                        FormService,
                    ],
                },] }
    ];

    var ListModule = /** @class */ (function () {
        function ListModule() {
        }
        return ListModule;
    }());
    ListModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [
                        ListComponent,
                        ListItemsComponent,
                        ListHeaderComponent,
                        PaginationComponent,
                        SearchbarComponent,
                        GroupPipe,
                    ],
                    imports: [common.CommonModule, forms.FormsModule, FormModule, IconModule, SymbolModule, UtilityModule],
                    exports: [
                        ListComponent,
                        ListItemsComponent,
                        ListHeaderComponent,
                        PaginationComponent,
                        SearchbarComponent,
                        GroupPipe,
                        FormModule,
                    ],
                    providers: [ListConfigService],
                },] }
    ];

    var selectTemplate = "<div class=\"ec-select\" [class.ec-select_solo]=\"solo\"\n[class.is-empty]=\"selection?.isEmpty()\" (click)=\"activate($event)\" [class.has-searchbar]=\"!config?.disableSearchbar\">\n  <ul class=\"ec-select-selection\" dndDropzone (dndDrop)=\"onDrop($event)\">\n    <li *ngIf=\"config?.disableSearchbar&&selection?.isEmpty()\">\n      <span class=\"ec-select__placeholder\">\n        {{placeholder||'make your selection?...'}}\n      </span>\n    </li>\n    <li *ngFor=\"let selected of selection?.display;let i = index\" [dndDisableIf]=\"solo||config?.disableDrag\"\n      [class.is-dragged]=\"selected===dragged\" [class.is-draggable]=\"solo||!config?.disableDrag\" dndEffectAllowed=\"move\"\n      [dndDraggable]=\"i\" (dndStart)=\"onDragStart(selected,$event,item)\" (dndCanceled)=\"cancelDrag(selected,$event,item)\"\n      (dndEnd)=\"cancelDrag(selected,$event,item)\" #item>\n      <span [class.ec-select-selected]=\"!solo\" [class.ec-select-selected_solo]=\"solo\" (click)=\"clickItem(selected,$event)\">\n        {{selected.display()}}\n        <a (click)=\"removeItem(selected,$event)\" *ngIf=\"!config?.disableRemove\">&times;</a>\n      </span>\n    </li>\n    <li dndPlaceholderRef>\n      <div class=\"drag-placeholder\" style=\"width: 48px;\"></div>\n    </li>\n    <li *ngIf=\"!config?.disableSearchbar\" class=\"ec-select__searchbar\">\n      <ec-searchbar [autofocus]=\"false\" [property]=\"config?.label\" [placeholder]=\"placeholder\"\n        (focus)=\"focus($event)\" (keypressed)=\"handleKey($event,dropdownList)\" [focusEvent]=\"focusEvent\"\n        (queryChanged)=\"filterDropdownList(dropdownList,$event)\"></ec-searchbar>\n    </li>\n  </ul>\n  <ec-pop class=\"ec-select-options\" [hideOnClickOutside]=\"true\" #dropdown>\n    <ec-loader class=\"ec-loader loader is-local\" #dropdownLoader></ec-loader>\n    <ec-list (changed)=\"searchbar.updatedList($event)\" #dropdownList [list]=\"list\" (columnClicked)=\"listItemClicked($event, dropdownList)\"\n      [selection]=\"selection\"></ec-list>\n  </ec-pop>\n</div>";

    /**
     * The SelectComponent will render a dropdown of a given list.
     *
     * <example-url>https://components.entrecode.de/ui/select?e=1</example-url>
     * */
    var SelectComponent = /** @class */ (function () {
        function SelectComponent(elementRef, cdr) {
            var _this = this;
            this.elementRef = elementRef;
            this.cdr = cdr;
            /** Event emitter on item selection */
            this.changed = new core.EventEmitter();
            /** Event emitter on selected item click */
            this.itemClick = new core.EventEmitter();
            /** Emits when an item is being removed */
            this.remove = new core.EventEmitter();
            /** Emits when an item is being added */
            this.add = new core.EventEmitter();
            /** Emits the query when enter is pressed */
            this.enter = new core.EventEmitter();
            /** Subject that is nexted when enter is pressed */
            this.enterPressed = new rxjs.Subject();
            /** Event emitter to focus input */
            this.focusEvent = new core.EventEmitter();
            /** Subject that is nexted when an item is being selected (clicked or entered on) */
            this.toggleItem = new rxjs.Subject();
            /** Propagates formControl/ngModel changes */
            this.propagateChange = function (_) { };
            this.toggleItem.asObservable().subscribe(function (item) {
                if (_this.selection.has(item)) {
                    _this.removeItem(item);
                }
                else {
                    _this.addItem(item);
                }
            });
            this.enterPressed.asObservable().subscribe(function (query) {
                _this.enter.emit(_this);
            });
        }
        SelectComponent.prototype.getParentTree = function (el, tree) {
            if (tree === void 0) { tree = []; }
            if (el.parentNode) {
                return tree.concat([el.parentNode]);
            }
            return tree;
        };
        SelectComponent.prototype.ngOnInit = function () {
            this.initSelection();
        };
        SelectComponent.prototype.ngOnChanges = function () {
            this.initSelection();
        };
        /** creates the collection from the config */
        SelectComponent.prototype.initSelection = function () {
            var _this = this;
            if (this.values) {
                if (this.list) {
                    console.warn('ec-select: list is overwritten by values', this.list);
                }
                this.list = new core$1.List(this.values, this.config);
                delete this.values;
            }
            if (this.list && !this.config) {
                this.config = this.list.config;
            }
            if (!this.config) {
                // || !this.config.selectMode
                return;
            }
            this.config = Object.assign({ solo: this.solo }, this.config);
            var value = Array.isArray(this.value) ? this.value : this.value ? [this.value] : [];
            if (!this.formControl) {
                this.formControl = new forms.FormControl(value || []);
            }
            this.selection = new core$1.Selection(value, this.config);
            this.cdr.markForCheck();
            this.selection.update$.subscribe(function () {
                _this.onChange();
            });
        };
        /** Called when the model changes */
        SelectComponent.prototype.writeValue = function (value) {
            this.use(value, false);
        };
        /** Removes the given item from selection */
        SelectComponent.prototype.removeItem = function (item, e) {
            if (e) {
                e.preventDefault();
                e.stopPropagation();
                e.stopImmediatePropagation();
            }
            if (this.remove.observers.length) {
                this.remove.emit(item);
            }
            else {
                this.selection.remove(item);
            }
        };
        /** Adds the given ite, emits add output if observed */
        SelectComponent.prototype.addItem = function (item) {
            if (this.add.observers.length) {
                this.add.emit(item);
            }
            else {
                this.selection.toggle(item);
            }
            this.cdr.markForCheck();
        };
        SelectComponent.prototype.getArray = function (value) {
            return Array.isArray(value) ? value : value ? [value] : [];
        };
        /** Uses the given value as selection items */
        SelectComponent.prototype.use = function (value, event) {
            if (event === void 0) { event = true; }
            Object.assign(this.config || {}, { solo: this.solo });
            this.value = this.getArray(value);
            if (!this.selection) {
                return;
            }
            if (!this.value.length) {
                this.selection.removeAll();
                return;
            }
            Object.assign(this.config, { selection: this.selection });
            var list = new core$1.List(this.value, this.config);
            this.selection.replaceWith(list.items, event);
        };
        /** Initializes either with values, collection or list. Creates Selection with config. */
        SelectComponent.prototype.useConfig = function (config) {
            if (config === void 0) { config = {}; }
            this.config = Object.assign(this.config || {}, config);
            this.use(this.value, false);
            this.initSelection();
        };
        /** Is called when a selected item is clicked*/
        SelectComponent.prototype.clickItem = function (item, e) {
            if (this.itemClick.observers.length) {
                this.itemClick.emit(item);
            }
        };
        /** Select handler. Toggles selection. */
        SelectComponent.prototype.listItemClicked = function (item, list) {
            this.toggleItem.next(item);
            // TODO: prevent default to prevent bluring searchbear.
            // refocusing is not possible because that will activate the pop again..
            if (list && list.list.isFiltered()) {
                list.list.clearFilter();
            }
        };
        SelectComponent.prototype.focus = function (e) {
            if (this.dropdown && !this.dropdown.active) {
                this.dropdown.show();
            }
        };
        SelectComponent.prototype.hasSoloSelection = function () {
            return this.config.solo && !this.selection.isEmpty();
        };
        SelectComponent.prototype.focusSearchbar = function () {
            if (this.searchbar) {
                this.searchbar.focusEvent.emit(true);
            }
        };
        /** Fires on selection change. Hides dropdown if solo */
        SelectComponent.prototype.onChange = function () {
            this.changed.emit(this.selection);
            if (this.dropdown && this.hasSoloSelection()) {
                this.dropdown.hide();
            }
            else {
                this.focusSearchbar();
            }
            this.value = this.selection.items.map(function (i) { return i.resolve(); });
            return this.propagateChange(this.selection.getValue());
        };
        /** registers change method. (handled by angular) */
        SelectComponent.prototype.registerOnChange = function (fn) {
            this.propagateChange = fn;
        };
        SelectComponent.prototype.registerOnTouched = function () { };
        /** is called when an element is dragged by the user. hides element in selection */
        SelectComponent.prototype.onDragStart = function (item, e, target) {
            if (target === void 0) { target = e.target; }
            this.dragged = item;
            window.requestAnimationFrame(function () {
                target.style.display = 'none';
            });
        };
        /** called when the element is dropped. moves item in selection. */
        SelectComponent.prototype.onDrop = function (e) {
            if (e.isExternal) {
                return;
            }
            var index = e.index;
            if (this.selection.index(this.dragged) < e.index) {
                index -= 1;
            }
            this.selection.move(this.dragged, index);
        };
        /** is called when the drag stops in any kind of way. */
        SelectComponent.prototype.cancelDrag = function (item, e, target) {
            if (target === void 0) { target = e.target; }
            delete this.dragged;
            window.requestAnimationFrame(function () {
                target.style.display = 'inherit';
            });
        };
        SelectComponent.prototype.activate = function (e) {
            if (this.dropdown) {
                this.dropdown.show(e);
            }
            if (this.searchbar) {
                this.searchbar.focusEvent.emit(true);
            }
        };
        SelectComponent.prototype.preventDefault = function (e) {
            e.preventDefault();
            e.stopPropagation();
            e.stopImmediatePropagation();
        };
        SelectComponent.prototype.canRemove = function () {
            return !this.config || !this.config.disableRemove;
        };
        SelectComponent.prototype.handleKey = function (e, list) {
            var event = e.event, query = e.query;
            if (!list) {
                console.warn('no dropdown given');
                return;
            }
            switch (event.key) {
                case 'ArrowUp':
                    if (!this.dropdown.active) {
                        this.dropdown.show(event);
                    }
                    else {
                        list.focusPrev();
                    }
                    this.preventDefault(event);
                    break;
                case 'ArrowDown':
                    if (!this.dropdown.active) {
                        this.dropdown.show(event);
                    }
                    else {
                        list.focusNext();
                    }
                    this.preventDefault(event);
                    break;
                case 'ArrowRight':
                    list.list.pagination.next();
                    this.preventDefault(event);
                    break;
                case 'ArrowLeft':
                    list.list.pagination.prev();
                    this.preventDefault(event);
                    break;
                case 'Enter':
                    if (list.focusItem) {
                        if (list.list.isFiltered()) {
                            list.list.clearFilter();
                        }
                        this.toggleItem.next(list.focusItem);
                    }
                    else {
                        this.enterPressed.next(query);
                    }
                    this.preventDefault(event);
                    break;
                case 'Backspace':
                    if (!this.selection.isEmpty() && query === '' && this.canRemove()) {
                        this.removeItem(this.selection.items[this.selection.items.length - 1]);
                        this.preventDefault(event);
                    }
                    break;
                case 'Tab':
                    if (this.dropdown) {
                        this.dropdown.hide();
                    }
                    break;
                default:
                    return;
            }
        };
        SelectComponent.prototype.filterDropdownList = function (listComponent, query) {
            if (!listComponent) {
                /* console.warn('cannot filter yet: list not ready'); */
                return;
            }
            this.dropdown.show();
            Promise.resolve(listComponent.filter(this.config.label, query)).then(function () {
                listComponent.focusFirst();
            });
        };
        SelectComponent.prototype.setDisabledState = function (isDisabled) {
            this.disabled = isDisabled;
        };
        return SelectComponent;
    }());
    SelectComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-select',
                    /*   templateUrl: './select.component.html', */
                    template: selectTemplate,
                    encapsulation: core.ViewEncapsulation.None,
                    changeDetection: core.ChangeDetectionStrategy.OnPush,
                    providers: [
                        {
                            provide: forms.NG_VALUE_ACCESSOR,
                            useExisting: core.forwardRef(function () { return SelectComponent; }),
                            multi: true,
                        },
                    ]
                },] }
    ];
    SelectComponent.ctorParameters = function () { return [
        { type: core.ElementRef },
        { type: core.ChangeDetectorRef }
    ]; };
    SelectComponent.propDecorators = {
        config: [{ type: core.Input }],
        disabled: [{ type: core.Input }],
        value: [{ type: core.Input }],
        selection: [{ type: core.Input }],
        placeholder: [{ type: core.Input }],
        changed: [{ type: core.Output }],
        itemClick: [{ type: core.Output }],
        remove: [{ type: core.Output }],
        add: [{ type: core.Output }],
        enter: [{ type: core.Output }],
        enterPressed: [{ type: core.Output }],
        list: [{ type: core.Input }],
        values: [{ type: core.Input }],
        solo: [{ type: core.Input }],
        focusEvent: [{ type: core.Input }],
        dropdown: [{ type: core.ViewChild, args: ['dropdown', { static: true },] }],
        dropdownLoader: [{ type: core.ViewChild, args: ['dropdownLoader', { static: true },] }],
        dropdownList: [{ type: core.ViewChild, args: [ListComponent, { static: true },] }],
        searchbar: [{ type: core.ViewChild, args: [SearchbarComponent,] }],
        formControl: [{ type: core.Input }]
    };

    var ActionbarComponent = /** @class */ (function (_super) {
        __extends(ActionbarComponent, _super);
        function ActionbarComponent(elementRef, cdr) {
            var _this = _super.call(this, elementRef, cdr) || this;
            _this.elementRef = elementRef;
            _this.cdr = cdr;
            _this.root = 'ROOT'; // id of root stack item
            _this.config = {
                label: 'title',
                identifier: 'id',
                fields: {
                    title: {},
                },
            };
            _this.actionStack = {};
            _this.add.subscribe(function (item) {
                if (item.getBody().select !== false) {
                    _this.selection.add(item);
                }
                if (item.getBody().action) {
                    item.getBody().action(item, _this);
                }
                if (item.getBody().children) {
                    _this.loadActions(item.getBody().children);
                }
                // this.searchbar.clear();
            });
            _this.remove.subscribe(function (item) {
                _this.selection.remove(item);
                _this.loadActionsBefore();
            });
            return _this;
        }
        ActionbarComponent.prototype.loadActionsBefore = function () {
            var actionsBefore = this.actionStack[this.currentID()];
            if (actionsBefore) {
                this.loadActions(actionsBefore);
            }
        };
        ActionbarComponent.prototype.ngOnInit = function () {
            this.loadActions(this.actions);
        };
        ActionbarComponent.prototype.currentID = function () {
            if (!this.selection || this.selection.isEmpty()) {
                return this.root;
            }
            return this.selection.items[this.selection.items.length - 1].id();
        };
        ActionbarComponent.prototype.reset = function () {
            this.selection.removeAll();
            this.loadActions(this.actionStack[this.currentID()]);
        };
        ActionbarComponent.prototype.currentActions = function () {
            return this.actionStack[this.currentID()];
        };
        ActionbarComponent.prototype.loadActions = function (actions, addToStack) {
            if (addToStack === void 0) { addToStack = true; }
            return __awaiter(this, void 0, void 0, function () {
                var resolved;
                var _this = this;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            if (!(typeof actions === 'function')) return [3 /*break*/, 2];
                            return [4 /*yield*/, Promise.resolve(actions(this.actionStack, this))];
                        case 1:
                            resolved = _a.sent();
                            return [3 /*break*/, 3];
                        case 2:
                            resolved = [].concat(actions);
                            _a.label = 3;
                        case 3:
                            if (addToStack) {
                                this.actionStack[this.currentID()] = actions;
                            }
                            this.list = new core$1.List(resolved, Object.assign({ size: 1000 }, this.config));
                            if (resolved.length > this.list.config) {
                                console.warn('actions exceed list size...');
                            }
                            if (!this.selection) {
                                this.initSelection();
                            }
                            setTimeout(function () {
                                if (_this.dropdownList) {
                                    _this.dropdownList.focusFirst();
                                }
                            });
                            return [2 /*return*/];
                    }
                });
            });
        };
        ActionbarComponent.prototype.getPath = function () {
            return this.selection.getValue();
        };
        return ActionbarComponent;
    }(SelectComponent));
    ActionbarComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ec-actionbar',
                    template: selectTemplate
                },] }
    ];
    ActionbarComponent.ctorParameters = function () { return [
        { type: core.ElementRef },
        { type: core.ChangeDetectorRef }
    ]; };
    ActionbarComponent.propDecorators = {
        root: [{ type: core.Input }],
        config: [{ type: core.Input }],
        actions: [{ type: core.Input }]
    };

    var SelectModule = /** @class */ (function () {
        function SelectModule() {
        }
        return SelectModule;
    }());
    SelectModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [common.CommonModule, ListModule, ngxDragDrop.DndModule, LoaderModule],
                    declarations: [SelectComponent, ActionbarComponent],
                    exports: [ListModule, SelectComponent, ActionbarComponent, ngxDragDrop.DndModule],
                    providers: [],
                },] }
    ];

    /** Contains all icons that are available in ec-icons font. */
    var ecIcons = [
        { name: 'add' },
        { name: 'add-circle' },
        { name: 'alarm' },
        { name: 'alarm-clock' },
        { name: 'alarm-silent' },
        { name: 'align-center' },
        { name: 'align-justify' },
        { name: 'align-left' },
        { name: 'align-right' },
        { name: 'all-caps' },
        { name: 'brackets' },
        { name: 'angle-tool' },
        { name: 'arrange-1-to-9' },
        { name: 'arrange-9-to-1' },
        { name: 'arrange-a-to-z' },
        { name: 'arrange-z-to-a' },
        { name: 'arrow-down' },
        { name: 'arrow-down-left' },
        { name: 'arrow-down-right' },
        { name: 'arrow-left' },
        { name: 'arrow-return' },
        { name: 'arrow-right' },
        { name: 'arrow-up' },
        { name: 'arrow-up-left' },
        { name: 'arrow-up-right' },
        { name: 'artboard' },
        { name: 'asterisk' },
        { name: 'at-sign' },
        { name: 'bank' },
        { name: 'bank-note' },
        { name: 'banking-debit-machine' },
        { name: 'barcode' },
        { name: 'trash' },
        { name: 'binoculars' },
        { name: 'bitcoin-coin' },
        { name: 'bookmark' },
        { name: 'border-bottom' },
        { name: 'border-inside' },
        { name: 'border-inside-vertical' },
        { name: 'border-inside-horizontal' },
        { name: 'border-left' },
        { name: 'border-none' },
        { name: 'border-outside' },
        { name: 'border-right' },
        { name: 'border-top' },
        { name: 'box' },
        { name: 'briefcase' },
        { name: 'bus' },
        { name: 'graph-pie' },
        { name: 'scale' },
        { name: 'whiteboard' },
        { name: 'graph-plot' },
        { name: 'calculator' },
        { name: 'calculator-2' },
        { name: 'calendar' },
        { name: 'calendar-check' },
        { name: 'calendar-close' },
        { name: 'calendar-pencil' },
        { name: 'calendar-refresh-2' },
        { name: 'camera' },
        { name: 'brightness-1' },
        { name: 'camera-off' },
        { name: 'camera-pin' },
        { name: 'camera-refresh' },
        { name: 'car-6' },
        { name: 'dashboard' },
        { name: 'tape' },
        { name: 'center-point' },
        { name: 'chat-bubble-circle' },
        { name: 'chat-bubble-circle-active' },
        { name: 'chat-bubble-square' },
        { name: 'chat-bubble-square-active' },
        { name: 'chat-bubble-square-2' },
        { name: 'chat-bubbles-square' },
        { name: 'check-box' },
        { name: 'cloud' },
        { name: 'cloud-disable' },
        { name: 'cloud-download' },
        { name: 'cloud-refresh' },
        { name: 'cloud-upload' },
        { name: 'cloud-wifi' },
        { name: 'color-contrast-off' },
        { name: 'color-contrast-on' },
        { name: 'color-palette' },
        { name: 'computer-screen' },
        { name: 'contact-book' },
        { name: 'content-book' },
        { name: 'content-bookmark' },
        { name: 'filter' },
        { name: 'layers-hide' },
        { name: 'layers-show' },
        { name: 'note' },
        { name: 'content-view-array' },
        { name: 'content-view-content' },
        { name: 'content-view-list' },
        { name: 'content-view-module' },
        { name: 'crop' },
        { name: 'cursor-arrow' },
        { name: 'cursor-hand' },
        { name: 'cursor-move' },
        { name: 'cursor-select-area' },
        { name: 'cursor-tap' },
        { name: 'cursor-target' },
        { name: 'data-download' },
        { name: 'data-syncing' },
        { name: 'data-transfer' },
        { name: 'data-upload' },
        { name: 'delete' },
        { name: 'dial-pad' },
        { name: 'diamond' },
        { name: 'divide' },
        { name: 'email' },
        { name: 'email-read' },
        { name: 'envelope' },
        { name: 'equaliser' },
        { name: 'eraser' },
        { name: 'expand' },
        { name: 'expand-2' },
        { name: 'expand-vertical' },
        { name: 'expand-horizontal' },
        { name: 'exposure-level' },
        { name: 'file-add' },
        { name: 'file-copy' },
        { name: 'file-new' },
        { name: 'file-notes-document' },
        { name: 'file-notes-new' },
        { name: 'files' },
        { name: 'files-thumbs' },
        { name: 'flash' },
        { name: 'flash-off' },
        { name: 'flip-down' },
        { name: 'flip-left' },
        { name: 'flip-right' },
        { name: 'flip-up' },
        { name: 'focus' },
        { name: 'focus-off' },
        { name: 'folder-new' },
        { name: 'folders' },
        { name: 'font-color' },
        { name: 'font-size' },
        { name: 'format-clear' },
        { name: 'frame' },
        { name: 'gradient' },
        { name: 'hash' },
        { name: 'health-blood-drop' },
        { name: 'eye-closed' },
        { name: 'highlight' },
        { name: 'hourglass' },
        { name: 'id-card' },
        { name: 'inbox' },
        { name: 'indent-decrease' },
        { name: 'indent-increase' },
        { name: 'infinity-loop' },
        { name: 'interface-alert-circle' },
        { name: 'interface-information' },
        { name: 'interface-question-mark' },
        { name: 'intersect' },
        { name: 'italic' },
        { name: 'key' },
        { name: 'laptop' },
        { name: 'square' },
        { name: 'lightbulb' },
        { name: 'link' },
        { name: 'link-broken' },
        { name: 'list-bullets' },
        { name: 'list-number' },
        { name: 'location-direction' },
        { name: 'location-globe' },
        { name: 'location-gps-off' },
        { name: 'location-gps-on' },
        { name: 'location-plan' },
        { name: 'location-map' },
        { name: 'location-pin-1' },
        { name: 'location-pin-2' },
        { name: 'lock-closed' },
        { name: 'lock-open' },
        { name: 'leave' },
        { name: 'harry-potter' },
        { name: 'measuring-tool' },
        { name: 'minus-front' },
        { name: 'mobile-phone' },
        { name: 'money-note-coin' },
        { name: 'move-down' },
        { name: 'move-left' },
        { name: 'move-right' },
        { name: 'move-to-back' },
        { name: 'move-to-front' },
        { name: 'move-up' },
        { name: 'music-note' },
        { name: 'hamburger' },
        { name: 'more-horizontal' },
        { name: 'more-vertical' },
        { name: 'new-square' },
        { name: 'outbox' },
        { name: 'paint-brush' },
        { name: 'paint-bucket' },
        { name: 'paint-palette' },
        { name: 'paint-roll' },
        { name: 'paperclip' },
        { name: 'paperplane' },
        { name: 'paragraph' },
        { name: 'paragraph-left-to-right' },
        { name: 'paragraph-right-to-left' },
        { name: 'paragraph-spacing' },
        { name: 'pen-tool' },
        { name: 'pencil' },
        { name: 'percent' },
        { name: 'bug' },
        { name: 'photo-landscape' },
        { name: 'photo-portrait' },
        { name: 'photo-view-all' },
        { name: 'picture-layer' },
        { name: 'pin' },
        { name: 'home' },
        { name: 'power' },
        { name: 'printer' },
        { name: 'qr-code' },
        { name: 'quote-closing' },
        { name: 'quote-opening' },
        { name: 'reflect-left' },
        { name: 'reflect-right' },
        { name: 'close-x-big' },
        { name: 'ruler' },
        { name: 'scale-vertical' },
        { name: 'scissors' },
        { name: 'select-area' },
        { name: 'send-to-back' },
        { name: 'send-to-front' },
        { name: 'database' },
        { name: 'settings-slider' },
        { name: 'share' },
        { name: 'megaphone' },
        { name: 'rss' },
        { name: 'signal' },
        { name: 'signal-tower' },
        { name: 'shear-left' },
        { name: 'shear-right' },
        { name: 'shopping-bag-alt' },
        { name: 'shopping-basket' },
        { name: 'shopping-cart' },
        { name: 'shrink' },
        { name: 'shrink-diagonal' },
        { name: 'shrink-horizontal' },
        { name: 'shrink-vertical' },
        { name: 'command' },
        { name: 'sign-euro' },
        { name: 'sign-ramp-left' },
        { name: 'sign-ramp-right' },
        { name: 'skull' },
        { name: 'sliders' },
        { name: 'slider' },
        { name: 'small-caps' },
        { name: 'speaker-volume-decrease' },
        { name: 'speaker-volume-high' },
        { name: 'speaker-volume-increase' },
        { name: 'speaker-volume-low' },
        { name: 'speaker-volume-off' },
        { name: 'spelling-check' },
        { name: 'spray-paint' },
        { name: 'strike-through' },
        { name: 'subscript' },
        { name: 'substract' },
        { name: 'sunny' },
        { name: 'superscript' },
        { name: 'switch-left' },
        { name: 'switch-right' },
        { name: 'switches' },
        { name: 'bluetooth' },
        { name: 'wifi' },
        { name: 'repeat' },
        { name: 'synchronize' },
        { name: 'switch' },
        { name: 'price-tag' },
        { name: 'tank' },
        { name: 'text' },
        { name: 'text-eraser' },
        { name: 'rotate-right' },
        { name: 'rotate-left' },
        { name: 'text-vector' },
        { name: 'toolbox' },
        { name: 'underline' },
        { name: 'unite' },
        { name: 'user' },
        { name: 'vector-circle' },
        { name: 'vector-line' },
        { name: 'vector-square' },
        { name: 'video-call' },
        { name: 'video-clip' },
        { name: 'eject' },
        { name: 'next' },
        { name: 'pause' },
        { name: 'play' },
        { name: 'previous' },
        { name: 'stop' },
        { name: 'heart-outlined' },
        { name: 'star-outlined' },
        { name: 'thumbs-down' },
        { name: 'thumbs-up' },
        { name: 'zoom-in' },
        { name: 'zoom-out' },
        { name: 'glasses' },
        { name: 'save' },
        { name: 'chevron-left' },
        { name: 'chevron-right' },
        { name: 'move-vertical' },
        { name: 'drag-handle' },
        { name: 'user-chat' },
        { name: 'text-input' },
        { name: 'tablet' },
        { name: 'company' },
        { name: 'android' },
        { name: 'apple' },
        { name: 'facebook' },
        { name: 'google' },
        { name: 'linkedin' },
        { name: 'twitter' },
        { name: 'xing' },
        { name: 'youtube' },
        { name: 'find' },
        { name: 'business-man' },
        { name: 'factory' },
        { name: 'building' },
        { name: 'fax' },
        { name: 'globe' },
        { name: 'phone' },
        { name: 'close-x-circle' },
        { name: 'ticket' },
        { name: 'key-enter' },
        { name: 'key-left' },
        { name: 'key-right' },
        { name: 'key-shift' },
        { name: 'img' },
        { name: 'smiley' },
        { name: 'arrow-next' },
        { name: 'arrow-prev' },
        { name: 'wand' },
        { name: 'h-align-left' },
        { name: 'h-align-middle' },
        { name: 'h-align-right' },
        { name: 'v-align-bottom' },
        { name: 'v-align-middle' },
        { name: 'v-align-top' },
        { name: 'flip-h' },
        { name: 'flip-v' },
        { name: 'graph-bar' },
        { name: 'check' },
        { name: 'layer-down' },
        { name: 'layer-up' },
        { name: 'undo' },
        { name: 'redo' },
        { name: 'stackoverflow' },
        { name: 'kununu' },
        { name: 'totop' },
        { name: 'shopping-bag' },
        { name: 'profile-circle' },
        { name: 'heart-filled' },
        { name: 'github' },
        { name: 'glue' },
        { name: 'adhesive-tape' },
        { name: 'transparent' },
        { name: 'recycling' },
        { name: 'dumbbell' },
        { name: 'instagram' },
        { name: 'eye-open' },
        { name: 'water-bottle' },
        { name: 'close-x' },
        { name: 'star-filled' },
        { name: 'clock' },
        { name: 'appointment' },
        { name: 'save-date' },
        { name: 'whistle' },
        { name: 'weight' },
        { name: 'share-alt' },
        { name: 'coin-transfer' },
        { name: 'toggle-caret' },
        { name: 'config' },
        { name: 'server' },
        { name: 'undo-2' },
        { name: 'filter-2' },
        { name: 'article' },
        { name: 'bold' },
        { name: 'bigger-text' },
        { name: 'checkmark' },
        { name: 'cross' },
        { name: 'img-center' },
        { name: 'img-full' },
        { name: 'img-left' },
        { name: 'smaller-text' },
        { name: 'checkmark-2' },
        { name: 'json' },
        { name: 'required' },
        { name: 'validate' },
        { name: 'fingerprint' },
    ];

    /** Contains fonts using emojis. */
    var emojiIcons = [
        { name: 'add', content: '➕' },
        { name: 'close', content: '❌' },
        { name: 'bitcoin-coin', content: '💰' },
        { name: 'bookmark', content: '🔖' },
        { name: 'bus', content: '🚌' },
        { name: 'calendar', content: '📅' },
        { name: 'camera', content: '📷' },
        { name: 'check-box', content: '✅' },
        { name: 'cloud', content: '☁' },
        { name: 'computer-screen', content: '🖥' },
        { name: 'note', content: '🎵' },
        { name: 'email', content: '📧' },
        { name: 'find', content: '🔍' },
    ];

    var UiModule = /** @class */ (function () {
        function UiModule() {
        }
        return UiModule;
    }());
    UiModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        UtilityModule,
                        NotificationsModule,
                        PopModule,
                        LoaderModule,
                        FormModule,
                        ListModule,
                        SelectModule,
                        IconModule,
                        SymbolModule,
                    ],
                    exports: [
                        UtilityModule,
                        PopModule,
                        NotificationsModule,
                        LoaderModule,
                        ListModule,
                        FormModule,
                        SelectModule,
                        IconModule,
                        SymbolModule,
                    ],
                },] }
    ];

    /*
     * Public API Surface of ui
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.ActionbarComponent = ActionbarComponent;
    exports.DatetimeComponent = DatetimeComponent;
    exports.DefaultInputComponent = DefaultInputComponent;
    exports.DefaultOutputComponent = DefaultOutputComponent;
    exports.DynamicRackComponent = DynamicRackComponent;
    exports.DynamicSlotComponent = DynamicSlotComponent;
    exports.ErrorComponent = ErrorComponent;
    exports.FocusDirective = FocusDirective;
    exports.FormComponent = FormComponent;
    exports.FormModule = FormModule;
    exports.FormService = FormService;
    exports.GroupPipe = GroupPipe;
    exports.IconComponent = IconComponent;
    exports.IconModule = IconModule;
    exports.IconService = IconService;
    exports.InputComponent = InputComponent;
    exports.InputErrorsComponent = InputErrorsComponent;
    exports.IoModule = IoModule;
    exports.KeycommandsService = KeycommandsService;
    exports.ListComponent = ListComponent;
    exports.ListConfigService = ListConfigService;
    exports.ListHeaderComponent = ListHeaderComponent;
    exports.ListItemsComponent = ListItemsComponent;
    exports.ListModule = ListModule;
    exports.LoaderComponent = LoaderComponent;
    exports.LoaderModule = LoaderModule;
    exports.LoaderService = LoaderService;
    exports.LoginFormComponent = LoginFormComponent;
    exports.MaxItemsPipe = MaxItemsPipe;
    exports.ModalComponent = ModalComponent;
    exports.Notification = Notification;
    exports.NotificationsComponent = NotificationsComponent;
    exports.NotificationsModule = NotificationsModule;
    exports.NotificationsService = NotificationsService;
    exports.OutputComponent = OutputComponent;
    exports.PaginationComponent = PaginationComponent;
    exports.PopComponent = PopComponent;
    exports.PopModule = PopModule;
    exports.PopService = PopService;
    exports.SearchbarComponent = SearchbarComponent;
    exports.SelectComponent = SelectComponent;
    exports.SelectModule = SelectModule;
    exports.SignupFormComponent = SignupFormComponent;
    exports.SlotHostDirective = SlotHostDirective;
    exports.SymbolModule = SymbolModule;
    exports.SymbolPipe = SymbolPipe;
    exports.SymbolService = SymbolService;
    exports.TabComponent = TabComponent;
    exports.TabsComponent = TabsComponent;
    exports.ToggleComponent = ToggleComponent;
    exports.UiModule = UiModule;
    exports.UtilityModule = UtilityModule;
    exports.VisibleFieldsPipe = VisibleFieldsPipe;
    exports.componentDestroyed = componentDestroyed;
    exports.de = de;
    exports.ecIcons = ecIcons;
    exports.emojiIcons = emojiIcons;
    exports.en = en;
    exports.formTemplate = formTemplate;
    exports.listTemplate = listTemplate;
    exports.selectTemplate = selectTemplate;
    exports.ɵa = PeriodComponent;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ec.components-ui.umd.js.map
